/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.17u-20030607-0942
 * 
 * This file is not intended to be easily readable and contains a number of 
 * coding conventions designed to improve portability and efficiency. Do not make
 * changes to this file unless you know what you are doing--modify the SWIG 
 * interface file instead. 
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
template<class T> class SwigValueWrapper {
    T *tt;
public:
    inline SwigValueWrapper() : tt(0) { }
    inline ~SwigValueWrapper() { if (tt) delete tt; } 
    inline SwigValueWrapper& operator=(const T& t) { tt = new T(t); return *this; }
    inline operator T&() const { return *tt; }
    inline T *operator&() { return tt; }
};                                                    
#endif

/***********************************************************************
 * common.swg
 *
 *     This file contains generic SWIG runtime support for pointer
 *     type checking as well as a few commonly used macros to control
 *     external linkage.
 *
 * Author : David Beazley (beazley@cs.uchicago.edu)
 *
 * Copyright (c) 1999-2000, The University of Chicago
 * 
 * This file may be freely redistributed without license or fee provided
 * this copyright message remains intact.
 ************************************************************************/

#include <string.h>

#if defined(_WIN32) || defined(__WIN32__)
#       if defined(_MSC_VER)
#               if defined(STATIC_LINKED)
#                       define SWIGEXPORT(a) a
#                       define SWIGIMPORT(a) extern a
#               else
#                       define SWIGEXPORT(a) __declspec(dllexport) a
#                       define SWIGIMPORT(a) extern a
#               endif
#       else
#               if defined(__BORLANDC__)
#                       define SWIGEXPORT(a) a _export
#                       define SWIGIMPORT(a) a _export
#               else
#                       define SWIGEXPORT(a) a
#                       define SWIGIMPORT(a) a
#               endif
#       endif
#else
#       define SWIGEXPORT(a) a
#       define SWIGIMPORT(a) a
#endif

#ifdef SWIG_GLOBAL
#define SWIGRUNTIME(a) SWIGEXPORT(a)
#else
#define SWIGRUNTIME(a) static a
#endif

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

typedef struct swig_type_info {
  const char             *name;                 
  swig_converter_func     converter;
  const char             *str;
  void                   *clientdata;	
  swig_dycast_func        dcast;
  struct swig_type_info  *next;
  struct swig_type_info  *prev;
} swig_type_info;

#ifdef SWIG_NOINCLUDE

SWIGIMPORT(swig_type_info *) SWIG_TypeRegister(swig_type_info *);
SWIGIMPORT(swig_type_info *) SWIG_TypeCheck(char *c, swig_type_info *);
SWIGIMPORT(void *)           SWIG_TypeCast(swig_type_info *, void *);
SWIGIMPORT(swig_type_info *) SWIG_TypeDynamicCast(swig_type_info *, void **);
SWIGIMPORT(swig_type_info *) SWIG_TypeQuery(const char *);
SWIGIMPORT(void)             SWIG_TypeClientData(swig_type_info *, void *);

#else

static swig_type_info *swig_type_list = 0;

/* Register a type mapping with the type-checking */
SWIGRUNTIME(swig_type_info *)
SWIG_TypeRegister(swig_type_info *ti)
{
  swig_type_info *tc, *head, *ret, *next;
  /* Check to see if this type has already been registered */
  tc = swig_type_list;
  while (tc) {
    if (strcmp(tc->name, ti->name) == 0) {
      /* Already exists in the table.  Just add additional types to the list */
      if (tc->clientdata) ti->clientdata = tc->clientdata;	
      head = tc;
      next = tc->next;
      goto l1;
    }
    tc = tc->prev;
  }
  head = ti;
  next = 0;

  /* Place in list */
  ti->prev = swig_type_list;
  swig_type_list = ti;

  /* Build linked lists */
 l1:
  ret = head;
  tc = ti + 1;
  /* Patch up the rest of the links */
  while (tc->name) {
    head->next = tc;
    tc->prev = head;
    head = tc;
    tc++;
  }
  head->next = next;
  return ret;
}

/* Cast a pointer up an inheritance hierarchy */
SWIGRUNTIME(void *) 
SWIG_TypeCast(swig_type_info *ty, void *ptr) 
{
  if ((!ty) || (!ty->converter)) return ptr;
  return (*ty->converter)(ptr);
}

/* Dynamic pointer casting. Down an inheritance hierarchy */
SWIGRUNTIME(swig_type_info *) 
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) 
{
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
     ty = (*ty->dcast)(ptr);
     if (ty) lastty = ty;
  }
  return lastty;
}

/* Search for a swig_type_info structure */
SWIGRUNTIME(swig_type_info *)
SWIG_TypeQuery(const char *name) {
  swig_type_info *ty = swig_type_list;
  while (ty) {
    if (ty->str && (strcmp(name,ty->str) == 0)) return ty;
    if (ty->name && (strcmp(name,ty->name) == 0)) return ty;
    ty = ty->prev;
  }
  return 0;
}

/* Set the clientdata field for a type */
SWIGRUNTIME(void)
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_type_info *tc, *equiv;
  if (ti->clientdata) return;
  ti->clientdata = clientdata;
  equiv = ti->next;
  while (equiv) {
    if (!equiv->converter) {
      tc = swig_type_list;
      while (tc) {
	if ((strcmp(tc->name, equiv->name) == 0))
	  SWIG_TypeClientData(tc,clientdata);
	tc = tc->prev;
      }
    }
    equiv = equiv->next;
  }
}
#endif

#ifdef __cplusplus
}

#endif

/* -----------------------------------------------------------------------------
 * perl5.swg
 *
 * Perl5 runtime library
 * ----------------------------------------------------------------------------- */

#define SWIGPERL
#define SWIGPERL5
#ifdef __cplusplus
/* Needed on some windows machines---since MS plays funny
   games with the header files under C++ */
#include <math.h>
#include <stdlib.h>
extern "C" {
#endif
#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

/* Get rid of free and malloc defined by perl */
#undef free
#undef malloc

#ifndef pTHX_
#define pTHX_
#endif

#include <string.h>
#ifdef __cplusplus
}
#endif

/* Macro to call an XS function */

/* Check the typename */
SWIGRUNTIME(swig_type_info *) 
SWIG_TypeCheck(SV *sv, swig_type_info *ty)
{
  swig_type_info *s;
  if (!ty) return 0;        /* Void pointer */
  s = ty->next;             /* First element always just a name */
  while (s) {
    if (sv_derived_from(sv,(char*)s->name)) {
      if (s == ty->next) return s;
      /* Move s to the top of the linked list */
      s->prev->next = s->next;
      if (s->next) {
	s->next->prev = s->prev;
      }
      /* Insert s as second element in the list */
      s->next = ty->next;
      if (ty->next) ty->next->prev = s;
      ty->next = s;
      return s;
    }
    s = s->next;
  }
  return 0;
}

#ifdef PERL_OBJECT 
#define SWIG_CALLXS(_name) _name(cv,pPerl) 
#else 
#ifndef MULTIPLICITY 
#define SWIG_CALLXS(_name) _name(cv) 
#else 
#define SWIG_CALLXS(_name) _name(PERL_GET_THX, cv) 
#endif 
#endif 

/* Macros for low-level exception handling */
#define SWIG_fail      goto fail
#define SWIG_croak(x)  while ((_swigerr = (const char *) x)) goto fail
#define SWIG_MAX_ERRMSG 256

/* Note: SwigMagicFuncHack is a typedef used to get the C++
   compiler to just shut up already */

#ifdef PERL_OBJECT
#define MAGIC_PPERL  CPerlObj *pPerl = (CPerlObj *) this;
typedef int (CPerlObj::*SwigMagicFunc)(SV *, MAGIC *);

#ifdef __cplusplus
extern "C" {
#endif
typedef int (CPerlObj::*SwigMagicFuncHack)(SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#define SWIG_MAGIC(a,b) (SV *a, MAGIC *b)
#define SWIGCLASS_STATIC
#else
#define MAGIC_PPERL
#define SWIGCLASS_STATIC static
#ifndef MULTIPLICITY
#define SWIG_MAGIC(a,b) (SV *a, MAGIC *b)
typedef int (*SwigMagicFunc)(SV *, MAGIC *);

#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFuncHack)(SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#else
#define SWIG_MAGIC(a,b) (struct interpreter *interp, SV *a, MAGIC *b)
typedef int (*SwigMagicFunc)(struct interpreter *, SV *, MAGIC *);
#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFuncHack)(struct interpreter *, SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#endif
#endif

#if defined(WIN32) && defined(PERL_OBJECT) && !defined(PerlIO_exportFILE)
#define PerlIO_exportFILE(fh,fl) (FILE*)(fh)
#endif

/* Modifications for newer Perl 5.005 releases */

#if !defined(PERL_REVISION) || ((PERL_REVISION >= 5) && ((PERL_VERSION < 5) || ((PERL_VERSION == 5) && (PERL_SUBVERSION < 50))))
#ifndef PL_sv_yes
#define PL_sv_yes sv_yes
#endif
#ifndef PL_sv_undef
#define PL_sv_undef sv_undef
#endif
#ifndef PL_na
#define PL_na na
#endif
#endif

#include <stdlib.h>

#ifdef __cplusplus
extern "C" {
#endif

#ifdef SWIG_NOINCLUDE

#ifndef PERL_OBJECT
extern int SWIG_ConvertPtr(SV *, void **, swig_type_info *, int flags);
extern void SWIG_MakePtr(SV *, void *, swig_type_info *, int flags);
#else
extern int _SWIG_ConvertPtr(CPerlObj *, SV *, void **, swig_type_info *,int flags);
extern void _SWIG_MakePtr(CPerlObj *, SV *, void *, swig_type_info *, int flags);
#define SWIG_ConvertPtr(a,b,c,d) _SWIG_ConvertPtr(pPerl,a,b,c,d)
#define SWIG_MakePtr(a,b,c,d) _SWIG_MakePtr(pPerl,a,b,c,d)
#endif

#else

/* Function for getting a pointer value */

#ifndef PERL_OBJECT
SWIGRUNTIME(int) 
SWIG_ConvertPtr(SV *sv, void **ptr, swig_type_info *_t, int flags)
#else
#define SWIG_ConvertPtr(a,b,c,d) _SWIG_ConvertPtr(pPerl,a,b,c,d)
SWIGRUNTIME(int)
_SWIG_ConvertPtr(CPerlObj *pPerl, SV *sv, void **ptr, swig_type_info *_t, int flags)
#endif
{
  char *_c;
  swig_type_info *tc;
  IV   tmp;

  /* If magical, apply more magic */
  if (SvGMAGICAL(sv))
    mg_get(sv);

  /* Check to see if this is an object */
  if (sv_isobject(sv)) {
    SV *tsv = (SV*) SvRV(sv);
    if ((SvTYPE(tsv) == SVt_PVHV)) {
      MAGIC *mg;
      if (SvMAGICAL(tsv)) {
	mg = mg_find(tsv,'P');
	if (mg) {
	  SV *rsv = mg->mg_obj;
	  if (sv_isobject(rsv)) {
	    tmp = SvIV((SV*)SvRV(rsv));
	  }
	}
      } else {
	return -1;
      }
    } else {
      tmp = SvIV((SV*)SvRV(sv));
    }
    if (!_t) {
      *(ptr) = (void *) tmp;
      return 0;
    }
  } else if (! SvOK(sv)) {            /* Check for undef */
    *(ptr) = (void *) 0;
    return 0;
  } else if (SvTYPE(sv) == SVt_RV) {  /* Check for NULL pointer */
    *(ptr) = (void *) 0;
    if (!SvROK(sv)) 
      return 0;
    else
      return -1;
  } else {                            /* Don't know what it is */
      *(ptr) = (void *) 0;
      return -1;
  }
  if (_t) {
    /* Now see if the types match */      
    _c = HvNAME(SvSTASH(SvRV(sv)));
    tc = SWIG_TypeCheck(sv,_t);
    if (!tc) {
      *ptr = (void *) tmp;
      return -1;
    }
    *ptr = SWIG_TypeCast(tc,(void *)tmp);
    return 0;
  }
  *ptr = (void *) tmp;
  return 0;
}
#ifndef PERL_OBJECT
SWIGRUNTIME(void) 
SWIG_MakePtr(SV *sv, void *ptr, swig_type_info *t,int flags)
#else
#define SWIG_MakePtr(a,b,c,d) _SWIG_MakePtr(pPerl,a,b,c,d)
SWIGRUNTIME(void)
_SWIG_MakePtr(CPerlObj *pPerl, SV *sv, void *ptr, swig_type_info *t, int flags)
#endif
{
  sv_setref_pv(sv, (char *) t->name, ptr);
}

#endif

typedef XS(SwigPerlWrapper);
typedef SwigPerlWrapper *SwigPerlWrapperPtr;

/* Structure for command table */
typedef struct {
  const char         *name;
  SwigPerlWrapperPtr  wrapper;
} swig_command_info;

/* Information for constant table */

#define SWIG_INT     1
#define SWIG_FLOAT   2
#define SWIG_STRING  3
#define SWIG_POINTER 4
#define SWIG_BINARY  5

/* Constant information structure */
typedef struct swig_constant_info {
    int              type;
    const char      *name;
    long             lvalue;
    double           dvalue;
    void            *pvalue;
    swig_type_info **ptype;
} swig_constant_info;

#ifdef __cplusplus
}
#endif

/* Structure for variable table */
typedef struct {
  const char   *name;
  SwigMagicFunc   set;
  SwigMagicFunc   get;
  swig_type_info  **type;
} swig_variable_info;

/* Magic variable code */
#ifndef PERL_OBJECT
#define swig_create_magic(s,a,b,c) _swig_create_magic(s,a,b,c)
  #ifndef MULTIPLICITY 
       static void _swig_create_magic(SV *sv, char *name, int (*set)(SV *, MAGIC *), int \
(*get)(SV *,MAGIC *)) { 
  #else 
       static void _swig_create_magic(SV *sv, char *name, int (*set)(struct interpreter*,\
 SV *, MAGIC *), int (*get)(struct interpreter*, SV *,MAGIC *)) { 
  #endif 
#else
#define swig_create_magic(s,a,b,c) _swig_create_magic(pPerl,s,a,b,c)
static void _swig_create_magic(CPerlObj *pPerl, SV *sv, const char *name, int (CPerlObj::*set)(SV *, MAGIC *), int (CPerlObj::*get)(SV *, MAGIC *)) {
#endif
  MAGIC *mg;
  sv_magic(sv,sv,'U',(char *) name,strlen(name));
  mg = mg_find(sv,'U');
  mg->mg_virtual = (MGVTBL *) malloc(sizeof(MGVTBL));
  mg->mg_virtual->svt_get = (SwigMagicFuncHack) get;
  mg->mg_virtual->svt_set = (SwigMagicFuncHack) set;
  mg->mg_virtual->svt_len = 0;
  mg->mg_virtual->svt_clear = 0;
  mg->mg_virtual->svt_free = 0;
}

/* -------- TYPES TABLE (BEGIN) -------- */

#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator swig_types[0] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument swig_types[1] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation swig_types[2] 
#define  SWIGTYPE_p_XMLCh swig_types[3] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry swig_types[4] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMConfiguration swig_types[5] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter swig_types[6] 
#define  SWIGTYPE_p_size_t swig_types[7] 
#define  SWIGTYPE_p_XMLAttr swig_types[8] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLReaderFactory swig_types[9] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList swig_types[10] 
#define  SWIGTYPE_p_XMLBuffer swig_types[11] 
#define  SWIGTYPE_p_bool swig_types[12] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter swig_types[13] 
#define  SWIGTYPE_p_XMLNotationDecl swig_types[14] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUni swig_types[15] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLExcepts swig_types[16] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType swig_types[17] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode swig_types[18] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl swig_types[19] 
#define  SWIGTYPE_p_void swig_types[20] 
#define  SWIGTYPE_p_p_void swig_types[21] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange swig_types[22] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityReference swig_types[23] 
#define  SWIGTYPE_p_int swig_types[24] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation swig_types[25] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException swig_types[26] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException swig_types[27] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException swig_types[28] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException swig_types[29] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException swig_types[30] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException swig_types[31] 
#define  SWIGTYPE_p_XMLErrorReporter swig_types[32] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLErrorReporter swig_types[33] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException swig_types[34] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDeleter swig_types[35] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes swig_types[36] 
#define  SWIGTYPE_FileHandle swig_types[37] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal swig_types[38] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser swig_types[39] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser swig_types[40] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner swig_types[41] 
#define  SWIGTYPE_p_XMLReader__XMLVersion swig_types[42] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr swig_types[43] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder swig_types[44] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser swig_types[45] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL swig_types[46] 
#define  SWIGTYPE_p_XMLAttDef swig_types[47] 
#define  SWIGTYPE_p_p_XERCES_CPP_NAMESPACE__QName swig_types[48] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName swig_types[49] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver swig_types[50] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__GrammarResolver swig_types[51] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityResolver swig_types[52] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter swig_types[53] 
#define  SWIGTYPE_p_DOMWriterFilter swig_types[54] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter swig_types[55] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler swig_types[56] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLEntityHandler swig_types[57] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler swig_types[58] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler swig_types[59] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler swig_types[60] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler swig_types[61] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler swig_types[62] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler swig_types[63] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler swig_types[64] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocTypeHandler swig_types[65] 
#define  SWIGTYPE_p_PanicHandler swig_types[66] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMUserDataHandler swig_types[67] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler swig_types[68] 
#define  SWIGTYPE_p_PerlErrorCallbackHandler swig_types[69] 
#define  SWIGTYPE_p_PerlDocumentCallbackHandler swig_types[70] 
#define  SWIGTYPE_p_PerlContentCallbackHandler swig_types[71] 
#define  SWIGTYPE_p_PerlEntityResolverHandler swig_types[72] 
#define  SWIGTYPE_p_PerlNodeFilterCallbackHandler swig_types[73] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker swig_types[74] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText swig_types[75] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS swig_types[76] 
#define  SWIGTYPE_p_XMLValid__Codes swig_types[77] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLStringPool swig_types[78] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTypeInfo swig_types[79] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLMsgLoader swig_types[80] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager swig_types[81] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLBufferMgr swig_types[82] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator swig_types[83] 
#define  SWIGTYPE_p_SecurityManager swig_types[84] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator swig_types[85] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData swig_types[86] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment swig_types[87] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream swig_types[88] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource swig_types[89] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource swig_types[90] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdInInputSource swig_types[91] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource swig_types[92] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource swig_types[93] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap swig_types[94] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource swig_types[95] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationSource swig_types[96] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__ReaderMgr swig_types[97] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList swig_types[98] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar swig_types[99] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader swig_types[100] 
#define  SWIGTYPE_p_SV swig_types[101] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser swig_types[102] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMComment swig_types[103] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase swig_types[104] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri swig_types[105] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter swig_types[106] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentRange swig_types[107] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLTranscoder swig_types[108] 
#define  SWIGTYPE_p_unsigned_int swig_types[109] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget swig_types[110] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget swig_types[111] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget swig_types[112] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction swig_types[113] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection swig_types[114] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__HexBin swig_types[115] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__Base64 swig_types[116] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken swig_types[117] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPlatformUtils swig_types[118] 
#define  SWIGTYPE_p_PanicHandler__PanicReasons swig_types[119] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator swig_types[120] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement swig_types[121] 
#define  SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity swig_types[122] 
static swig_type_info *swig_types[124];

/* -------- TYPES TABLE (END) -------- */

#define SWIG_init    boot_XML__Xerces

#define SWIG_name   "XML::Xercesc::boot_XML__Xerces"
#define SWIG_prefix "XML::Xercesc::"

#ifdef __cplusplus
extern "C"
#endif
#ifndef PERL_OBJECT
#ifndef MULTIPLICITY
SWIGEXPORT(void) SWIG_init (CV* cv);
#else
SWIGEXPORT(void) SWIG_init (pTHXo_ CV* cv);
#endif
#else
SWIGEXPORT(void) SWIG_init (CV *cv, CPerlObj *);
#endif

#include "stdio.h"
#include "string.h"
#include "xercesc/sax/InputSource.hpp"
#include "xercesc/sax/SAXException.hpp"
#include "xercesc/sax/SAXParseException.hpp"
#include "xercesc/sax/Locator.hpp"
#include "xercesc/sax/HandlerBase.hpp"
#include "xercesc/sax2/Attributes.hpp"
#include "xercesc/sax2/ContentHandler.hpp"
#include "xercesc/sax2/LexicalHandler.hpp"
#include "xercesc/sax2/DefaultHandler.hpp"
#include "xercesc/sax2/SAX2XMLReader.hpp"
#include "xercesc/sax2/XMLReaderFactory.hpp"
#include "xercesc/util/PlatformUtils.hpp"
#include "xercesc/util/TransService.hpp"
#include "xercesc/util/XMLString.hpp"
#include "xercesc/util/XMLUri.hpp"
#include "xercesc/util/QName.hpp"
#include "xercesc/util/HexBin.hpp"
#include "xercesc/util/Base64.hpp"
#include "xercesc/parsers/AbstractDOMParser.hpp"
#include "xercesc/parsers/XercesDOMParser.hpp"
#include "xercesc/parsers/SAXParser.hpp"
#include "xercesc/dom/DOM.hpp"
#include "xercesc/framework/LocalFileInputSource.hpp"
#include "xercesc/framework/MemBufInputSource.hpp"
#include "xercesc/framework/StdInInputSource.hpp"
#include "xercesc/framework/URLInputSource.hpp"
#include "xercesc/framework/XMLValidator.hpp"
#include "xercesc/framework/XMLFormatter.hpp"
#include "xercesc/framework/MemBufFormatTarget.hpp"
#include "xercesc/framework/StdOutFormatTarget.hpp"
#include "xercesc/validators/common/Grammar.hpp"

#include "PerlErrorCallbackHandler.hpp"
#include "PerlDocumentCallbackHandler.hpp"
#include "PerlContentCallbackHandler.hpp"

#include "PerlEntityResolverHandler.i"
#include "PerlNodeFilterCallbackHandler.i"

XERCES_CPP_NAMESPACE_USE

// we initialize the static UTF-8 transcoding info
// these are used by the typemaps to convert between
// Xerces internal UTF-16 and Perl's internal UTF-8
static XMLCh* UTF8_ENCODING = NULL; 
static XMLTranscoder* UTF8_TRANSCODER  = NULL;

static XMLCh* ISO_8859_1_ENCODING = NULL; 
static XMLTranscoder* ISO_8859_1_TRANSCODER  = NULL;

static bool DEBUG_UTF8_OUT = 0;
static bool DEBUG_UTF8_IN = 0;

static char debug_char[2048];
static XMLCh debug_xml[2048];

char*
debugPrint(const XMLCh* str){
    return (char*)XMLString::transcode(str);
}

// These exception creation methods make the Xerces.C code *much* smaller
void
makeXMLException(const XMLException& e){
    SV *tmpsv;
    HV *hash = newHV();
    char *XML_EXCEPTION = "XML::Xerces::XMLException";
    HV *XML_EXCEPTION_STASH = gv_stashpv(XML_EXCEPTION, FALSE);
    hv_magic(hash, 
	     (GV *)sv_setref_pv(sv_newmortal(), 
				XML_EXCEPTION, (void *)&e), 
	     'P');
    tmpsv = sv_bless(newRV_noinc((SV *)hash), XML_EXCEPTION_STASH);
    SV *error = ERRSV;
    SvSetSV(error,tmpsv);
    (void)SvUPGRADE(error, SVt_PV);
    croak(Nullch);
}

void
makeDOMException(const DOMException& e){
    SV *tmpsv;
    HV *hash = newHV();
    char *DOM_EXCEPTION = "XML::Xerces::DOMException";
    HV *DOM_EXCEPTION_STASH = gv_stashpv(DOM_EXCEPTION, FALSE);
    hv_magic(hash, 
	     (GV *)sv_setref_pv(sv_newmortal(), 
				DOM_EXCEPTION, (void *)&e), 
	     'P');
    tmpsv = sv_bless(newRV_noinc((SV *)hash), DOM_EXCEPTION_STASH);
    SV *error = ERRSV;
    SvSetSV(error,tmpsv);
    (void)SvUPGRADE(error, SVt_PV);
    croak(Nullch);
}

void
makeSAXNotRecognizedException(const SAXNotRecognizedException& e){
    SV *tmpsv;
    HV *hash = newHV();
    char *SAX_NOT_RECOGNIZED_EXCEPTION = "XML::Xerces::SAXNotRecognizedException";
    HV *SAX_NOT_RECOGNIZED_EXCEPTION_STASH = gv_stashpv(SAX_NOT_RECOGNIZED_EXCEPTION, FALSE);
    hv_magic(hash, 
	     (GV *)sv_setref_pv(sv_newmortal(), 
				SAX_NOT_RECOGNIZED_EXCEPTION, (void *)&e), 
	     'P');
    tmpsv = sv_bless(newRV_noinc((SV *)hash), SAX_NOT_RECOGNIZED_EXCEPTION_STASH);
    SV *error = ERRSV;
    SvSetSV(error,tmpsv);
    (void)SvUPGRADE(error, SVt_PV);
    croak(Nullch);
}

void
makeSAXNotSupportedException(const SAXNotSupportedException& e){
    SV *tmpsv;
    HV *hash = newHV();
    char *SAX_NOT_SUPPORTED_EXCEPTION = "XML::Xerces::SAXNotSupportedException";
    HV *SAX_NOT_SUPPORTED_EXCEPTION_STASH = gv_stashpv(SAX_NOT_SUPPORTED_EXCEPTION, FALSE);
    hv_magic(hash, 
	     (GV *)sv_setref_pv(sv_newmortal(), 
				SAX_NOT_SUPPORTED_EXCEPTION, (void *)&e), 
	     'P');
    tmpsv = sv_bless(newRV_noinc((SV *)hash), SAX_NOT_SUPPORTED_EXCEPTION_STASH);
    SV *error = ERRSV;
    SvSetSV(error,tmpsv);
    (void)SvUPGRADE(error, SVt_PV);
    croak(Nullch);
}

SV*
XMLString2Perl(XMLCh* input){
    SV *output;
  unsigned int charsEaten = 0;
  int length  = XMLString::stringLen(input);      // string length
  XMLByte* res = new XMLByte[length * UTF8_MAXLEN];          // output string
  unsigned int total_chars =
    UTF8_TRANSCODER->transcodeTo((const XMLCh*) input, 
				   (unsigned int) length,
				   (XMLByte*) res,
				   (unsigned int) length*UTF8_MAXLEN,
				   charsEaten,
				   XMLTranscoder::UnRep_Throw
				   );
  res[total_chars] = '\0';
  if (DEBUG_UTF8_OUT) {
      printf("Xerces out length = %d: ",total_chars);
      for (int i=0;i<length;i++){
	  printf("<0x%.4X>",res[i]);
      }
      printf("\n");
  }
  output = sv_newmortal();
  sv_setpv((SV*)output, (char *)res );
  SvUTF8_on((SV*)output);
  delete[] res;
  return output;
}

XMLCh* 
Perl2XMLString(SV* input){
    XMLCh* output;

    STRLEN length;
    char *ptr = (char *)SvPV(input,length);
    if (DEBUG_UTF8_IN) {
	printf("Perl in length = %d: ",length);
	for (unsigned int i=0;i<length;i++){
	    printf("<0x%.4X>",ptr[i]);
	}
	printf("\n");
    }
    if (SvUTF8(input)) {
	unsigned int charsEaten = 0;
        unsigned char* sizes = new unsigned char[length+1];
        output = new XMLCh[length+1];
	unsigned int chars_stored = 
	    UTF8_TRANSCODER->transcodeFrom((const XMLByte*) ptr,
					   (unsigned int) length,
					   (XMLCh*) output, 
					   (unsigned int) length,
					   charsEaten,
					   (unsigned char*)sizes
					   );
	delete [] sizes;
	if (DEBUG_UTF8_IN) {
	    printf("Xerces in length = %d: ",chars_stored);
	    for (unsigned int i=0;i<chars_stored;i++){
		printf("<0x%.4X>",output[i]);
	    }
	    printf("\n");
	}
	    // indicate the end of the string
	output[chars_stored] = '\0';
    } else {
	output = XMLString::transcode(ptr);
	if (DEBUG_UTF8_IN) {
	    printf("Xerces: ");
	    for (int i=0;output[i];i++){
		printf("<0x%.4X>",output[i]);
	    }
	    printf("\n");
	}
    }
    return(output);
}

static swig_type_info *
DOMNode_dynamic_cast(void **ptr) {
   DOMNode **nptr = (DOMNode **) ptr;
   if (*nptr == NULL) {
       return NULL;
   }
   short int type = (*nptr)->getNodeType();
   if (type == DOMNode::TEXT_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText;
   }
   if (type == DOMNode::PROCESSING_INSTRUCTION_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction;
   }
   if (type == DOMNode::DOCUMENT_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument;
   }
   if (type == DOMNode::ELEMENT_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement;
   }
   if (type == DOMNode::ENTITY_REFERENCE_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityReference;
   }
   if (type == DOMNode::CDATA_SECTION_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection;
   }
   if (type == DOMNode::CDATA_SECTION_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection;
   }
   if (type == DOMNode::COMMENT_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMComment;
   }
   if (type == DOMNode::DOCUMENT_TYPE_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType;
   }
   if (type == DOMNode::ENTITY_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity;
   }
   if (type == DOMNode::ATTRIBUTE_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr;
   }
   if (type == DOMNode::NOTATION_NODE) {
      return SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation;
   }
   return NULL;
}

bool XERCES_CPP_NAMESPACE_DOMNode_operator_ee___(XERCES_CPP_NAMESPACE::DOMNode *self,XERCES_CPP_NAMESPACE::DOMNode const *other){
       return self->isSameNode(other);
   }
bool XERCES_CPP_NAMESPACE_DOMNode_operator_Ne___(XERCES_CPP_NAMESPACE::DOMNode *self,XERCES_CPP_NAMESPACE::DOMNode const *other){
       return !self->isSameNode(other);
   }
XERCES_CPP_NAMESPACE::DOMNode *XERCES_CPP_NAMESPACE_DOMDocument_toDOMNode(XERCES_CPP_NAMESPACE::DOMDocument *self){
     return (DOMNode*) self;
   }
XERCES_CPP_NAMESPACE::DOMDocumentTraversal *XERCES_CPP_NAMESPACE_DOMDocument_toDOMDocumentTraversal(XERCES_CPP_NAMESPACE::DOMDocument *self){
     return (DOMDocumentTraversal*) self;
   }
#ifdef PERL_OBJECT
#define MAGIC_CLASS _wrap_XML::Xerces_var::
class _wrap_XML::Xerces_var : public CPerlObj {
public:
#else
#define MAGIC_CLASS
#endif
SWIGCLASS_STATIC int swig_magic_readonly(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    sv = sv; mg = mg;
    croak("Value is read-only.");
    return 0;
}
SWIGCLASS_STATIC int _wrap_set_DEBUG_UTF8_OUT(pTHX_ SV* sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    DEBUG_UTF8_OUT = (bool) SvIV(sv);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_DEBUG_UTF8_OUT(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(sv, (IV) DEBUG_UTF8_OUT);
    return 1;
}

SWIGCLASS_STATIC int _wrap_set_DEBUG_UTF8_IN(pTHX_ SV* sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    DEBUG_UTF8_IN = (bool) SvIV(sv);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_DEBUG_UTF8_IN(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(sv, (IV) DEBUG_UTF8_IN);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgAnyString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgAnyString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgAttListString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgAttListString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgCommentString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgCommentString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgCDATAString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgCDATAString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDefaultString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDefaultString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDocTypeString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDocTypeString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEBCDICEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEBCDICEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgElemString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgElemString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEmptyString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEmptyString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEntitString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEntitString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEntityString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEntityString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEntitiesString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEntitiesString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEnumerationString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEnumerationString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgExceptDomain(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgExceptDomain);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgFixedString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgFixedString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM037EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM037EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM037EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM037EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM1140EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM1140EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM1140EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM1140EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM1140EncodingString3(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM1140EncodingString3);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIBM1140EncodingString4(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIBM1140EncodingString4);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIESString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIESString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIDString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIDString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIDRefString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIDRefString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIDRefsString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIDRefsString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgImpliedString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgImpliedString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIgnoreString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIgnoreString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIncludeString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIncludeString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString3(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString3);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString4(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString4);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString5(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString5);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString6(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString6);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString7(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString7);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString8(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString8);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString9(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString9);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString10(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString10);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString11(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString11);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgISO88591EncodingString12(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgISO88591EncodingString12);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgLocalHostString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgLocalHostString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNoString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNoString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNotationString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNotationString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNDATAString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNDATAString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNmTokenString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNmTokenString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNmTokensString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNmTokensString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgPCDATAString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgPCDATAString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgPIString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgPIString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgPubIDString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgPubIDString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgRefString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgRefString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgRequiredString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgRequiredString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgStandaloneString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgStandaloneString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgVersion1_0(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgVersion1_0);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgVersion1_1(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgVersion1_1);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSysIDString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSysIDString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUnknownURIName(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUnknownURIName);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4EncodingString3(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4EncodingString3);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4BEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4BEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4BEncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4BEncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4LEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4LEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUCS4LEncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUCS4LEncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUSASCIIEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUSASCIIEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUSASCIIEncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUSASCIIEncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUSASCIIEncodingString3(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUSASCIIEncodingString3);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUSASCIIEncodingString4(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUSASCIIEncodingString4);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF8EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF8EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF8EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF8EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16EncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16EncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16EncodingString3(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16EncodingString3);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16EncodingString4(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16EncodingString4);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16EncodingString5(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16EncodingString5);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16BEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16BEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16BEncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16BEncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16LEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16LEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTF16LEncodingString2(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTF16LEncodingString2);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgVersionString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgVersionString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgValidityDomain(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgValidityDomain);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgWin1252EncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgWin1252EncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLChEncodingString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLChEncodingString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDOMMsgDomain(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDOMMsgDomain);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringSpace(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringSpace);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringHTab(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringHTab);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringCR(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringCR);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringLF(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringLF);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringSpaceU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringSpaceU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringHTabU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringHTabU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringCRU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringCRU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLStringLFU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLStringLFU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringSpace(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringSpace);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringHTab(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringHTab);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringLF(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringLF);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringCR(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringCR);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringSpaceU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringSpaceU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringHTabU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringHTabU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringLFU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringLFU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLDeclStringCRU(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLDeclStringCRU);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLNSString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLNSString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLNSColonString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLNSColonString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLNSURIName(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLNSURIName);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLErrDomain(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLErrDomain);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLURIName(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLURIName);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgYesString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgYesString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgZeroLenString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgZeroLenString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDTDEntityString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDTDEntityString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgAmp(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgAmp);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgLT(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgLT);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgGT(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgGT);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgQuot(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgQuot);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgApos(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgApos);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgWFXMLScanner(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgWFXMLScanner);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIGXMLScanner(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIGXMLScanner);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSGXMLScanner(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSGXMLScanner);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDGXMLScanner(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDGXMLScanner);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgArrayIndexOutOfBoundsException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgArrayIndexOutOfBoundsException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEmptyStackException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEmptyStackException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIllegalArgumentException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIllegalArgumentException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgInvalidCastException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgInvalidCastException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgIOException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgIOException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNoSuchElementException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNoSuchElementException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNullPointerException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNullPointerException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXMLPlatformUtilsException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXMLPlatformUtilsException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgRuntimeException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgRuntimeException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgTranscodingException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgTranscodingException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUnexpectedEOFException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUnexpectedEOFException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUnsupportedEncodingException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUnsupportedEncodingException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgUTFDataFormatException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgUTFDataFormatException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNetAccessorException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNetAccessorException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgMalformedURLException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgMalformedURLException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNumberFormatException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNumberFormatException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgParseException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgParseException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgInvalidDatatypeFacetException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgInvalidDatatypeFacetException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgInvalidDatatypeValueException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgInvalidDatatypeValueException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSchemaDateTimeException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSchemaDateTimeException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXPathException_Name(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXPathException_Name);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNegINFString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNegINFString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNegZeroString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNegZeroString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgPosZeroString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgPosZeroString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgPosINFString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgPosINFString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNaNString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNaNString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgEString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgEString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgZeroString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgZeroString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgNullString(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgNullString);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesDynamic(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesDynamic);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesSchema(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesSchema);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesSchemaFullChecking(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesSchemaFullChecking);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesSchemaExternalSchemaLocation(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesSchemaExternalSchemaLocation);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesSchemaExternalNoNameSpaceSchemaLocation(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesSchemaExternalNoNameSpaceSchemaLocation);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesSecurityManager(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesSecurityManager);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesLoadExternalDTD(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesLoadExternalDTD);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesContinueAfterFatalError(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesContinueAfterFatalError);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesValidationErrorAsFatal(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesValidationErrorAsFatal);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesUserAdoptsDOMDocument(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesUserAdoptsDOMDocument);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesCacheGrammarFromParse(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesCacheGrammarFromParse);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesUseCachedGrammarInParse(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesUseCachedGrammarInParse);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesScannerName(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesScannerName);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesCalculateSrcOfs(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesCalculateSrcOfs);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercesStandardUriConformant(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgXercesStandardUriConformant);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSAX2CoreValidation(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSAX2CoreValidation);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSAX2CoreNameSpaces(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSAX2CoreNameSpaces);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgSAX2CoreNameSpacePrefixes(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgSAX2CoreNameSpacePrefixes);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMCanonicalForm(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMCanonicalForm);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMCDATASections(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMCDATASections);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMComments(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMComments);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMCharsetOverridesXMLEncoding(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMCharsetOverridesXMLEncoding);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMDatatypeNormalization(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMDatatypeNormalization);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMEntities(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMEntities);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMInfoset(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMInfoset);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMNamespaces(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMNamespaces);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMNamespaceDeclarations(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMNamespaceDeclarations);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMSupportedMediatypesOnly(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMSupportedMediatypesOnly);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMValidateIfSchema(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMValidateIfSchema);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMValidation(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMValidation);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWhitespaceInElementContent(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWhitespaceInElementContent);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTCanonicalForm(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTCanonicalForm);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTDiscardDefaultContent(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTDiscardDefaultContent);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTEntities(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTEntities);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTFormatPrettyPrint(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTFormatPrettyPrint);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTNormalizeCharacters(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTNormalizeCharacters);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTSplitCdataSections(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTSplitCdataSections);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTValidation(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTValidation);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTWhitespaceInElementContent(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTWhitespaceInElementContent);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgDOMWRTBOM(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    sv_setiv(SvRV(sv),(IV) XERCES_CPP_NAMESPACE::XMLUni::fgDOMWRTBOM);
    return 1;
}

SWIGCLASS_STATIC int _wrap_val_XMLUni_fgXercescDefaultLocale(pTHX_ SV *sv, MAGIC *mg) {
    MAGIC_PPERL
    mg = mg;
    if (XERCES_CPP_NAMESPACE::XMLUni::fgXercescDefaultLocale) {
        sv_setpv((SV*)sv, (char *) XERCES_CPP_NAMESPACE::XMLUni::fgXercescDefaultLocale);
    }else {
        sv_setsv((SV*)sv, &PL_sv_undef);
    }
    return 1;
}

#ifdef PERL_OBJECT
};
#endif

#ifdef __cplusplus
extern "C" {
#endif
XS(_wrap_delete_XMLDeleter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLDeleter *arg1 = (XERCES_CPP_NAMESPACE::XMLDeleter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLDeleter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDeleter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLDeleter. Expected _p_XERCES_CPP_NAMESPACE__XMLDeleter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_Initialize) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        char *arg1 = (char *) (char *)XERCES_CPP_NAMESPACE::XMLUni::fgXercescDefaultLocale ;
        char *arg2 = (char *) (char *)0 ;
        PanicHandler *arg3 = (PanicHandler *) (PanicHandler *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 4)) {
            SWIG_croak("Usage: XMLPlatformUtils_Initialize(locale,nlsHome,panicHandler,memoryManager);");
        }
        if (items > 0) {
            if (!SvOK((SV*) ST(0))) arg1 = 0;
            else arg1 = (char *) SvPV(ST(0), PL_na);
        }
        if (items > 1) {
            if (!SvOK((SV*) ST(1))) arg2 = 0;
            else arg2 = (char *) SvPV(ST(1), PL_na);
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_PanicHandler,0) < 0) {
                    SWIG_croak("Type error in argument 3 of XMLPlatformUtils_Initialize. Expected _p_PanicHandler");
                }
            }
        }
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of XMLPlatformUtils_Initialize. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::Initialize((char const *)arg1,(char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_Terminate) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_Terminate();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::Terminate();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_panic) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PanicHandler::PanicReasons arg1 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_panic(reason);");
        }
        {
            PanicHandler::PanicReasons * argp;
            if (SWIG_ConvertPtr(ST(0),(void **) &argp, SWIGTYPE_p_PanicHandler__PanicReasons,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_panic. Expected _p_PanicHandler__PanicReasons");
            }
            arg1 = *argp;
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::panic(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_curFilePos) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_curFilePos(theFile);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_curFilePos. Expected _FileHandle");
            }
        }
        {
            try {
                result = (unsigned int)XERCES_CPP_NAMESPACE::XMLPlatformUtils::curFilePos(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_closeFile) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_closeFile(theFile);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_closeFile. Expected _FileHandle");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::closeFile(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_fileSize) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_fileSize(theFile);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_fileSize. Expected _FileHandle");
            }
        }
        {
            try {
                result = (unsigned int)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fileSize(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_openFile) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        char *arg1 ;
        FileHandle result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_openFile(fileName);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (char *) SvPV(ST(0), PL_na);
        {
            try {
                result = (FileHandle)XERCES_CPP_NAMESPACE::XMLPlatformUtils::openFile((char const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_FileHandle,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_openFileToWrite__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        char *arg1 ;
        FileHandle result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_openFileToWrite(fileName);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (char *) SvPV(ST(0), PL_na);
        {
            try {
                result = (FileHandle)XERCES_CPP_NAMESPACE::XMLPlatformUtils::openFileToWrite((char const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_FileHandle,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_openFileToWrite__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        FileHandle result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_openFileToWrite(fileName);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (FileHandle)XERCES_CPP_NAMESPACE::XMLPlatformUtils::openFileToWrite((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_FileHandle,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_openFileToWrite) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLPlatformUtils_openFileToWrite__SWIG_1); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLPlatformUtils_openFileToWrite__SWIG_0); return;
        }
    }
    
    croak("No matching function for overloaded 'XMLPlatformUtils_openFileToWrite'");
    XSRETURN(0);
}

XS(_wrap_XMLPlatformUtils_openStdInHandle) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_openStdInHandle();");
        }
        {
            try {
                result = (FileHandle)XERCES_CPP_NAMESPACE::XMLPlatformUtils::openStdInHandle();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_FileHandle,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_readFileBuffer) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) 0 ;
        unsigned int arg2 ;
        XMLByte *arg3 = (XMLByte *) (XMLByte *)0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLPlatformUtils_readFileBuffer(theFile,toRead,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_readFileBuffer. Expected _FileHandle");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        if (!SvOK((SV*) ST(2))) arg3 = 0;
        else arg3 = (XMLByte *) SvPV(ST(2), PL_na);
        {
            try {
                result = (unsigned int)XERCES_CPP_NAMESPACE::XMLPlatformUtils::readFileBuffer(arg1,arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_writeBufferToFile) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) (FileHandle)0 ;
        long arg2 ;
        XMLByte *arg3 = (XMLByte *) (XMLByte *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLPlatformUtils_writeBufferToFile(theFile,toWrite,toFlush);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_writeBufferToFile. Expected _FileHandle");
            }
        }
        arg2 = (long) SvIV(ST(1));
        if (!SvOK((SV*) ST(2))) arg3 = 0;
        else arg3 = (XMLByte *) SvPV(ST(2), PL_na);
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::writeBufferToFile(arg1,arg2,(XMLByte const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_resetFile) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        FileHandle arg1 = (FileHandle) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_resetFile(theFile);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_resetFile. Expected _FileHandle");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::resetFile(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_getFullPath) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: XMLPlatformUtils_getFullPath(srcPath,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of XMLPlatformUtils_getFullPath. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XMLCh *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::getFullPath((XMLCh const *)arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_getCurrentDirectory) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemoryManager *arg1 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_getCurrentDirectory(manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 1 of XMLPlatformUtils_getCurrentDirectory. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XMLCh *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::getCurrentDirectory(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_removeDotSlash) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_removeDotSlash(srcPath);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::removeDotSlash(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_removeDotDotSlash) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_removeDotDotSlash(srcPath);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::removeDotDotSlash(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_isRelative) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_isRelative(toCheck);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE::XMLPlatformUtils::isRelative((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_weavePaths) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLPlatformUtils_weavePaths(basePath,relativePath);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::weavePaths((XMLCh const *)arg1,(XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_getCurrentMillis) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        unsigned long result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_getCurrentMillis();");
        }
        {
            try {
                result = (unsigned long)XERCES_CPP_NAMESPACE::XMLPlatformUtils::getCurrentMillis();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_closeMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        void *arg1 = (void *) (void *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_closeMutex(mtxHandle);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_closeMutex. Expected _p_void");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::closeMutex(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_lockMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        void *arg1 = (void *) (void *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_lockMutex(mtxHandle);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_lockMutex. Expected _p_void");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::lockMutex(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_makeMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_makeMutex();");
        }
        {
            try {
                result = (void *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::makeMutex();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_unlockMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        void *arg1 = (void *) (void *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_unlockMutex(mtxHandle);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, 0,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_unlockMutex. Expected _p_void");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::unlockMutex(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_loadMsgSet) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLMsgLoader *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_loadMsgSet(msgDomain);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLMsgLoader *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::loadMsgSet((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLMsgLoader,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_compareAndSwap) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        void **arg1 = (void **) 0 ;
        void *arg2 = (void *) (void *)0 ;
        void *arg3 = (void *) (void *)0 ;
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLPlatformUtils_compareAndSwap(toFill,newValue,toCompare);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_p_void,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_compareAndSwap. Expected _p_p_void");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, 0,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLPlatformUtils_compareAndSwap. Expected _p_void");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, 0,0) < 0) {
                SWIG_croak("Type error in argument 3 of XMLPlatformUtils_compareAndSwap. Expected _p_void");
            }
        }
        {
            try {
                result = (void *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::compareAndSwap(arg1,(void const *)arg2,(void const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_atomicIncrement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int *arg1 = 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_atomicIncrement(location);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_int,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_atomicIncrement. Expected _p_int");
            }
        }
        {
            try {
                result = (int)XERCES_CPP_NAMESPACE::XMLPlatformUtils::atomicIncrement(*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_atomicDecrement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int *arg1 = 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_atomicDecrement(location);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_int,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPlatformUtils_atomicDecrement. Expected _p_int");
            }
        }
        {
            try {
                result = (int)XERCES_CPP_NAMESPACE::XMLPlatformUtils::atomicDecrement(*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_recognizeNEL) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        bool arg1 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_recognizeNEL(state);");
        }
        arg1 = (bool) SvIV(ST(0));
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::recognizeNEL(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_isNELRecognized) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_isNELRecognized();");
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE::XMLPlatformUtils::isNELRecognized();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_strictIANAEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        bool arg1 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_strictIANAEncoding(state);");
        }
        arg1 = (bool) SvIV(ST(0));
        {
            try {
                XERCES_CPP_NAMESPACE::XMLPlatformUtils::strictIANAEncoding(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_isStrictIANAEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLPlatformUtils_isStrictIANAEncoding();");
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE::XMLPlatformUtils::isStrictIANAEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPlatformUtils_alignPointerForNewBlockAllocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        size_t arg1 ;
        size_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLPlatformUtils_alignPointerForNewBlockAllocation(ptrSize);");
        }
        arg1 = (size_t) SvUV(ST(0));
        {
            try {
                result = XERCES_CPP_NAMESPACE::XMLPlatformUtils::alignPointerForNewBlockAllocation(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLPlatformUtils) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPlatformUtils *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_XMLPlatformUtils();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLPlatformUtils *)new XERCES_CPP_NAMESPACE::XMLPlatformUtils();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPlatformUtils,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLPlatformUtils) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPlatformUtils *arg1 = (XERCES_CPP_NAMESPACE::XMLPlatformUtils *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLPlatformUtils(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPlatformUtils,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLPlatformUtils. Expected _p_XERCES_CPP_NAMESPACE__XMLPlatformUtils");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_lookupByName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_lookupByName(protoName);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (int)XERCES_CPP_NAMESPACE::XMLURL::lookupByName((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemoryManager *arg1 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 1)) {
            SWIG_croak("Usage: new_XMLURL(manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 1 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_XMLURL(baseURL,relativeURL,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((XMLCh const *)arg1,(XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_XMLURL(baseURL,relativeURL,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((XMLCh const *)arg1,(char const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_3) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: new_XMLURL(baseURL,relativeURL);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((XERCES_CPP_NAMESPACE::XMLURL const &)*arg1,(XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_4) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: new_XMLURL(urlText,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((XMLCh const *)arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_5) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        char *arg1 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: new_XMLURL(urlText,manager);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (char *) SvPV(ST(0), PL_na);
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((char const *)arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL__SWIG_6) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_XMLURL(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLURL *)new XERCES_CPP_NAMESPACE::XMLURL((XERCES_CPP_NAMESPACE::XMLURL const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLURL) {
    dXSARGS;
    
    if ((items >= 0) && (items <= 1)) {
        int _v;
        if (items <= 0) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_0); return;
        }
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_6); return;
        }
    }
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_4); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_4); return;
            }
        }
    }
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_5); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_5); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_3); return;
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_1); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_1); return;
                }
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_2); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLURL__SWIG_2); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_XMLURL'");
    XSRETURN(0);
}

XS(_wrap_delete_XMLURL) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLURL(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_operator_assignment(self,toAssign);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLURL_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLURL &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::XMLURL const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::XMLURL *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_operator_equal_to) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_operator_equal_to(self,toCompare);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLURL_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->operator ==((XERCES_CPP_NAMESPACE::XMLURL const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_operator_not_equal_to) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_operator_not_equal_to(self,toCompare);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_operator_not_equal_to. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLURL_operator_not_equal_to. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->operator !=((XERCES_CPP_NAMESPACE::XMLURL const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getFragment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getFragment(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getFragment. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getFragment();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getHost) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getHost(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getHost. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getHost();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getPassword) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getPassword(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getPassword. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getPassword();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getPath) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getPath(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getPath. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getPath();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getPortNum) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getPortNum(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getPortNum. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getPortNum();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getProtocol) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getProtocol(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getProtocol. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getProtocol();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getProtocolName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getProtocolName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getProtocolName. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getProtocolName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getQuery) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getQuery(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getQuery. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getQuery();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getURLText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getURLText(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getURLText. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getURLText();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getUser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getUser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getUser. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getUser();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_getMemoryManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_getMemoryManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_getMemoryManager. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemoryManager *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->getMemoryManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_setURL__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_setURL(self,urlText);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_setURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setURL((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_setURL__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLURL_setURL(self,baseURL,relativeURL);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_setURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setURL((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_setURL__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *arg2 = 0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLURL_setURL(self,baseURL,relativeURL);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_setURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLURL_setURL. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setURL((XERCES_CPP_NAMESPACE::XMLURL const &)*arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_setURL) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLURL_setURL__SWIG_0); return;
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLURL_setURL__SWIG_2); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLURL_setURL__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'XMLURL_setURL'");
    XSRETURN(0);
}

XS(_wrap_XMLURL_isRelative) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_isRelative(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_isRelative. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->isRelative();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_hasInvalidChar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_hasInvalidChar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_hasInvalidChar. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->hasInvalidChar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_makeNewStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLURL_makeNewStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_makeNewStream. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::XMLURL const *)arg1)->makeNewStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_makeRelativeTo__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_makeRelativeTo(self,baseURLText);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_makeRelativeTo. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->makeRelativeTo((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_makeRelativeTo__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = (XERCES_CPP_NAMESPACE::XMLURL *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLURL_makeRelativeTo(self,baseURL);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLURL_makeRelativeTo. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLURL_makeRelativeTo. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        {
            try {
                (arg1)->makeRelativeTo((XERCES_CPP_NAMESPACE::XMLURL const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLURL_makeRelativeTo) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLURL_makeRelativeTo__SWIG_1); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLURL_makeRelativeTo__SWIG_0); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'XMLURL_makeRelativeTo'");
    XSRETURN(0);
}

XS(_wrap_new_XMLUri__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLUri *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: new_XMLUri(uriSpec,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_XMLUri. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLUri *)new XERCES_CPP_NAMESPACE::XMLUri((XMLCh const *)arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLUri__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) (XERCES_CPP_NAMESPACE::XMLUri *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLUri *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_XMLUri(baseURI,uriSpec,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_XMLUri. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_XMLUri. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLUri *)new XERCES_CPP_NAMESPACE::XMLUri((XERCES_CPP_NAMESPACE::XMLUri const *)arg1,(XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLUri__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::XMLUri *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_XMLUri(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_XMLUri. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLUri *)new XERCES_CPP_NAMESPACE::XMLUri((XERCES_CPP_NAMESPACE::XMLUri const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLUri) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLUri__SWIG_2); return;
        }
    }
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLUri__SWIG_0); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLUri__SWIG_0); return;
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLUri__SWIG_1); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLUri__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_XMLUri'");
    XSRETURN(0);
}

XS(_wrap_XMLUri_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XERCES_CPP_NAMESPACE::XMLUri *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLUri *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_operator_assignment(self,toAssign);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLUri_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLUri &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::XMLUri const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::XMLUri *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLUri) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLUri(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLUri. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getUriText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getUriText(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getUriText. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getUriText();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getScheme(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getScheme. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getScheme();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getUserInfo) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getUserInfo(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getUserInfo. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getUserInfo();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getHost) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getHost(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getHost. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getHost();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getPort) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getPort(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getPort. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getPort();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getPath) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getPath(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getPath. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getPath();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getQueryString) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getQueryString(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getQueryString. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getQueryString();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_getFragment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_getFragment(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_getFragment. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLUri const *)arg1)->getFragment();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setScheme(self,newScheme);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setScheme. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setScheme((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setUserInfo) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setUserInfo(self,newUserInfo);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setUserInfo. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setUserInfo((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setHost) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setHost(self,newHost);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setHost. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setHost((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setPort) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setPort(self,newPort);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setPort. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setPort(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setPath) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setPath(self,newPath);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setPath. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setPath((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setQueryString) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setQueryString(self,newQueryString);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setQueryString. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setQueryString((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_setFragment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUri *arg1 = (XERCES_CPP_NAMESPACE::XMLUri *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLUri_setFragment(self,newFragment);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLUri_setFragment. Expected _p_XERCES_CPP_NAMESPACE__XMLUri");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setFragment((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLUri_isURIString) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLUri_isURIString(uric);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE::XMLUri::isURIString((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_QName__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemoryManager *arg1 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::QName *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 1)) {
            SWIG_croak("Usage: new_QName(manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 1 of new_QName. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::QName *)new XERCES_CPP_NAMESPACE::QName(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_QName__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::QName *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: new_QName(prefix,localPart,uriId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of new_QName. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::QName *)new XERCES_CPP_NAMESPACE::QName((XMLCh const *)arg1,(XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_QName__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg2 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::QName *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_QName(rawName,uriId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_QName. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::QName *)new XERCES_CPP_NAMESPACE::QName((XMLCh const *)arg1,arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_QName__SWIG_3) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::QName *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_QName(qname);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_QName. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::QName *)new XERCES_CPP_NAMESPACE::QName((XERCES_CPP_NAMESPACE::QName const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_QName) {
    dXSARGS;
    
    if ((items >= 0) && (items <= 1)) {
        int _v;
        if (items <= 0) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_0); return;
        }
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_3); return;
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_2); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_2); return;
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_1); return;
                    }
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_QName__SWIG_1); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_QName'");
    XSRETURN(0);
}

XS(_wrap_delete_QName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_QName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_QName. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_getPrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: QName_getPrefix(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_getPrefix. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (XMLCh *)(arg1)->getPrefix();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_getLocalPart) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: QName_getLocalPart(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_getLocalPart. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (XMLCh *)(arg1)->getLocalPart();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_getRawName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: QName_getRawName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_getRawName. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (XMLCh *)(arg1)->getRawName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_getMemoryManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: QName_getMemoryManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_getMemoryManager. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemoryManager *)((XERCES_CPP_NAMESPACE::QName const *)arg1)->getMemoryManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg4 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: QName_setName(self,prefix,localPart,uriId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setName. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (unsigned int) SvUV(ST(3));
        {
            try {
                (arg1)->setName((XMLCh const *)arg2,(XMLCh const *)arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setPrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: QName_setPrefix(self,XMLCh const *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setPrefix. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setPrefix((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setLocalPart) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: QName_setLocalPart(self,XMLCh const *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setLocalPart. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setLocalPart((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setNPrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: QName_setNPrefix(self,XMLCh const *,unsigned int const);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setNPrefix. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->setNPrefix((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setNLocalPart) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: QName_setNLocalPart(self,XMLCh const *,unsigned int const);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setNLocalPart. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->setNLocalPart((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        unsigned int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: QName_setURI(self,unsigned int const);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setURI. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                (arg1)->setURI(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_setValues) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XERCES_CPP_NAMESPACE::QName *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: QName_setValues(self,qname);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_setValues. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 2 of QName_setValues. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                (arg1)->setValues((XERCES_CPP_NAMESPACE::QName const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_operator_equal_to) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        XERCES_CPP_NAMESPACE::QName *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: QName_operator_equal_to(self,XERCES_CPP_NAMESPACE::QName const &);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 2 of QName_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::QName const *)arg1)->operator ==((XERCES_CPP_NAMESPACE::QName const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_QName_cleanUp) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::QName *arg1 = (XERCES_CPP_NAMESPACE::QName *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: QName_cleanUp(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 1 of QName_cleanUp. Expected _p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        {
            try {
                (arg1)->cleanUp();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HexBin_getDataLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HexBin_getDataLength(hexData);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (int)XERCES_CPP_NAMESPACE::HexBin::getDataLength((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HexBin_isArrayByteHex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HexBin_isArrayByteHex(hexData);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE::HexBin::isArrayByteHex((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_HexBin) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HexBin *arg1 = (XERCES_CPP_NAMESPACE::HexBin *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_HexBin(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HexBin,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_HexBin. Expected _p_XERCES_CPP_NAMESPACE__HexBin");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Base64_encode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLByte *arg1 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg2 ;
        unsigned int *arg3 = (unsigned int *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)0 ;
        XMLByte *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: Base64_encode(inputData,inputLength,outputLength,memMgr);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (XMLByte *) SvPV(ST(0), PL_na);
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_unsigned_int,0) < 0) {
                SWIG_croak("Type error in argument 3 of Base64_encode. Expected _p_unsigned_int");
            }
        }
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of Base64_encode. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XMLByte *)XERCES_CPP_NAMESPACE::Base64::encode((XMLByte const *)arg1,arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        if (result) {
            sv_setpv((SV*)ST(argvi++), (char *) result);
        }else {
            sv_setsv((SV*)ST(argvi++), &PL_sv_undef);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Base64_decode__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLByte *arg1 = (XMLByte *) (XMLByte *)0 ;
        unsigned int *arg2 = (unsigned int *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)0 ;
        XMLByte *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: Base64_decode(inputData,outputLength,memMgr);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (XMLByte *) SvPV(ST(0), PL_na);
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_unsigned_int,0) < 0) {
                SWIG_croak("Type error in argument 2 of Base64_decode. Expected _p_unsigned_int");
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of Base64_decode. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XMLByte *)XERCES_CPP_NAMESPACE::Base64::decode((XMLByte const *)arg1,arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        if (result) {
            sv_setpv((SV*)ST(argvi++), (char *) result);
        }else {
            sv_setsv((SV*)ST(argvi++), &PL_sv_undef);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Base64_decode__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        unsigned int *arg2 = (unsigned int *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: Base64_decode(inputData,outputLength,memMgr);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_unsigned_int,0) < 0) {
                SWIG_croak("Type error in argument 2 of Base64_decode. Expected _p_unsigned_int");
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of Base64_decode. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XMLCh *)XERCES_CPP_NAMESPACE::Base64::decode((XMLCh const *)arg1,arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Base64_decode) {
    dXSARGS;
    
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_unsigned_int, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Base64_decode__SWIG_1); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Base64_decode__SWIG_1); return;
                }
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_unsigned_int, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Base64_decode__SWIG_0); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Base64_decode__SWIG_0); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Base64_decode'");
    XSRETURN(0);
}

XS(_wrap_Base64_getDataLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Base64_getDataLength(inputData);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (int)XERCES_CPP_NAMESPACE::Base64::getDataLength((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_Base64) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Base64 *arg1 = (XERCES_CPP_NAMESPACE::Base64 *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_Base64(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Base64,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_Base64. Expected _p_XERCES_CPP_NAMESPACE__Base64");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLExcepts) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLExcepts *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_XMLExcepts();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLExcepts *)new XERCES_CPP_NAMESPACE::XMLExcepts();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLExcepts,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLExcepts) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLExcepts *arg1 = (XERCES_CPP_NAMESPACE::XMLExcepts *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLExcepts(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLExcepts,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLExcepts. Expected _p_XERCES_CPP_NAMESPACE__XMLExcepts");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLException. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getType. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getCode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getCode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getCode. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getCode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getMessage) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getMessage(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getMessage. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getMessage();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getSrcFile) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        char *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getSrcFile(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getSrcFile. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (char *)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getSrcFile();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        if (result) {
            sv_setpv((SV*)ST(argvi++), (char *) result);
        }else {
            sv_setsv((SV*)ST(argvi++), &PL_sv_undef);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getSrcLine) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getSrcLine(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getSrcLine. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getSrcLine();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_getErrorType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLException_getErrorType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_getErrorType. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::XMLException const *)arg1)->getErrorType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_setPosition) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        char *arg2 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLException_setPosition(self,file,line);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_setPosition. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->setPosition((char const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLException *arg1 = (XERCES_CPP_NAMESPACE::XMLException *) 0 ;
        XERCES_CPP_NAMESPACE::XMLException *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLException_operator_assignment(self,toAssign);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLException");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLException &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::XMLException const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::XMLException *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_reinitMsgMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLException_reinitMsgMutex();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLException::reinitMsgMutex();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLException_reinitMsgLoader) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLException_reinitMsgLoader();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLException::reinitMsgLoader();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLValidator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLValidator. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_checkContent) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *arg2 = (XERCES_CPP_NAMESPACE::XMLElementDecl *) (XERCES_CPP_NAMESPACE::XMLElementDecl *)0 ;
        XERCES_CPP_NAMESPACE::QName **arg3 = (XERCES_CPP_NAMESPACE::QName **) (XERCES_CPP_NAMESPACE::QName **)0 ;
        unsigned int arg4 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: XMLValidator_checkContent(self,elemDecl,children,childCount);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_checkContent. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_checkContent. Expected _p_XERCES_CPP_NAMESPACE__XMLElementDecl");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_p_XERCES_CPP_NAMESPACE__QName,0) < 0) {
                SWIG_croak("Type error in argument 3 of XMLValidator_checkContent. Expected _p_p_XERCES_CPP_NAMESPACE__QName");
            }
        }
        arg4 = (unsigned int) SvUV(ST(3));
        {
            try {
                result = (int)(arg1)->checkContent(arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_faultInAttr) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XMLAttr *arg2 = 0 ;
        XMLAttDef *arg3 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLValidator_faultInAttr(self,toFill,attDef);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_faultInAttr. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XMLAttr,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_faultInAttr. Expected _p_XMLAttr");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XMLAttDef,0) < 0) {
                SWIG_croak("Type error in argument 3 of XMLValidator_faultInAttr. Expected _p_XMLAttDef");
            }
        }
        {
            try {
                ((XERCES_CPP_NAMESPACE::XMLValidator const *)arg1)->faultInAttr(*arg2,(XMLAttDef const &)*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_preContentValidation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        bool arg2 ;
        bool arg3 = (bool) false ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: XMLValidator_preContentValidation(self,reuseGrammar,validateDefAttr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_preContentValidation. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        if (items > 2) {
            arg3 = (bool) SvIV(ST(2));
        }
        {
            try {
                (arg1)->preContentValidation(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_postParseValidation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_postParseValidation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_postParseValidation. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                (arg1)->postParseValidation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_reset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_reset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_reset. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                (arg1)->reset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_requiresNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_requiresNamespaces(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_requiresNamespaces. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLValidator const *)arg1)->requiresNamespaces();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_validateAttrValue) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XMLAttDef *arg2 = (XMLAttDef *) 0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        bool arg4 = (bool) false ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *arg5 = (XERCES_CPP_NAMESPACE::XMLElementDecl *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 5)) {
            SWIG_croak("Usage: XMLValidator_validateAttrValue(self,attDef,attrValue,preValidation,elemDecl);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_validateAttrValue. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XMLAttDef,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_validateAttrValue. Expected _p_XMLAttDef");
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        if (items > 4) {
            {
                if (SWIG_ConvertPtr(ST(4), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0) < 0) {
                    SWIG_croak("Type error in argument 5 of XMLValidator_validateAttrValue. Expected _p_XERCES_CPP_NAMESPACE__XMLElementDecl");
                }
            }
        }
        {
            try {
                (arg1)->validateAttrValue((XMLAttDef const *)arg2,(XMLCh const *)arg3,arg4,(XERCES_CPP_NAMESPACE::XMLElementDecl const *)arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_validateElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *arg2 = (XERCES_CPP_NAMESPACE::XMLElementDecl *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLValidator_validateElement(self,elemDef);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_validateElement. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_validateElement. Expected _p_XERCES_CPP_NAMESPACE__XMLElementDecl");
            }
        }
        {
            try {
                (arg1)->validateElement((XERCES_CPP_NAMESPACE::XMLElementDecl const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_getGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_getGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_getGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)((XERCES_CPP_NAMESPACE::XMLValidator const *)arg1)->getGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_setGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *arg2 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLValidator_setGrammar(self,aGrammar);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_setGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_setGrammar. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                (arg1)->setGrammar(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_handlesDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_handlesDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_handlesDTD. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLValidator const *)arg1)->handlesDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_handlesSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLValidator_handlesSchema(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_handlesSchema. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLValidator const *)arg1)->handlesSchema();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_setScannerInfo) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XERCES_CPP_NAMESPACE::XMLScanner *arg2 = (XERCES_CPP_NAMESPACE::XMLScanner *) (XERCES_CPP_NAMESPACE::XMLScanner *)0 ;
        XERCES_CPP_NAMESPACE::ReaderMgr *arg3 = (XERCES_CPP_NAMESPACE::ReaderMgr *) (XERCES_CPP_NAMESPACE::ReaderMgr *)0 ;
        XERCES_CPP_NAMESPACE::XMLBufferMgr *arg4 = (XERCES_CPP_NAMESPACE::XMLBufferMgr *) (XERCES_CPP_NAMESPACE::XMLBufferMgr *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: XMLValidator_setScannerInfo(self,owningScanner,readerMgr,bufMgr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_setScannerInfo. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_setScannerInfo. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ReaderMgr,0) < 0) {
                SWIG_croak("Type error in argument 3 of XMLValidator_setScannerInfo. Expected _p_XERCES_CPP_NAMESPACE__ReaderMgr");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLBufferMgr,0) < 0) {
                SWIG_croak("Type error in argument 4 of XMLValidator_setScannerInfo. Expected _p_XERCES_CPP_NAMESPACE__XMLBufferMgr");
            }
        }
        {
            try {
                (arg1)->setScannerInfo(arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_setErrorReporter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XMLErrorReporter *arg2 = (XMLErrorReporter *) (XMLErrorReporter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLValidator_setErrorReporter(self,errorReporter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_setErrorReporter. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XMLErrorReporter,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_setErrorReporter. Expected _p_XMLErrorReporter");
            }
        }
        {
            try {
                (arg1)->setErrorReporter(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_emitError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        XMLValid::Codes arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLValidator_emitError(self,toEmit);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_emitError. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            XMLValid::Codes * argp;
            if (SWIG_ConvertPtr(ST(1),(void **) &argp, SWIGTYPE_p_XMLValid__Codes,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLValidator_emitError. Expected _p_XMLValid__Codes");
            }
            arg2 = *argp;
        }
        {
            try {
                (arg1)->emitError(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_checkRootElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        unsigned int arg2 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLValidator_checkRootElement(self,unsigned int const);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLValidator_checkRootElement. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (bool)(arg1)->checkRootElement(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_reinitMsgMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLValidator_reinitMsgMutex();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLValidator::reinitMsgMutex();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLValidator_reinitMsgLoader) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLValidator_reinitMsgLoader();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLValidator::reinitMsgLoader();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_SAXException();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXException *)new XERCES_CPP_NAMESPACE::SAXException();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::SAXException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXException(msg);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXException *)new XERCES_CPP_NAMESPACE::SAXException((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::SAXException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXException(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_SAXException. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXException *)new XERCES_CPP_NAMESPACE::SAXException((XERCES_CPP_NAMESPACE::SAXException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXException) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXException__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXException__SWIG_2); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXException__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_SAXException'");
    XSRETURN(0);
}

XS(_wrap_delete_SAXException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = (XERCES_CPP_NAMESPACE::SAXException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAXException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAXException. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXException_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = (XERCES_CPP_NAMESPACE::SAXException *) 0 ;
        XERCES_CPP_NAMESPACE::SAXException *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::SAXException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXException_operator_assignment(self,toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::SAXException &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::SAXException const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::SAXException *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXException_getMessage) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = (XERCES_CPP_NAMESPACE::SAXException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXException_getMessage(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXException_getMessage. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXException const *)arg1)->getMessage();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotSupportedException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXNotSupportedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_SAXNotSupportedException();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotSupportedException *)new XERCES_CPP_NAMESPACE::SAXNotSupportedException();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotSupportedException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::SAXNotSupportedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXNotSupportedException(msg);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotSupportedException *)new XERCES_CPP_NAMESPACE::SAXNotSupportedException((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotSupportedException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::SAXNotSupportedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXNotSupportedException(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_SAXNotSupportedException. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotSupportedException *)new XERCES_CPP_NAMESPACE::SAXNotSupportedException((XERCES_CPP_NAMESPACE::SAXException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotSupportedException) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotSupportedException__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotSupportedException__SWIG_2); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotSupportedException__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_SAXNotSupportedException'");
    XSRETURN(0);
}

XS(_wrap_delete_SAXNotSupportedException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXNotSupportedException *arg1 = (XERCES_CPP_NAMESPACE::SAXNotSupportedException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAXNotSupportedException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAXNotSupportedException. Expected _p_XERCES_CPP_NAMESPACE__SAXNotSupportedException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotRecognizedException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXNotRecognizedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_SAXNotRecognizedException();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotRecognizedException *)new XERCES_CPP_NAMESPACE::SAXNotRecognizedException();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotRecognizedException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::SAXNotRecognizedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXNotRecognizedException(msg);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotRecognizedException *)new XERCES_CPP_NAMESPACE::SAXNotRecognizedException((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotRecognizedException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::SAXNotRecognizedException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXNotRecognizedException(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_SAXNotRecognizedException. Expected _p_XERCES_CPP_NAMESPACE__SAXException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXNotRecognizedException *)new XERCES_CPP_NAMESPACE::SAXNotRecognizedException((XERCES_CPP_NAMESPACE::SAXException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXNotRecognizedException) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotRecognizedException__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotRecognizedException__SWIG_2); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXNotRecognizedException__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_SAXNotRecognizedException'");
    XSRETURN(0);
}

XS(_wrap_delete_SAXNotRecognizedException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXNotRecognizedException *arg1 = (XERCES_CPP_NAMESPACE::SAXNotRecognizedException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAXNotRecognizedException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAXNotRecognizedException. Expected _p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXParseException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: new_SAXParseException(message,locator);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of new_SAXParseException. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXParseException *)new XERCES_CPP_NAMESPACE::SAXParseException((XMLCh const *)arg1,(XERCES_CPP_NAMESPACE::Locator const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXParseException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLSSize_t arg4 ;
        XMLSSize_t arg5 ;
        XERCES_CPP_NAMESPACE::SAXParseException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: new_SAXParseException(message,publicId,systemId,lineNumber,columnNumber);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (XMLSSize_t) SvIV(ST(3));
        arg5 = (XMLSSize_t) SvIV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXParseException *)new XERCES_CPP_NAMESPACE::SAXParseException((XMLCh const *)arg1,(XMLCh const *)arg2,(XMLCh const *)arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXParseException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_SAXParseException(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_SAXParseException. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXParseException *)new XERCES_CPP_NAMESPACE::SAXParseException((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXParseException) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXParseException__SWIG_2); return;
        }
    }
    if (items == 2) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXParseException__SWIG_0); return;
            }
        }
    }
    if (items == 5) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_SAXParseException__SWIG_1); return;
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_SAXParseException'");
    XSRETURN(0);
}

XS(_wrap_delete_SAXParseException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAXParseException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAXParseException. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParseException_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParseException_operator_assignment(self,toAssign);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParseException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParseException_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::SAXParseException &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::SAXParseException *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParseException_getColumnNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParseException_getColumnNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParseException_getColumnNumber. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::SAXParseException const *)arg1)->getColumnNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParseException_getLineNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParseException_getLineNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParseException_getLineNumber. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::SAXParseException const *)arg1)->getLineNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParseException_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParseException_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParseException_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXParseException const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParseException_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParseException *arg1 = (XERCES_CPP_NAMESPACE::SAXParseException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParseException_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParseException_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXParseException const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_ErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ErrorHandler *arg1 = (XERCES_CPP_NAMESPACE::ErrorHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_ErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_ErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ErrorHandler_warning) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ErrorHandler *arg1 = (XERCES_CPP_NAMESPACE::ErrorHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ErrorHandler_warning(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ErrorHandler_warning. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of ErrorHandler_warning. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->warning((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ErrorHandler_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ErrorHandler *arg1 = (XERCES_CPP_NAMESPACE::ErrorHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ErrorHandler_error(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ErrorHandler_error. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of ErrorHandler_error. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->error((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ErrorHandler_fatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ErrorHandler *arg1 = (XERCES_CPP_NAMESPACE::ErrorHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ErrorHandler_fatalError(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ErrorHandler_fatalError. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of ErrorHandler_fatalError. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->fatalError((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ErrorHandler_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ErrorHandler *arg1 = (XERCES_CPP_NAMESPACE::ErrorHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: ErrorHandler_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ErrorHandler_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DTDHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DTDHandler *arg1 = (XERCES_CPP_NAMESPACE::DTDHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DTDHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DTDHandler. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DTDHandler_notationDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DTDHandler *arg1 = (XERCES_CPP_NAMESPACE::DTDHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DTDHandler_notationDecl(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DTDHandler_notationDecl. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->notationDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DTDHandler_unparsedEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DTDHandler *arg1 = (XERCES_CPP_NAMESPACE::DTDHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DTDHandler_unparsedEntityDecl(self,name,publicId,systemId,notationName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DTDHandler_unparsedEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->unparsedEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DTDHandler_resetDocType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DTDHandler *arg1 = (XERCES_CPP_NAMESPACE::DTDHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DTDHandler_resetDocType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DTDHandler_resetDocType. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            try {
                (arg1)->resetDocType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DocumentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DocumentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DocumentHandler_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_characters. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_endDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DocumentHandler_endDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_endDocument. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                (arg1)->endDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_endElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DocumentHandler_endElement(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_endElement. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endElement((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_ignorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DocumentHandler_ignorableWhitespace(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_ignorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->ignorableWhitespace((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DocumentHandler_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_processingInstruction. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_resetDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DocumentHandler_resetDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_resetDocument. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                (arg1)->resetDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DocumentHandler_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of DocumentHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_startDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DocumentHandler_startDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_startDocument. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                (arg1)->startDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DocumentHandler_startElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::DocumentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::AttributeList *arg3 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DocumentHandler_startElement(self,name,attrs);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DocumentHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 3 of DocumentHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            try {
                (arg1)->startElement((XMLCh const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_EntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::EntityResolver *arg1 = (XERCES_CPP_NAMESPACE::EntityResolver *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_EntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_EntityResolver. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_EntityResolver_resolveEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::EntityResolver *arg1 = (XERCES_CPP_NAMESPACE::EntityResolver *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::InputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: EntityResolver_resolveEntity(self,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 1 of EntityResolver_resolveEntity. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::InputSource *)(arg1)->resolveEntity((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_AttributeList) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_AttributeList(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_AttributeList. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AttributeList_getLength(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getLength. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getLength();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getName(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getName. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getName(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getType(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getType. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getType(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getValue__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getValue(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getValue. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getValue(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getType__overload__name) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getType__overload__name(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getType__overload__name. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getType((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getValue__overload__name) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getValue__overload__name(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getValue__overload__name. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getValue((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getValue__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AttributeList *arg1 = (XERCES_CPP_NAMESPACE::AttributeList *) 0 ;
        char *arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AttributeList_getValue(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of AttributeList_getValue. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AttributeList const *)arg1)->getValue((char const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AttributeList_getValue) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AttributeList_getValue__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AttributeList_getValue__SWIG_1); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'AttributeList_getValue'");
    XSRETURN(0);
}

XS(_wrap_HandlerBase_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: HandlerBase_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_characters. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_endDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HandlerBase_endDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_endDocument. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                (arg1)->endDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_endElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: HandlerBase_endElement(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_endElement. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endElement((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_ignorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: HandlerBase_ignorableWhitespace(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_ignorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->ignorableWhitespace((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: HandlerBase_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_processingInstruction. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_resetDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HandlerBase_resetDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_resetDocument. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                (arg1)->resetDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: HandlerBase_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of HandlerBase_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_startDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HandlerBase_startDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_startDocument. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                (arg1)->startDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_startElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::AttributeList *arg3 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: HandlerBase_startElement(self,name,attributes);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_startElement. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList,0) < 0) {
                SWIG_croak("Type error in argument 3 of HandlerBase_startElement. Expected _p_XERCES_CPP_NAMESPACE__AttributeList");
            }
        }
        {
            try {
                (arg1)->startElement((XMLCh const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_resolveEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::InputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: HandlerBase_resolveEntity(self,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_resolveEntity. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::InputSource *)(arg1)->resolveEntity((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: HandlerBase_error(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_error. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of HandlerBase_error. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->error((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_fatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: HandlerBase_fatalError(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_fatalError. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of HandlerBase_fatalError. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->fatalError((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_warning) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: HandlerBase_warning(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_warning. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of HandlerBase_warning. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->warning((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HandlerBase_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_notationDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: HandlerBase_notationDecl(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_notationDecl. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->notationDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_resetDocType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: HandlerBase_resetDocType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_resetDocType. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                (arg1)->resetDocType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_HandlerBase_unparsedEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: HandlerBase_unparsedEntityDecl(self,name,publicId,systemId,notationName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of HandlerBase_unparsedEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->unparsedEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_HandlerBase) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_HandlerBase();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::HandlerBase *)new XERCES_CPP_NAMESPACE::HandlerBase();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_HandlerBase) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::HandlerBase *arg1 = (XERCES_CPP_NAMESPACE::HandlerBase *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_HandlerBase(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_HandlerBase. Expected _p_XERCES_CPP_NAMESPACE__HandlerBase");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_Locator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Locator *arg1 = (XERCES_CPP_NAMESPACE::Locator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_Locator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_Locator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Locator_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Locator *arg1 = (XERCES_CPP_NAMESPACE::Locator *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Locator_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 1 of Locator_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Locator const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Locator_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Locator *arg1 = (XERCES_CPP_NAMESPACE::Locator *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Locator_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 1 of Locator_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Locator const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Locator_getLineNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Locator *arg1 = (XERCES_CPP_NAMESPACE::Locator *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Locator_getLineNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 1 of Locator_getLineNumber. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::Locator const *)arg1)->getLineNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Locator_getColumnNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Locator *arg1 = (XERCES_CPP_NAMESPACE::Locator *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Locator_getColumnNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 1 of Locator_getColumnNumber. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::Locator const *)arg1)->getColumnNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_Attributes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_Attributes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_Attributes. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Attributes_getLength(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getLength. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getLength();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getURI(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getURI. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getURI(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getLocalName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getLocalName(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getLocalName. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getLocalName(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getQName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getQName(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getQName. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getQName(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getType__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getType(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getType. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getType(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getValue__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getValue(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getValue. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getValue(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getIndex__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: Attributes_getIndex(self,uri,localPart);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getIndex. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getIndex((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getIndex__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getIndex(self,qName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getIndex. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getIndex((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getIndex) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getIndex__SWIG_1); return;
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getIndex__SWIG_0); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Attributes_getIndex'");
    XSRETURN(0);
}

XS(_wrap_Attributes_getType__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: Attributes_getType(self,uri,localPart);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getType. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getType((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getType) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getType__SWIG_0); return;
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getType__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Attributes_getType'");
    XSRETURN(0);
}

XS(_wrap_Attributes_getType__overload__name) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getType__overload__name(self,qName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getType__overload__name. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getType((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getValue__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: Attributes_getValue(self,uri,localPart);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getValue. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getValue((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Attributes_getValue) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getValue__SWIG_0); return;
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Attributes_getValue__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Attributes_getValue'");
    XSRETURN(0);
}

XS(_wrap_Attributes_getValue__overload__name) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Attributes *arg1 = (XERCES_CPP_NAMESPACE::Attributes *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Attributes_getValue__overload__name(self,qName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 1 of Attributes_getValue__overload__name. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Attributes const *)arg1)->getValue((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_ContentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_ContentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_ContentHandler. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: ContentHandler_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_characters. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_endDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: ContentHandler_endDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_endDocument. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            try {
                (arg1)->endDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_endElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: ContentHandler_endElement(self,uri,localname,qname);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_endElement. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endElement((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_ignorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: ContentHandler_ignorableWhitespace(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_ignorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->ignorableWhitespace((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: ContentHandler_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_processingInstruction. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ContentHandler_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of ContentHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_startDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: ContentHandler_startDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_startDocument. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            try {
                (arg1)->startDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_startElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Attributes *arg5 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: ContentHandler_startElement(self,uri,localname,qname,attrs);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(4), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 5 of ContentHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            try {
                (arg1)->startElement((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XERCES_CPP_NAMESPACE::Attributes const &)*arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_startPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: ContentHandler_startPrefixMapping(self,prefix,uri);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_startPrefixMapping. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startPrefixMapping((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_endPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ContentHandler_endPrefixMapping(self,prefix);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_endPrefixMapping. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endPrefixMapping((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_ContentHandler_skippedEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::ContentHandler *arg1 = (XERCES_CPP_NAMESPACE::ContentHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: ContentHandler_skippedEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of ContentHandler_skippedEntity. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->skippedEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_LexicalHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_LexicalHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_LexicalHandler. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_comment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: LexicalHandler_comment(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_comment. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->comment((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_endCDATA) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: LexicalHandler_endCDATA(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_endCDATA. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            try {
                (arg1)->endCDATA();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_endDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: LexicalHandler_endDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_endDTD. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            try {
                (arg1)->endDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_endEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: LexicalHandler_endEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_endEntity. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_startCDATA) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: LexicalHandler_startCDATA(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_startCDATA. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            try {
                (arg1)->startCDATA();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_startDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: LexicalHandler_startDTD(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_startDTD. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startDTD((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LexicalHandler_startEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LexicalHandler *arg1 = (XERCES_CPP_NAMESPACE::LexicalHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: LexicalHandler_startEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of LexicalHandler_startEntity. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DeclHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DeclHandler *arg1 = (XERCES_CPP_NAMESPACE::DeclHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DeclHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DeclHandler. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DeclHandler_elementDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DeclHandler *arg1 = (XERCES_CPP_NAMESPACE::DeclHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DeclHandler_elementDecl(self,name,model);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DeclHandler_elementDecl. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->elementDecl((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DeclHandler_attributeDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DeclHandler *arg1 = (XERCES_CPP_NAMESPACE::DeclHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg6 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 6) || (items > 6)) {
            SWIG_croak("Usage: DeclHandler_attributeDecl(self,eName,aName,type,mode,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DeclHandler_attributeDecl. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(5))||SvIOK(ST(5))||SvNOK(ST(5))) {
                arg6 = Perl2XMLString(ST(5));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->attributeDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5,(XMLCh const *)arg6);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DeclHandler_internalEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DeclHandler *arg1 = (XERCES_CPP_NAMESPACE::DeclHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DeclHandler_internalEntityDecl(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DeclHandler_internalEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->internalEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DeclHandler_externalEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DeclHandler *arg1 = (XERCES_CPP_NAMESPACE::DeclHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DeclHandler_externalEntityDecl(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DeclHandler_externalEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->externalEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_characters. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_endDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endDocument. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->endDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DefaultHandler_endElement(self,uri,localname,qname);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endElement. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endElement((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_ignorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_ignorableWhitespace(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_ignorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->ignorableWhitespace((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_processingInstruction. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_resetDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_resetDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_resetDocument. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->resetDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of DefaultHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_startDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startDocument. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->startDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Attributes *arg5 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DefaultHandler_startElement(self,uri,localname,qname,attrs);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(4), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes,0) < 0) {
                SWIG_croak("Type error in argument 5 of DefaultHandler_startElement. Expected _p_XERCES_CPP_NAMESPACE__Attributes");
            }
        }
        {
            try {
                (arg1)->startElement((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XERCES_CPP_NAMESPACE::Attributes const &)*arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_startPrefixMapping(self,prefix,uri);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startPrefixMapping. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startPrefixMapping((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_endPrefixMapping(self,prefix);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endPrefixMapping. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endPrefixMapping((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_skippedEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_skippedEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_skippedEntity. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->skippedEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_resolveEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::InputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_resolveEntity(self,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_resolveEntity. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::InputSource *)(arg1)->resolveEntity((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_error(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_error. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of DefaultHandler_error. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->error((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_fatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_fatalError(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_fatalError. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of DefaultHandler_fatalError. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->fatalError((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_warning) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XERCES_CPP_NAMESPACE::SAXParseException *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_warning(self,exception);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_warning. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException,0) < 0) {
                SWIG_croak("Type error in argument 2 of DefaultHandler_warning. Expected _p_XERCES_CPP_NAMESPACE__SAXParseException");
            }
        }
        {
            try {
                (arg1)->warning((XERCES_CPP_NAMESPACE::SAXParseException const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_notationDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DefaultHandler_notationDecl(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_notationDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->notationDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_resetDocType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_resetDocType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_resetDocType. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->resetDocType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_unparsedEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DefaultHandler_unparsedEntityDecl(self,name,publicId,systemId,notationName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_unparsedEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->unparsedEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_comment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_comment(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_comment. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->comment((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endCDATA) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_endCDATA(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endCDATA. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->endCDATA();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_endDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endDTD. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->endDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_endEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_endEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_endEntity. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startCDATA) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DefaultHandler_startCDATA(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startCDATA. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                (arg1)->startCDATA();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DefaultHandler_startDTD(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startDTD. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startDTD((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_startEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DefaultHandler_startEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_startEntity. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_elementDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_elementDecl(self,name,model);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_elementDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->elementDecl((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_attributeDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg6 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 6) || (items > 6)) {
            SWIG_croak("Usage: DefaultHandler_attributeDecl(self,eName,aName,type,mode,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_attributeDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(5))||SvIOK(ST(5))||SvNOK(ST(5))) {
                arg6 = Perl2XMLString(ST(5));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->attributeDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5,(XMLCh const *)arg6);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_internalEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DefaultHandler_internalEntityDecl(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_internalEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->internalEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DefaultHandler_externalEntityDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DefaultHandler_externalEntityDecl(self,name,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of DefaultHandler_externalEntityDecl. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->externalEntityDecl((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DefaultHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_DefaultHandler();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DefaultHandler *)new XERCES_CPP_NAMESPACE::DefaultHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DefaultHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DefaultHandler *arg1 = (XERCES_CPP_NAMESPACE::DefaultHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DefaultHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DefaultHandler. Expected _p_XERCES_CPP_NAMESPACE__DefaultHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_InputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_InputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_InputSource. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_getEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_getEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_getEncoding. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->getEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_getIssueFatalErrorIfNotFound) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_getIssueFatalErrorIfNotFound(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_getIssueFatalErrorIfNotFound. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->getIssueFatalErrorIfNotFound();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_getMemoryManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: InputSource_getMemoryManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_getMemoryManager. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemoryManager *)((XERCES_CPP_NAMESPACE::InputSource const *)arg1)->getMemoryManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_setEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: InputSource_setEncoding(self,encodingStr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_setEncoding. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_setPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: InputSource_setPublicId(self,publicId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_setPublicId. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setPublicId((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_setSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: InputSource_setSystemId(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_setSystemId. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setSystemId((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_InputSource_setIssueFatalErrorIfNotFound) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::InputSource *arg1 = (XERCES_CPP_NAMESPACE::InputSource *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: InputSource_setIssueFatalErrorIfNotFound(self,flag);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of InputSource_setIssueFatalErrorIfNotFound. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setIssueFatalErrorIfNotFound(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_MemBufInputSource__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLByte *arg1 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        bool arg4 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg5 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::MemBufInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: new_MemBufInputSource(srcDocBytes,byteCount,bufId,adoptBuffer,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                STRLEN len;
                XMLByte *xmlbytes = (XMLByte *)SvPV(ST(0), len);
                arg2 = len;
                arg1 = new XMLByte[len];
                memcpy(arg1, xmlbytes, len);
            }else {
                croak("Type error in argument 2 of new_MemBufInputSource, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg3 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (bool) SvIV(ST(2));
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of new_MemBufInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemBufInputSource *)new XERCES_CPP_NAMESPACE::MemBufInputSource((XMLByte const *)arg1,arg2,(XMLCh const *)arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource,0);
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_MemBufInputSource__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLByte *arg1 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg2 ;
        char *arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg5 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::MemBufInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 4)) {
            SWIG_croak("Usage: new_MemBufInputSource(srcDocBytes,byteCount,bufId,adoptBuffer,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                STRLEN len;
                XMLByte *xmlbytes = (XMLByte *)SvPV(ST(0), len);
                arg2 = len;
                arg1 = new XMLByte[len];
                memcpy(arg1, xmlbytes, len);
            }else {
                croak("Type error in argument 2 of new_MemBufInputSource, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (!SvOK((SV*) ST(1))) arg3 = 0;
        else arg3 = (char *) SvPV(ST(1), PL_na);
        if (items > 2) {
            arg4 = (bool) SvIV(ST(2));
        }
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of new_MemBufInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemBufInputSource *)new XERCES_CPP_NAMESPACE::MemBufInputSource((XMLByte const *)arg1,arg2,(char const *)arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_MemBufInputSource) {
    dXSARGS;
    
    if ((items >= 2) && (items <= 4)) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_MemBufInputSource__SWIG_1); return;
                }
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_MemBufInputSource__SWIG_1); return;
                    }
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_MemBufInputSource__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_MemBufInputSource__SWIG_0); return;
                    }
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_MemBufInputSource__SWIG_0); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_MemBufInputSource'");
    XSRETURN(0);
}

XS(_wrap_delete_MemBufInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufInputSource *arg1 = (XERCES_CPP_NAMESPACE::MemBufInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_MemBufInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_MemBufInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemBufInputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufInputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufInputSource *arg1 = (XERCES_CPP_NAMESPACE::MemBufInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: MemBufInputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufInputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__MemBufInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::MemBufInputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufInputSource_setCopyBufToStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufInputSource *arg1 = (XERCES_CPP_NAMESPACE::MemBufInputSource *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: MemBufInputSource_setCopyBufToStream(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufInputSource_setCopyBufToStream. Expected _p_XERCES_CPP_NAMESPACE__MemBufInputSource");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCopyBufToStream(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_StdInInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemoryManager *arg1 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::StdInInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 1)) {
            SWIG_croak("Usage: new_StdInInputSource(manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 1 of new_StdInInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::StdInInputSource *)new XERCES_CPP_NAMESPACE::StdInInputSource(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdInInputSource,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_StdInInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdInInputSource *arg1 = (XERCES_CPP_NAMESPACE::StdInInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_StdInInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdInInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_StdInInputSource. Expected _p_XERCES_CPP_NAMESPACE__StdInInputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_StdInInputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdInInputSource *arg1 = (XERCES_CPP_NAMESPACE::StdInInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: StdInInputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdInInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of StdInInputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__StdInInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::StdInInputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_LocalFileInputSource__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::LocalFileInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_LocalFileInputSource(basePath,relativePath,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_LocalFileInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::LocalFileInputSource *)new XERCES_CPP_NAMESPACE::LocalFileInputSource((XMLCh const *)arg1,(XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_LocalFileInputSource__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::LocalFileInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: new_LocalFileInputSource(filePath,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_LocalFileInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::LocalFileInputSource *)new XERCES_CPP_NAMESPACE::LocalFileInputSource((XMLCh const *)arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_LocalFileInputSource) {
    dXSARGS;
    
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_LocalFileInputSource__SWIG_1); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_LocalFileInputSource__SWIG_1); return;
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_LocalFileInputSource__SWIG_0); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_LocalFileInputSource__SWIG_0); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_LocalFileInputSource'");
    XSRETURN(0);
}

XS(_wrap_delete_LocalFileInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LocalFileInputSource *arg1 = (XERCES_CPP_NAMESPACE::LocalFileInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_LocalFileInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_LocalFileInputSource. Expected _p_XERCES_CPP_NAMESPACE__LocalFileInputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_LocalFileInputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::LocalFileInputSource *arg1 = (XERCES_CPP_NAMESPACE::LocalFileInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: LocalFileInputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of LocalFileInputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__LocalFileInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::LocalFileInputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLURL *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::URLInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: new_URLInputSource(urlId,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__XMLURL");
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::URLInputSource *)new XERCES_CPP_NAMESPACE::URLInputSource((XERCES_CPP_NAMESPACE::XMLURL const &)*arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::URLInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_URLInputSource(baseId,systemId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::URLInputSource *)new XERCES_CPP_NAMESPACE::URLInputSource((XMLCh const *)arg1,(XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::URLInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: new_URLInputSource(baseId,systemId,publicId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::URLInputSource *)new XERCES_CPP_NAMESPACE::URLInputSource((XMLCh const *)arg1,(XMLCh const *)arg2,(XMLCh const *)arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource__SWIG_3) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg3 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::URLInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: new_URLInputSource(baseId,systemId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        if (items > 2) {
            {
                if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 3 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::URLInputSource *)new XERCES_CPP_NAMESPACE::URLInputSource((XMLCh const *)arg1,(char const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource__SWIG_4) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        char *arg2 ;
        char *arg3 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::URLInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: new_URLInputSource(baseId,systemId,publicId,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        if (!SvOK((SV*) ST(2))) arg3 = 0;
        else arg3 = (char *) SvPV(ST(2), PL_na);
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of new_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::URLInputSource *)new XERCES_CPP_NAMESPACE::URLInputSource((XMLCh const *)arg1,(char const *)arg2,(char const *)arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_URLInputSource) {
    dXSARGS;
    
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_0); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_0); return;
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_1); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_1); return;
                }
            }
        }
    }
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_3); return;
                }
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_3); return;
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_2); return;
                    }
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_2); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_4); return;
                    }
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_URLInputSource__SWIG_4); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_URLInputSource'");
    XSRETURN(0);
}

XS(_wrap_delete_URLInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::URLInputSource *arg1 = (XERCES_CPP_NAMESPACE::URLInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_URLInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_URLInputSource. Expected _p_XERCES_CPP_NAMESPACE__URLInputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_URLInputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::URLInputSource *arg1 = (XERCES_CPP_NAMESPACE::URLInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: URLInputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of URLInputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__URLInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::URLInputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_URLInputSource_urlSrc) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::URLInputSource *arg1 = (XERCES_CPP_NAMESPACE::URLInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::XMLURL *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: URLInputSource_urlSrc(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of URLInputSource_urlSrc. Expected _p_XERCES_CPP_NAMESPACE__URLInputSource");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLURL const &_result_ref = ((XERCES_CPP_NAMESPACE::URLInputSource const *)arg1)->urlSrc();
                    result = (XERCES_CPP_NAMESPACE::XMLURL *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLFormatter__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg3 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) (XERCES_CPP_NAMESPACE::XMLFormatTarget *)0 ;
        int arg4 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::NoEscapes ;
        int arg5 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::UnRep_Fail ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg6 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLFormatter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 6)) {
            SWIG_croak("Usage: new_XMLFormatter(outEncoding,docVersion,target,escapeFlags,unrepFlags,manager);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 3 of new_XMLFormatter. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        if (items > 3) {
            arg4 = (int) SvIV(ST(3));
        }
        if (items > 4) {
            arg5 = (int) SvIV(ST(4));
        }
        if (items > 5) {
            {
                if (SWIG_ConvertPtr(ST(5), (void **) &arg6, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 6 of new_XMLFormatter. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLFormatter *)new XERCES_CPP_NAMESPACE::XMLFormatter((XMLCh const *)arg1,(XMLCh const *)arg2,arg3,(XERCES_CPP_NAMESPACE::XMLFormatter::EscapeFlags )arg4,(XERCES_CPP_NAMESPACE::XMLFormatter::UnRepFlags )arg5,arg6);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0);
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLFormatter__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        char *arg1 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg3 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) (XERCES_CPP_NAMESPACE::XMLFormatTarget *)0 ;
        int arg4 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::NoEscapes ;
        int arg5 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::UnRep_Fail ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg6 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XMLFormatter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 6)) {
            SWIG_croak("Usage: new_XMLFormatter(outEncoding,docVersion,target,escapeFlags,unrepFlags,manager);");
        }
        if (!SvOK((SV*) ST(0))) arg1 = 0;
        else arg1 = (char *) SvPV(ST(0), PL_na);
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 3 of new_XMLFormatter. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        if (items > 3) {
            arg4 = (int) SvIV(ST(3));
        }
        if (items > 4) {
            arg5 = (int) SvIV(ST(4));
        }
        if (items > 5) {
            {
                if (SWIG_ConvertPtr(ST(5), (void **) &arg6, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 6 of new_XMLFormatter. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLFormatter *)new XERCES_CPP_NAMESPACE::XMLFormatter((char const *)arg1,(char const *)arg2,arg3,(XERCES_CPP_NAMESPACE::XMLFormatter::EscapeFlags )arg4,(XERCES_CPP_NAMESPACE::XMLFormatter::UnRepFlags )arg5,arg6);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLFormatter) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 6)) {
        int _v;
        {
            _v = SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        if (items <= 4) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_0); return;
                        }
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            if (items <= 5) {
                                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_0); return;
                            }
                            {
                                void *tmp;
                                if (SWIG_ConvertPtr(ST(5), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                                    _v = 0;
                                }else {
                                    _v = 1;
                                }
                            }
                            if (_v) {
                                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_0); return;
                            }
                        }
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 6)) {
        int _v;
        {
            _v = SvPOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        if (items <= 4) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_1); return;
                        }
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            if (items <= 5) {
                                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_1); return;
                            }
                            {
                                void *tmp;
                                if (SWIG_ConvertPtr(ST(5), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                                    _v = 0;
                                }else {
                                    _v = 1;
                                }
                            }
                            if (_v) {
                                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLFormatter__SWIG_1); return;
                            }
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'new_XMLFormatter'");
    XSRETURN(0);
}

XS(_wrap_delete_XMLFormatter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLFormatter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLFormatter. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_formatBuf) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int arg4 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::DefaultEscape ;
        int arg5 = (int) (int)XERCES_CPP_NAMESPACE::XMLFormatter::DefaultUnRep ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 5)) {
            SWIG_croak("Usage: XMLFormatter_formatBuf(self,toFormat,count,escapeFlags,unrepFlags);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_formatBuf. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        if (items > 3) {
            arg4 = (int) SvIV(ST(3));
        }
        if (items > 4) {
            arg5 = (int) SvIV(ST(4));
        }
        {
            try {
                (arg1)->formatBuf((XMLCh const *)arg2,arg3,(XERCES_CPP_NAMESPACE::XMLFormatter::EscapeFlags )arg4,(XERCES_CPP_NAMESPACE::XMLFormatter::UnRepFlags )arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_writeBOM) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        XMLByte *arg2 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: XMLFormatter_writeBOM(self,toFormat,count);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_writeBOM. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (XMLByte *) SvPV(ST(1), PL_na);
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->writeBOM((XMLByte const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_getEncodingName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLFormatter_getEncodingName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_getEncodingName. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLFormatter const *)arg1)->getEncodingName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_getTranscoder) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        XERCES_CPP_NAMESPACE::XMLTranscoder *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLFormatter_getTranscoder(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_getTranscoder. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLTranscoder *)((XERCES_CPP_NAMESPACE::XMLFormatter const *)arg1)->getTranscoder();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLTranscoder,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_setEscapeFlags) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLFormatter_setEscapeFlags(self,newFlags);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_setEscapeFlags. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setEscapeFlags((XERCES_CPP_NAMESPACE::XMLFormatter::EscapeFlags )arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatter_setUnRepFlags) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatter *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatter *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLFormatter_setUnRepFlags(self,newFlags);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatter_setUnRepFlags. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setUnRepFlags((XERCES_CPP_NAMESPACE::XMLFormatter::UnRepFlags )arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLFormatTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLFormatTarget(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLFormatTarget. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatTarget_writeChars) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) 0 ;
        XMLByte *arg2 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg3 ;
        XERCES_CPP_NAMESPACE::XMLFormatter *arg4 = (XERCES_CPP_NAMESPACE::XMLFormatter *) (XERCES_CPP_NAMESPACE::XMLFormatter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: XMLFormatTarget_writeChars(self,toWrite,count,formatter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (XMLByte *) SvPV(ST(1), PL_na);
        arg3 = (unsigned int) SvUV(ST(2));
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 4 of XMLFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                (arg1)->writeChars((XMLByte const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLFormatTarget_flush) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLFormatTarget_flush(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLFormatTarget_flush. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        {
            try {
                (arg1)->flush();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_MemBufFormatTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int arg1 = (int) 1023 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 2)) {
            SWIG_croak("Usage: new_MemBufFormatTarget(initCapacity,manager);");
        }
        if (items > 0) {
            arg1 = (int) SvIV(ST(0));
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_MemBufFormatTarget. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *)new XERCES_CPP_NAMESPACE::MemBufFormatTarget(arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_MemBufFormatTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_MemBufFormatTarget(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_MemBufFormatTarget. Expected _p_XERCES_CPP_NAMESPACE__MemBufFormatTarget");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufFormatTarget_writeChars) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *) 0 ;
        XMLByte *arg2 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg3 ;
        XERCES_CPP_NAMESPACE::XMLFormatter *arg4 = (XERCES_CPP_NAMESPACE::XMLFormatter *) (XERCES_CPP_NAMESPACE::XMLFormatter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: MemBufFormatTarget_writeChars(self,toWrite,count,formatter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__MemBufFormatTarget");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (XMLByte *) SvPV(ST(1), PL_na);
        arg3 = (unsigned int) SvUV(ST(2));
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 4 of MemBufFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                (arg1)->writeChars((XMLByte const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufFormatTarget_getRawBuffer) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *) 0 ;
        XMLByte *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: MemBufFormatTarget_getRawBuffer(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufFormatTarget_getRawBuffer. Expected _p_XERCES_CPP_NAMESPACE__MemBufFormatTarget");
            }
        }
        {
            try {
                result = (XMLByte *)((XERCES_CPP_NAMESPACE::MemBufFormatTarget const *)arg1)->getRawBuffer();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        if (result) {
            sv_setpv((SV*)ST(argvi++), (char *) result);
        }else {
            sv_setsv((SV*)ST(argvi++), &PL_sv_undef);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufFormatTarget_getLen) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: MemBufFormatTarget_getLen(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufFormatTarget_getLen. Expected _p_XERCES_CPP_NAMESPACE__MemBufFormatTarget");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::MemBufFormatTarget const *)arg1)->getLen();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_MemBufFormatTarget_reset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemBufFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::MemBufFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: MemBufFormatTarget_reset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of MemBufFormatTarget_reset. Expected _p_XERCES_CPP_NAMESPACE__MemBufFormatTarget");
            }
        }
        {
            try {
                (arg1)->reset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_StdOutFormatTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdOutFormatTarget *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_StdOutFormatTarget();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::StdOutFormatTarget *)new XERCES_CPP_NAMESPACE::StdOutFormatTarget();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_StdOutFormatTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdOutFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::StdOutFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_StdOutFormatTarget(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_StdOutFormatTarget. Expected _p_XERCES_CPP_NAMESPACE__StdOutFormatTarget");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_StdOutFormatTarget_writeChars) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdOutFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::StdOutFormatTarget *) 0 ;
        XMLByte *arg2 = (XMLByte *) (XMLByte *)0 ;
        unsigned int arg3 ;
        XERCES_CPP_NAMESPACE::XMLFormatter *arg4 = (XERCES_CPP_NAMESPACE::XMLFormatter *) (XERCES_CPP_NAMESPACE::XMLFormatter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: StdOutFormatTarget_writeChars(self,toWrite,count,formatter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of StdOutFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__StdOutFormatTarget");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (XMLByte *) SvPV(ST(1), PL_na);
        arg3 = (unsigned int) SvUV(ST(2));
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter,0) < 0) {
                SWIG_croak("Type error in argument 4 of StdOutFormatTarget_writeChars. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatter");
            }
        }
        {
            try {
                (arg1)->writeChars((XMLByte const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_StdOutFormatTarget_flush) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::StdOutFormatTarget *arg1 = (XERCES_CPP_NAMESPACE::StdOutFormatTarget *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: StdOutFormatTarget_flush(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 1 of StdOutFormatTarget_flush. Expected _p_XERCES_CPP_NAMESPACE__StdOutFormatTarget");
            }
        }
        {
            try {
                (arg1)->flush();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLUni) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUni *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_XMLUni();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLUni *)new XERCES_CPP_NAMESPACE::XMLUni();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUni,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLUni) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLUni *arg1 = (XERCES_CPP_NAMESPACE::XMLUni *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLUni(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUni,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLUni. Expected _p_XERCES_CPP_NAMESPACE__XMLUni");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLScanner) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLScanner(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLScanner. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getName. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_resolveQName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLBuffer *arg3 = 0 ;
        short arg4 ;
        int *arg5 = 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: XMLScanner_resolveQName(self,qName,prefixBufToFill,mode,prefixColonPos);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_resolveQName. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XMLBuffer,0) < 0) {
                SWIG_croak("Type error in argument 3 of XMLScanner_resolveQName. Expected _p_XMLBuffer");
            }
        }
        arg4 = (short) SvIV(ST(3));
        {
            if (SWIG_ConvertPtr(ST(4), (void **) &arg5, SWIGTYPE_p_int,0) < 0) {
                SWIG_croak("Type error in argument 5 of XMLScanner_resolveQName. Expected _p_int");
            }
        }
        {
            try {
                result = (unsigned int)(arg1)->resolveQName((XMLCh const *)arg2,*arg3,arg4,*arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_scanNext) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_scanNext(self,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_scanNext. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_scanNext. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->scanNext(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_loadGrammar__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XMLScanner_loadGrammar(self,src,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getErrorHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getErrorHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)(arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getErrorHandler) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_getErrorHandler__SWIG_1); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_getErrorHandler__SWIG_0); return;
        }
    }
    
    croak("No matching function for overloaded 'XMLScanner_getErrorHandler'");
    XSRETURN(0);
}

XS(_wrap_XMLScanner_getReaderMgr) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::ReaderMgr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getReaderMgr(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getReaderMgr. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ReaderMgr *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getReaderMgr();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ReaderMgr,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getSrcOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getSrcOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getSrcOffset. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getSrcOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        SecurityManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getSecurityManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (SecurityManager *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getSecurityManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SecurityManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getLoadExternalDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getLoadExternalDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getNormalizeData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getNormalizeData(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getNormalizeData. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getNormalizeData();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_isCachingGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_isCachingGrammarFromParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_isCachingGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->isCachingGrammarFromParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_isUsingCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_isUsingCachedGrammarInParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_isUsingCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->isUsingCachedGrammarInParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getCalculateSrcOfs(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getCalculateSrcOfs();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getRootGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getRootGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getRootGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getRootGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getXMLVersion) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLReader::XMLVersion result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getXMLVersion(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getXMLVersion. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = ((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getXMLVersion();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            XMLReader::XMLVersion * resultobj = new XMLReader::XMLVersion((XMLReader::XMLVersion &)result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) resultobj, SWIGTYPE_p_XMLReader__XMLVersion,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getMemoryManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getMemoryManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getMemoryManager. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::MemoryManager *)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getMemoryManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getEmptyNamespaceId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getEmptyNamespaceId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getEmptyNamespaceId. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getEmptyNamespaceId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getUnknownNamespaceId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getUnknownNamespaceId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getUnknownNamespaceId. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getUnknownNamespaceId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getXMLNamespaceId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getXMLNamespaceId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getXMLNamespaceId. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getXMLNamespaceId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getXMLNSNamespaceId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getXMLNSNamespaceId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getXMLNSNamespaceId. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getXMLNSNamespaceId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_isValidatorFromUser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_isValidatorFromUser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_isValidatorFromUser. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)(arg1)->isValidatorFromUser();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getStandardUriConformant(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getStandardUriConformant();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setDocHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::XMLDocumentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setDocHandler(self,docHandler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                (arg1)->setDocHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setDocTypeHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::DocTypeHandler *arg2 = (XERCES_CPP_NAMESPACE::DocTypeHandler *) (XERCES_CPP_NAMESPACE::DocTypeHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setDocTypeHandler(self,docTypeHandler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setDocTypeHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocTypeHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setDocTypeHandler. Expected _p_XERCES_CPP_NAMESPACE__DocTypeHandler");
            }
        }
        {
            try {
                (arg1)->setDocTypeHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setDoNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setDoNamespaces(self,doNamespaces);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setDoNamespaces. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoNamespaces(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setEntityHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLEntityHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLEntityHandler *) (XERCES_CPP_NAMESPACE::XMLEntityHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setEntityHandler(self,docTypeHandler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setEntityHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLEntityHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setEntityHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLEntityHandler");
            }
        }
        {
            try {
                (arg1)->setEntityHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setErrorReporter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLErrorReporter *arg2 = (XMLErrorReporter *) (XMLErrorReporter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setErrorReporter(self,errHandler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setErrorReporter. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XMLErrorReporter,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setErrorReporter. Expected _p_XMLErrorReporter");
            }
        }
        {
            try {
                (arg1)->setErrorReporter(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::ErrorHandler *) (XERCES_CPP_NAMESPACE::ErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setGrammarResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::GrammarResolver *arg2 = (XERCES_CPP_NAMESPACE::GrammarResolver *) (XERCES_CPP_NAMESPACE::GrammarResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setGrammarResolver(self,grammarResolver);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setGrammarResolver. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__GrammarResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setGrammarResolver. Expected _p_XERCES_CPP_NAMESPACE__GrammarResolver");
            }
        }
        {
            try {
                (arg1)->setGrammarResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setURIStringPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLStringPool *arg2 = (XERCES_CPP_NAMESPACE::XMLStringPool *) (XERCES_CPP_NAMESPACE::XMLStringPool *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setURIStringPool(self,stringPool);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setURIStringPool. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLStringPool,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setURIStringPool. Expected _p_XERCES_CPP_NAMESPACE__XMLStringPool");
            }
        }
        {
            try {
                (arg1)->setURIStringPool(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setExitOnFirstFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setExitOnFirstFatal(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setExitOnFirstFatal. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setExitOnFirstFatal(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setValidationConstraintFatal(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationConstraintFatal(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setValidationScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setValidationScheme(self,newScheme);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setValidationScheme. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationScheme((XERCES_CPP_NAMESPACE::XMLScanner::ValSchemes )arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLValidator *arg2 = (XERCES_CPP_NAMESPACE::XMLValidator *) (XERCES_CPP_NAMESPACE::XMLValidator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setValidator(self,valToAdopt);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setValidator. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setValidator. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                (arg1)->setValidator(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setDoSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setDoSchema(self,doSchema);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setDoSchema. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoSchema(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setValidationSchemaFullChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setValidationSchemaFullChecking(self,schemaFullChecking);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setValidationSchemaFullChecking. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationSchemaFullChecking(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setHasNoDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setHasNoDTD(self,hasNoDTD);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setHasNoDTD. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setHasNoDTD(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_cacheGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_cacheGrammarFromParse(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_cacheGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->cacheGrammarFromParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_useCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_useCachedGrammarInParse(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_useCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->useCachedGrammarInParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setRootElemName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setRootElemName(self,rootElemName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setRootElemName. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setRootElemName(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        SecurityManager *arg2 = (SecurityManager *) (SecurityManager *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setSecurityManager(self,securityManager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SecurityManager,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setSecurityManager. Expected _p_SecurityManager");
            }
        }
        {
            try {
                (arg1)->setSecurityManager(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setLoadExternalDTD(self,loadDTD);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setLoadExternalDTD(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setNormalizeData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setNormalizeData(self,normalizeData);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setNormalizeData. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setNormalizeData(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setCalculateSrcOfs(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCalculateSrcOfs(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setParseSettings) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLScanner *arg2 = (XERCES_CPP_NAMESPACE::XMLScanner *) (XERCES_CPP_NAMESPACE::XMLScanner *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setParseSettings(self,refScanner);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setParseSettings. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_setParseSettings. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                (arg1)->setParseSettings(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setStandardUriConformant(self,newValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setStandardUriConformant(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_incrementErrorCount) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_incrementErrorCount(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_incrementErrorCount. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                (arg1)->incrementErrorCount();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_getDoValidation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLScanner_getDoValidation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_getDoValidation. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XMLScanner const *)arg1)->getDoValidation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_setDoValidation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_setDoValidation(self,validate);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_setDoValidation. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoValidation(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_scanReset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_scanReset(self,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_scanReset. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLScanner_scanReset. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                (arg1)->scanReset(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_checkXMLDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        bool arg2 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLScanner_checkXMLDecl(self,startWithAngle);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_checkXMLDecl. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                result = (bool)(arg1)->checkXMLDecl(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_loadGrammar__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XMLScanner_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_loadGrammar__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLScanner *arg1 = (XERCES_CPP_NAMESPACE::XMLScanner *) 0 ;
        char *arg2 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XMLScanner_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLScanner_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XMLScanner");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_loadGrammar) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_0); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_2); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XMLScanner_loadGrammar__SWIG_2); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'XMLScanner_loadGrammar'");
    XSRETURN(0);
}

XS(_wrap_XMLScanner_reinitScannerMutex) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLScanner_reinitScannerMutex();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLScanner::reinitScannerMutex();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLScanner_reinitMsgLoader) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: XMLScanner_reinitMsgLoader();");
        }
        {
            try {
                XERCES_CPP_NAMESPACE::XMLScanner::reinitMsgLoader();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLPScanToken__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPScanToken *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_XMLPScanToken();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLPScanToken *)new XERCES_CPP_NAMESPACE::XMLPScanToken();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLPScanToken__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_XMLPScanToken(toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_XMLPScanToken. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLPScanToken *)new XERCES_CPP_NAMESPACE::XMLPScanToken((XERCES_CPP_NAMESPACE::XMLPScanToken const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XMLPScanToken) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLPScanToken__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_XMLPScanToken__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_XMLPScanToken'");
    XSRETURN(0);
}

XS(_wrap_delete_XMLPScanToken) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg1 = (XERCES_CPP_NAMESPACE::XMLPScanToken *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLPScanToken(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLPScanToken. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLPScanToken_operator_assignment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg1 = (XERCES_CPP_NAMESPACE::XMLPScanToken *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XMLPScanToken_operator_assignment(self,toCopy);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLPScanToken_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of XMLPScanToken_operator_assignment. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLPScanToken &_result_ref = (arg1)->operator =((XERCES_CPP_NAMESPACE::XMLPScanToken const &)*arg2);
                    result = (XERCES_CPP_NAMESPACE::XMLPScanToken *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_Parser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_Parser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_Parser. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_setEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *arg2 = (XERCES_CPP_NAMESPACE::EntityResolver *) (XERCES_CPP_NAMESPACE::EntityResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_setEntityResolver(self,resolver);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of Parser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            try {
                (arg1)->setEntityResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_setDTDHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XERCES_CPP_NAMESPACE::DTDHandler *arg2 = (XERCES_CPP_NAMESPACE::DTDHandler *) (XERCES_CPP_NAMESPACE::DTDHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_setDTDHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of Parser_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            try {
                (arg1)->setDTDHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_setDocumentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XERCES_CPP_NAMESPACE::DocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::DocumentHandler *) (XERCES_CPP_NAMESPACE::DocumentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_setDocumentHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_setDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of Parser_setDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                (arg1)->setDocumentHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::ErrorHandler *) (XERCES_CPP_NAMESPACE::ErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of Parser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_parse__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_parse(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_parse. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of Parser_parse. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                (arg1)->parse((XERCES_CPP_NAMESPACE::InputSource const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_parse__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_parse. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->parse((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_parse__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Parser *arg1 = (XERCES_CPP_NAMESPACE::Parser *) 0 ;
        char *arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Parser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser,0) < 0) {
                SWIG_croak("Type error in argument 1 of Parser_parse. Expected _p_XERCES_CPP_NAMESPACE__Parser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            try {
                (arg1)->parse((char const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Parser_parse) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Parser_parse__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Parser_parse__SWIG_1); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Parser_parse__SWIG_2); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'Parser_parse'");
    XSRETURN(0);
}

XS(_wrap_delete_XMLDocumentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg1 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLDocumentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLErrorReporter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLErrorReporter *arg1 = (XERCES_CPP_NAMESPACE::XMLErrorReporter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLErrorReporter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLErrorReporter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLErrorReporter. Expected _p_XERCES_CPP_NAMESPACE__XMLErrorReporter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLErrorReporter_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLErrorReporter *arg1 = (XERCES_CPP_NAMESPACE::XMLErrorReporter *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int arg4 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg6 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg7 = (XMLCh *) (XMLCh *)0 ;
        XMLSSize_t arg8 ;
        XMLSSize_t arg9 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 9) || (items > 9)) {
            SWIG_croak("Usage: XMLErrorReporter_error(self,errCode,errDomain,type,errorText,systemId,publicId,lineNum,colNum);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLErrorReporter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLErrorReporter_error. Expected _p_XERCES_CPP_NAMESPACE__XMLErrorReporter");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (int) SvIV(ST(3));
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(5))||SvIOK(ST(5))||SvNOK(ST(5))) {
                arg6 = Perl2XMLString(ST(5));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(6))||SvIOK(ST(6))||SvNOK(ST(6))) {
                arg7 = Perl2XMLString(ST(6));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg8 = (XMLSSize_t) SvIV(ST(7));
        arg9 = (XMLSSize_t) SvIV(ST(8));
        {
            try {
                (arg1)->error(arg2,(XMLCh const *)arg3,(XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrTypes )arg4,(XMLCh const *)arg5,(XMLCh const *)arg6,(XMLCh const *)arg7,arg8,arg9);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLErrorReporter_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLErrorReporter *arg1 = (XERCES_CPP_NAMESPACE::XMLErrorReporter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XMLErrorReporter_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLErrorReporter,0) < 0) {
                SWIG_croak("Type error in argument 1 of XMLErrorReporter_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__XMLErrorReporter");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XMLEntityHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLEntityHandler *arg1 = (XERCES_CPP_NAMESPACE::XMLEntityHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XMLEntityHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLEntityHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XMLEntityHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLEntityHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DocTypeHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DocTypeHandler *arg1 = (XERCES_CPP_NAMESPACE::DocTypeHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DocTypeHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocTypeHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DocTypeHandler. Expected _p_XERCES_CPP_NAMESPACE__DocTypeHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_SAX2XMLReader) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAX2XMLReader(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAX2XMLReader. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getContentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::ContentHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getContentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getContentHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ContentHandler *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getContentHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getDTDHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::DTDHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getDTDHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DTDHandler *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getDTDHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::EntityResolver *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_getFeature(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getFeature. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getFeature((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const SAXNotSupportedException& e)
            {
                makeSAXNotSupportedException(e);
            }
            catch (const SAXNotRecognizedException& e)
            {
                makeSAXNotRecognizedException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getProperty) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_getProperty(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getProperty. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (void *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getProperty((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const SAXNotSupportedException& e)
            {
                makeSAXNotSupportedException(e);
            }
            catch (const SAXNotRecognizedException& e)
            {
                makeSAXNotRecognizedException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setContentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::ContentHandler *arg2 = (XERCES_CPP_NAMESPACE::ContentHandler *) (XERCES_CPP_NAMESPACE::ContentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setContentHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setContentHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setContentHandler. Expected _p_XERCES_CPP_NAMESPACE__ContentHandler");
            }
        }
        {
            try {
                (arg1)->setContentHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setDTDHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::DTDHandler *arg2 = (XERCES_CPP_NAMESPACE::DTDHandler *) (XERCES_CPP_NAMESPACE::DTDHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setDTDHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            try {
                (arg1)->setDTDHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *arg2 = (XERCES_CPP_NAMESPACE::EntityResolver *) (XERCES_CPP_NAMESPACE::EntityResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setEntityResolver(self,resolver);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            try {
                (arg1)->setEntityResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::ErrorHandler *) (XERCES_CPP_NAMESPACE::ErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAX2XMLReader_setFeature(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setFeature. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                (arg1)->setFeature((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const SAXNotSupportedException& e)
            {
                makeSAXNotSupportedException(e);
            }
            catch (const SAXNotRecognizedException& e)
            {
                makeSAXNotRecognizedException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setProperty) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        void *arg3 = (void *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAX2XMLReader_setProperty(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setProperty. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, 0,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAX2XMLReader_setProperty. Expected _p_void");
            }
        }
        {
            try {
                (arg1)->setProperty((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const SAXNotSupportedException& e)
            {
                makeSAXNotSupportedException(e);
            }
            catch (const SAXNotRecognizedException& e)
            {
                makeSAXNotRecognizedException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parse__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_parse(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parse. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_parse. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                (arg1)->parse((XERCES_CPP_NAMESPACE::InputSource const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parse__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parse. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->parse((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parse) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_parse__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_parse__SWIG_1); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'SAX2XMLReader_parse'");
    XSRETURN(0);
}

XS(_wrap_SAX2XMLReader_getDeclarationHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::DeclHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getDeclarationHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getDeclarationHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DeclHandler *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getDeclarationHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getLexicalHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::LexicalHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getLexicalHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getLexicalHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::LexicalHandler *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getLexicalHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setDeclarationHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::DeclHandler *arg2 = (XERCES_CPP_NAMESPACE::DeclHandler *) (XERCES_CPP_NAMESPACE::DeclHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setDeclarationHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setDeclarationHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setDeclarationHandler. Expected _p_XERCES_CPP_NAMESPACE__DeclHandler");
            }
        }
        {
            try {
                (arg1)->setDeclarationHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setLexicalHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::LexicalHandler *arg2 = (XERCES_CPP_NAMESPACE::LexicalHandler *) (XERCES_CPP_NAMESPACE::LexicalHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setLexicalHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setLexicalHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setLexicalHandler. Expected _p_XERCES_CPP_NAMESPACE__LexicalHandler");
            }
        }
        {
            try {
                (arg1)->setLexicalHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLValidator *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getValidator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getValidator. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLValidator *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getValidator();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getErrorCount) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getErrorCount(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getErrorCount. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getErrorCount();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getExitOnFirstFatalError(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getExitOnFirstFatalError();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getValidationConstraintFatal(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getValidationConstraintFatal();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_getGrammar(self,nameSpaceKey);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getGrammar((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getRootGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getRootGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getRootGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getRootGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getURIText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_getURIText(self,uriId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getURIText. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getURIText(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_getSrcOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_getSrcOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_getSrcOffset. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::SAX2XMLReader const *)arg1)->getSrcOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLValidator *arg2 = (XERCES_CPP_NAMESPACE::XMLValidator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setValidator(self,valueToAdopt);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setValidator. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_setValidator. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
            }
        }
        {
            try {
                (arg1)->setValidator(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setExitOnFirstFatalError(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setExitOnFirstFatalError(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_setValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_setValidationConstraintFatal(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_setValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationConstraintFatal(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parseFirst__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAX2XMLReader_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XMLCh const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parseFirst__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAX2XMLReader_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((char const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parseFirst__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAX2XMLReader_parseFirst(self,source,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAX2XMLReader_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parseFirst) {
    dXSARGS;
    
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_parseFirst__SWIG_2); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_parseFirst__SWIG_0); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_parseFirst__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'SAX2XMLReader_parseFirst'");
    XSRETURN(0);
}

XS(_wrap_SAX2XMLReader_parseNext) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_parseNext(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parseNext. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_parseNext. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseNext(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_parseReset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_parseReset(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_parseReset. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_parseReset. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                (arg1)->parseReset(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_loadGrammar__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAX2XMLReader_loadGrammar(self,source,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_loadGrammar__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAX2XMLReader_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_loadGrammar__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        char *arg2 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAX2XMLReader_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_loadGrammar) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_0); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_2); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAX2XMLReader_loadGrammar__SWIG_2); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'SAX2XMLReader_loadGrammar'");
    XSRETURN(0);
}

XS(_wrap_SAX2XMLReader_resetCachedGrammarPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAX2XMLReader_resetCachedGrammarPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_resetCachedGrammarPool. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            try {
                (arg1)->resetCachedGrammarPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_installAdvDocHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::XMLDocumentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_installAdvDocHandler(self,toInstall);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_installAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_installAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                (arg1)->installAdvDocHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAX2XMLReader_removeAdvDocHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAX2XMLReader *arg1 = (XERCES_CPP_NAMESPACE::SAX2XMLReader *) 0 ;
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::XMLDocumentHandler *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAX2XMLReader_removeAdvDocHandler(self,toRemove);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAX2XMLReader_removeAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__SAX2XMLReader");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAX2XMLReader_removeAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                result = (bool)(arg1)->removeAdvDocHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XMLReaderFactory_createXMLReader) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::MemoryManager *arg1 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::SAX2XMLReader *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 1)) {
            SWIG_croak("Usage: XMLReaderFactory_createXMLReader(manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 1 of XMLReaderFactory_createXMLReader. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAX2XMLReader *)XERCES_CPP_NAMESPACE::XMLReaderFactory::createXMLReader(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_SAXParser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) (XERCES_CPP_NAMESPACE::XMLValidator *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::SAXParser *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 2)) {
            SWIG_croak("Usage: new_SAXParser(valToAdopt,manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                    SWIG_croak("Type error in argument 1 of new_SAXParser. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
                }
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_SAXParser. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::SAXParser *)new XERCES_CPP_NAMESPACE::SAXParser(arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_SAXParser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_SAXParser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_SAXParser. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getDocumentHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::DocumentHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getDocumentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DocumentHandler *)(arg1)->getDocumentHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getDocumentHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::DocumentHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getDocumentHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DocumentHandler *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getDocumentHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getDocumentHandler) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getDocumentHandler__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getDocumentHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_getDocumentHandler'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_getEntityResolver__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::EntityResolver *)(arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getEntityResolver__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::EntityResolver *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getEntityResolver) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getEntityResolver__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getEntityResolver__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_getEntityResolver'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_getErrorHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)(arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getErrorHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getErrorHandler) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getErrorHandler__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_getErrorHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_getErrorHandler'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_getValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLValidator *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getValidator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getValidator. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLValidator const &_result_ref = ((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getValidator();
                    result = (XERCES_CPP_NAMESPACE::XMLValidator *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getValidationScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getValidationScheme(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getValidationScheme. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getValidationScheme();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getDoSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getDoSchema(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getDoSchema. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getDoSchema();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getValidationSchemaFullChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getValidationSchemaFullChecking(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getValidationSchemaFullChecking. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getValidationSchemaFullChecking();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getErrorCount) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getErrorCount(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getErrorCount. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getErrorCount();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getDoNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getDoNamespaces(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getDoNamespaces. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getDoNamespaces();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getExitOnFirstFatalError(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getExitOnFirstFatalError();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getValidationConstraintFatal(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getValidationConstraintFatal();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getExternalSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getExternalSchemaLocation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getExternalSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getExternalSchemaLocation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getExternalNoNamespaceSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getExternalNoNamespaceSchemaLocation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getExternalNoNamespaceSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getExternalNoNamespaceSchemaLocation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        SecurityManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getSecurityManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (SecurityManager *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getSecurityManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SecurityManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getLoadExternalDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getLoadExternalDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_isCachingGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_isCachingGrammarFromParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_isCachingGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->isCachingGrammarFromParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_isUsingCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_isUsingCachedGrammarInParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_isUsingCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->isUsingCachedGrammarInParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getCalculateSrcOfs(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getCalculateSrcOfs();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getStandardUriConformant(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getStandardUriConformant();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_getGrammar(self,nameSpaceKey);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getGrammar((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getRootGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getRootGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getRootGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getRootGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getURIText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_getURIText(self,uriId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getURIText. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getURIText(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_getSrcOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_getSrcOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_getSrcOffset. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::SAXParser const *)arg1)->getSrcOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setDoNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setDoNamespaces(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setDoNamespaces. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoNamespaces(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setValidationScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setValidationScheme(self,newScheme);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setValidationScheme. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationScheme((XERCES_CPP_NAMESPACE::SAXParser::ValSchemes )arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setDoSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setDoSchema(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setDoSchema. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoSchema(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setValidationSchemaFullChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setValidationSchemaFullChecking(self,schemaFullChecking);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setValidationSchemaFullChecking. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationSchemaFullChecking(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setExitOnFirstFatalError(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setExitOnFirstFatalError(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setValidationConstraintFatal(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationConstraintFatal(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setExternalSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setExternalSchemaLocation(self,schemaLocation);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setExternalSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setExternalSchemaLocation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setExternalNoNamespaceSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setExternalNoNamespaceSchemaLocation(self,noNamespaceSchemaLocation);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setExternalNoNamespaceSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setExternalNoNamespaceSchemaLocation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        SecurityManager *arg2 = (SecurityManager *) (SecurityManager *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setSecurityManager(self,securityManager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SecurityManager,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_setSecurityManager. Expected _p_SecurityManager");
            }
        }
        {
            try {
                (arg1)->setSecurityManager(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setLoadExternalDTD(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setLoadExternalDTD(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_cacheGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_cacheGrammarFromParse(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_cacheGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->cacheGrammarFromParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_useCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_useCachedGrammarInParse(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_useCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->useCachedGrammarInParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setCalculateSrcOfs(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCalculateSrcOfs(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setStandardUriConformant(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setStandardUriConformant(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_useScanner) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_useScanner(self,scannerName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_useScanner. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->useScanner((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_installAdvDocHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::XMLDocumentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_installAdvDocHandler(self,toInstall);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_installAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_installAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                (arg1)->installAdvDocHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_removeAdvDocHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLDocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::XMLDocumentHandler *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_removeAdvDocHandler(self,toRemove);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_removeAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_removeAdvDocHandler. Expected _p_XERCES_CPP_NAMESPACE__XMLDocumentHandler");
            }
        }
        {
            try {
                result = (bool)(arg1)->removeAdvDocHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parseFirst__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAXParser_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XMLCh const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parseFirst__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAXParser_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((char const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parseFirst__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: SAXParser_parseFirst(self,source,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of SAXParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parseFirst) {
    dXSARGS;
    
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parseFirst__SWIG_2); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parseFirst__SWIG_0); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parseFirst__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_parseFirst'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_parseNext) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_parseNext(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parseNext. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_parseNext. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseNext(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parseReset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_parseReset(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parseReset. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_parseReset. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                (arg1)->parseReset(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_loadGrammar__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAXParser_loadGrammar(self,source,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_loadGrammar__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAXParser_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_loadGrammar__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        char *arg2 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: SAXParser_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_loadGrammar) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_0); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_2); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_loadGrammar__SWIG_2); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_loadGrammar'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_resetCachedGrammarPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_resetCachedGrammarPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_resetCachedGrammarPool. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                (arg1)->resetCachedGrammarPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parse__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_parse(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_parse. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                (arg1)->parse((XERCES_CPP_NAMESPACE::InputSource const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parse__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->parse((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parse__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        char *arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_parse. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            try {
                (arg1)->parse((char const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_parse) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parse__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parse__SWIG_1); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_SAXParser_parse__SWIG_2); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'SAXParser_parse'");
    XSRETURN(0);
}

XS(_wrap_SAXParser_setDocumentHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::DocumentHandler *arg2 = (XERCES_CPP_NAMESPACE::DocumentHandler *) (XERCES_CPP_NAMESPACE::DocumentHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setDocumentHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_setDocumentHandler. Expected _p_XERCES_CPP_NAMESPACE__DocumentHandler");
            }
        }
        {
            try {
                (arg1)->setDocumentHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setDTDHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::DTDHandler *arg2 = (XERCES_CPP_NAMESPACE::DTDHandler *) (XERCES_CPP_NAMESPACE::DTDHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setDTDHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_setDTDHandler. Expected _p_XERCES_CPP_NAMESPACE__DTDHandler");
            }
        }
        {
            try {
                (arg1)->setDTDHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::ErrorHandler *) (XERCES_CPP_NAMESPACE::ErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_setEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *arg2 = (XERCES_CPP_NAMESPACE::EntityResolver *) (XERCES_CPP_NAMESPACE::EntityResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: SAXParser_setEntityResolver(self,resolver);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of SAXParser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            try {
                (arg1)->setEntityResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int arg4 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg6 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg7 = (XMLCh *) (XMLCh *)0 ;
        XMLSSize_t arg8 ;
        XMLSSize_t arg9 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 9) || (items > 9)) {
            SWIG_croak("Usage: SAXParser_error(self,errCode,msgDomain,errType,errorText,systemId,publicId,lineNum,colNum);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_error. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (int) SvIV(ST(3));
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(5))||SvIOK(ST(5))||SvNOK(ST(5))) {
                arg6 = Perl2XMLString(ST(5));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(6))||SvIOK(ST(6))||SvNOK(ST(6))) {
                arg7 = Perl2XMLString(ST(6));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg8 = (XMLSSize_t) SvIV(ST(7));
        arg9 = (XMLSSize_t) SvIV(ST(8));
        {
            try {
                (arg1)->error(arg2,(XMLCh const *)arg3,(XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrTypes )arg4,(XMLCh const *)arg5,(XMLCh const *)arg6,(XMLCh const *)arg7,arg8,arg9);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_SAXParser_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::SAXParser *arg1 = (XERCES_CPP_NAMESPACE::SAXParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: SAXParser_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of SAXParser_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__SAXParser");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_Grammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_Grammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_Grammar. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getGrammarType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Grammar_getGrammarType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getGrammarType. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getGrammarType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getTargetNamespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Grammar_getTargetNamespace(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getTargetNamespace. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getTargetNamespace();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getValidated) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Grammar_getValidated(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getValidated. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getValidated();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_findOrAddElemDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg6 ;
        bool *arg7 = 0 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 7) || (items > 7)) {
            SWIG_croak("Usage: Grammar_findOrAddElemDecl(self,uriId,baseName,prefixName,qName,scope,wasAdded);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_findOrAddElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg6 = (unsigned int) SvUV(ST(5));
        {
            if (SWIG_ConvertPtr(ST(6), (void **) &arg7, SWIGTYPE_p_bool,0) < 0) {
                SWIG_croak("Type error in argument 7 of Grammar_findOrAddElemDecl. Expected _p_bool");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)(arg1)->findOrAddElemDecl(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5,arg6,*arg7);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg5 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: Grammar_getElemId(self,uriId,baseName,qName,scope);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getElemId. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg5 = (unsigned int) SvUV(ST(4));
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getElemId(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemDecl__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg5 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: Grammar_getElemDecl(self,uriId,baseName,qName,scope);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg5 = (unsigned int) SvUV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getElemDecl(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemDecl__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg5 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: Grammar_getElemDecl(self,uriId,baseName,qName,scope);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg5 = (unsigned int) SvUV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)(arg1)->getElemDecl(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemDecl__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_getElemDecl(self,elemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getElemDecl(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemDecl__SWIG_3) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_getElemDecl(self,elemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)(arg1)->getElemDecl(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getElemDecl) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getElemDecl__SWIG_3); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getElemDecl__SWIG_2); return;
            }
        }
    }
    if (items == 5) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        _v = SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getElemDecl__SWIG_1); return;
                        }
                    }
                }
            }
        }
    }
    if (items == 5) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        _v = SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getElemDecl__SWIG_0); return;
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Grammar_getElemDecl'");
    XSRETURN(0);
}

XS(_wrap_Grammar_getNotationDecl__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLNotationDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_getNotationDecl(self,notName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getNotationDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLNotationDecl *)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->getNotationDecl((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XMLNotationDecl,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getNotationDecl__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLNotationDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_getNotationDecl(self,notName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_getNotationDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLNotationDecl *)(arg1)->getNotationDecl((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XMLNotationDecl,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_getNotationDecl) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getNotationDecl__SWIG_1); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_getNotationDecl__SWIG_0); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'Grammar_getNotationDecl'");
    XSRETURN(0);
}

XS(_wrap_Grammar_putElemDecl__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg4 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg6 ;
        bool arg7 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 6) || (items > 7)) {
            SWIG_croak("Usage: Grammar_putElemDecl(self,uriId,baseName,prefixName,qName,scope,notDeclared);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_putElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg6 = (unsigned int) SvUV(ST(5));
        if (items > 6) {
            arg7 = (bool) SvIV(ST(6));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XMLElementDecl *)(arg1)->putElemDecl(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4,(XMLCh const *)arg5,arg6,arg7);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0);
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        {
            delete[] arg5;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_putElemDecl__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        XERCES_CPP_NAMESPACE::XMLElementDecl *arg2 = (XERCES_CPP_NAMESPACE::XMLElementDecl *) (XERCES_CPP_NAMESPACE::XMLElementDecl *)0 ;
        bool arg3 = (bool) (bool)false ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 3)) {
            SWIG_croak("Usage: Grammar_putElemDecl(self,elemDecl,notDeclared);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_putElemDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl,0) < 0) {
                SWIG_croak("Type error in argument 2 of Grammar_putElemDecl. Expected _p_XERCES_CPP_NAMESPACE__XMLElementDecl");
            }
        }
        if (items > 2) {
            arg3 = (bool) SvIV(ST(2));
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->putElemDecl(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_putElemDecl) {
    dXSARGS;
    
    if ((items >= 2) && (items <= 3)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLElementDecl, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                if (items <= 2) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_putElemDecl__SWIG_1); return;
                }
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_putElemDecl__SWIG_1); return;
                }
            }
        }
    }
    if ((items >= 6) && (items <= 7)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvIOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        _v = SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        {
                            _v = SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            {
                                _v = SvIOK(ST(5)) ? 1 : 0;
                            }
                            if (_v) {
                                if (items <= 6) {
                                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_putElemDecl__SWIG_0); return;
                                }
                                {
                                    _v = SvIOK(ST(6)) ? 1 : 0;
                                }
                                if (_v) {
                                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_Grammar_putElemDecl__SWIG_0); return;
                                }
                            }
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'Grammar_putElemDecl'");
    XSRETURN(0);
}

XS(_wrap_Grammar_putNotationDecl) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        XMLNotationDecl *arg2 = (XMLNotationDecl *) (XMLNotationDecl *)0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_putNotationDecl(self,notationDecl);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_putNotationDecl. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XMLNotationDecl,0) < 0) {
                SWIG_croak("Type error in argument 2 of Grammar_putNotationDecl. Expected _p_XMLNotationDecl");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::Grammar const *)arg1)->putNotationDecl(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_setValidated) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: Grammar_setValidated(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_setValidated. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidated(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_Grammar_reset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::Grammar *arg1 = (XERCES_CPP_NAMESPACE::Grammar *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: Grammar_reset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0) < 0) {
                SWIG_croak("Type error in argument 1 of Grammar_reset. Expected _p_XERCES_CPP_NAMESPACE__Grammar");
            }
        }
        {
            try {
                (arg1)->reset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_DOMException();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMException *)new XERCES_CPP_NAMESPACE::DOMException();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        short arg1 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: new_DOMException(code,message);");
        }
        arg1 = (short) SvIV(ST(0));
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMException *)new XERCES_CPP_NAMESPACE::DOMException(arg1,(XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::DOMException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_DOMException(other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_DOMException. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMException *)new XERCES_CPP_NAMESPACE::DOMException((XERCES_CPP_NAMESPACE::DOMException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMException) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMException__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMException__SWIG_2); return;
        }
    }
    if (items == 2) {
        int _v;
        {
            _v = SvIOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMException__SWIG_1); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'new_DOMException'");
    XSRETURN(0);
}

XS(_wrap_delete_DOMException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = (XERCES_CPP_NAMESPACE::DOMException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMException. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMException_code_set) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = (XERCES_CPP_NAMESPACE::DOMException *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMException_code_set(self,code);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMException_code_set. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        arg2 = (int) SvIV(ST(1));
        if (arg1) (arg1)->code = (XERCES_CPP_NAMESPACE::DOMException::ExceptionCode )arg2;
        
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMException_code_get) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = (XERCES_CPP_NAMESPACE::DOMException *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMException_code_get(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMException_code_get. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        result = (int) ((arg1)->code);
        
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMException_msg_set) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = (XERCES_CPP_NAMESPACE::DOMException *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMException_msg_set(self,msg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMException_msg_set. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (arg1) (arg1)->msg = (XMLCh const *)arg2;
        
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMException_msg_get) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMException *arg1 = (XERCES_CPP_NAMESPACE::DOMException *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMException_msg_get(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMException_msg_get. Expected _p_XERCES_CPP_NAMESPACE__DOMException");
            }
        }
        result = (XMLCh *) ((arg1)->msg);
        
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMDocumentRange) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentRange *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentRange *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMDocumentRange(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMDocumentRange. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentRange");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentRange_createRange) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentRange *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMRange *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentRange_createRange(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentRange_createRange. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMRange *)(arg1)->createRange();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMDocumentTraversal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentTraversal *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentTraversal *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMDocumentTraversal(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMDocumentTraversal. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentTraversal_createNodeIterator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentTraversal *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentTraversal *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        unsigned long arg3 ;
        XERCES_CPP_NAMESPACE::DOMNodeFilter *arg4 = (XERCES_CPP_NAMESPACE::DOMNodeFilter *) 0 ;
        bool arg5 ;
        XERCES_CPP_NAMESPACE::DOMNodeIterator *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DOMDocumentTraversal_createNodeIterator(self,root,whatToShow,filter,entityReferenceExpansion);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentTraversal_createNodeIterator. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMDocumentTraversal_createNodeIterator. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg3 = (unsigned long) SvUV(ST(2));
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0) < 0) {
                SWIG_croak("Type error in argument 4 of DOMDocumentTraversal_createNodeIterator. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeFilter");
            }
        }
        arg5 = (bool) SvIV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeIterator *)(arg1)->createNodeIterator(arg2,arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentTraversal_createTreeWalker) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentTraversal *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentTraversal *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        unsigned long arg3 ;
        XERCES_CPP_NAMESPACE::DOMNodeFilter *arg4 = (XERCES_CPP_NAMESPACE::DOMNodeFilter *) 0 ;
        bool arg5 ;
        XERCES_CPP_NAMESPACE::DOMTreeWalker *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DOMDocumentTraversal_createTreeWalker(self,root,whatToShow,filter,entityReferenceExpansion);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentTraversal_createTreeWalker. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMDocumentTraversal_createTreeWalker. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg3 = (unsigned long) SvUV(ST(2));
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0) < 0) {
                SWIG_croak("Type error in argument 4 of DOMDocumentTraversal_createTreeWalker. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeFilter");
            }
        }
        arg5 = (bool) SvIV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMTreeWalker *)(arg1)->createTreeWalker(arg2,arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNodeFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeFilter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNodeFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNodeFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeFilter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeFilter_acceptNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeFilter *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        short result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNodeFilter_acceptNode(self,node);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeFilter_acceptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeFilter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNodeFilter_acceptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (short)((XERCES_CPP_NAMESPACE::DOMNodeFilter const *)arg1)->acceptNode((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNodeIterator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNodeIterator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNodeIterator. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_getRoot) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_getRoot(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_getRoot. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->getRoot();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_getWhatToShow) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        unsigned long result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_getWhatToShow(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_getWhatToShow. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (unsigned long)(arg1)->getWhatToShow();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_getFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeFilter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_getFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_getFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeFilter *)(arg1)->getFilter();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_getExpandEntityReferences) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_getExpandEntityReferences(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_getExpandEntityReferences. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (bool)(arg1)->getExpandEntityReferences();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_nextNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_nextNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_nextNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->nextNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_previousNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_previousNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_previousNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->previousNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_detach) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_detach(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_detach. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                (arg1)->detach();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeIterator_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeIterator *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeIterator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeIterator_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeIterator_release. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeIterator");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMRange) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMRange(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMRange. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getStartContainer) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getStartContainer(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getStartContainer. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getStartContainer();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getStartOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XMLSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getStartOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getStartOffset. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XMLSize_t)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getStartOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getEndContainer) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getEndContainer(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getEndContainer. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getEndContainer();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getEndOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XMLSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getEndOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getEndOffset. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XMLSize_t)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getEndOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getCollapsed) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getCollapsed(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getCollapsed. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getCollapsed();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_getCommonAncestorContainer) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_getCommonAncestorContainer(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_getCommonAncestorContainer. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->getCommonAncestorContainer();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setStart) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLSize_t arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMRange_setStart(self,refNode,offset);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setStart. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setStart. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg3 = (XMLSize_t) SvUV(ST(2));
        {
            try {
                (arg1)->setStart((XERCES_CPP_NAMESPACE::DOMNode const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setEnd) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLSize_t arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMRange_setEnd(self,refNode,offset);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setEnd. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setEnd. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg3 = (XMLSize_t) SvUV(ST(2));
        {
            try {
                (arg1)->setEnd((XERCES_CPP_NAMESPACE::DOMNode const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setStartBefore) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_setStartBefore(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setStartBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setStartBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setStartBefore((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setStartAfter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_setStartAfter(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setStartAfter. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setStartAfter. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setStartAfter((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setEndBefore) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_setEndBefore(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setEndBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setEndBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setEndBefore((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_setEndAfter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_setEndAfter(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_setEndAfter. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_setEndAfter. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setEndAfter((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_collapse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_collapse(self,toStart);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_collapse. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->collapse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_selectNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_selectNode(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_selectNode. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_selectNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->selectNode((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_selectNodeContents) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_selectNodeContents(self,refNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_selectNodeContents. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_selectNodeContents. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->selectNodeContents((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_compareBoundaryPoints) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        int arg2 ;
        XERCES_CPP_NAMESPACE::DOMRange *arg3 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        short result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMRange_compareBoundaryPoints(self,how,sourceRange);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_compareBoundaryPoints. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMRange_compareBoundaryPoints. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (short)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->compareBoundaryPoints((XERCES_CPP_NAMESPACE::DOMRange::CompareHow )arg2,(XERCES_CPP_NAMESPACE::DOMRange const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_deleteContents) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_deleteContents(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_deleteContents. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                (arg1)->deleteContents();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_extractContents) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentFragment *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_extractContents(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_extractContents. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentFragment *)(arg1)->extractContents();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_cloneContents) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentFragment *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_cloneContents(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_cloneContents. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentFragment *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->cloneContents();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_insertNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_insertNode(self,newNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_insertNode. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_insertNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->insertNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_surroundContents) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRange_surroundContents(self,newParent);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_surroundContents. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMRange_surroundContents. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->surroundContents(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_cloneRange) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XERCES_CPP_NAMESPACE::DOMRange *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_cloneRange(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_cloneRange. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMRange *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->cloneRange();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_toString) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_toString(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_toString. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMRange const *)arg1)->toString();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_detach) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_detach(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_detach. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                (arg1)->detach();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRange_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRange *arg1 = (XERCES_CPP_NAMESPACE::DOMRange *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRange_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRange_release. Expected _p_XERCES_CPP_NAMESPACE__DOMRange");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMRangeException__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRangeException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_DOMRangeException();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMRangeException *)new XERCES_CPP_NAMESPACE::DOMRangeException();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMRangeException__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        int arg1 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMRangeException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: new_DOMRangeException(code,message);");
        }
        arg1 = (int) SvIV(ST(0));
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMRangeException *)new XERCES_CPP_NAMESPACE::DOMRangeException((XERCES_CPP_NAMESPACE::DOMRangeException::RangeExceptionCode )arg1,(XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMRangeException__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRangeException *arg1 = 0 ;
        XERCES_CPP_NAMESPACE::DOMRangeException *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_DOMRangeException(other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0) < 0) {
                SWIG_croak("Type error in argument 1 of new_DOMRangeException. Expected _p_XERCES_CPP_NAMESPACE__DOMRangeException");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMRangeException *)new XERCES_CPP_NAMESPACE::DOMRangeException((XERCES_CPP_NAMESPACE::DOMRangeException const &)*arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMRangeException) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMRangeException__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMRangeException__SWIG_2); return;
        }
    }
    if (items == 2) {
        int _v;
        {
            _v = SvIOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_DOMRangeException__SWIG_1); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'new_DOMRangeException'");
    XSRETURN(0);
}

XS(_wrap_delete_DOMRangeException) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRangeException *arg1 = (XERCES_CPP_NAMESPACE::DOMRangeException *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMRangeException(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMRangeException. Expected _p_XERCES_CPP_NAMESPACE__DOMRangeException");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRangeException_code_set) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRangeException *arg1 = (XERCES_CPP_NAMESPACE::DOMRangeException *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMRangeException_code_set(self,code);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRangeException_code_set. Expected _p_XERCES_CPP_NAMESPACE__DOMRangeException");
            }
        }
        arg2 = (int) SvIV(ST(1));
        if (arg1) (arg1)->code = (XERCES_CPP_NAMESPACE::DOMRangeException::RangeExceptionCode )arg2;
        
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMRangeException_code_get) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMRangeException *arg1 = (XERCES_CPP_NAMESPACE::DOMRangeException *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMRangeException_code_get(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMRangeException_code_get. Expected _p_XERCES_CPP_NAMESPACE__DOMRangeException");
            }
        }
        result = (int) ((arg1)->code);
        
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMTreeWalker) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMTreeWalker(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMTreeWalker. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_getRoot) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_getRoot(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_getRoot. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->getRoot();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_getWhatToShow) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        unsigned long result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_getWhatToShow(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_getWhatToShow. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (unsigned long)(arg1)->getWhatToShow();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_getFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeFilter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_getFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_getFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeFilter *)(arg1)->getFilter();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_getExpandEntityReferences) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_getExpandEntityReferences(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_getExpandEntityReferences. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (bool)(arg1)->getExpandEntityReferences();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_getCurrentNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_getCurrentNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_getCurrentNode. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->getCurrentNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_parentNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_parentNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_parentNode. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->parentNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_firstChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_firstChild(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_firstChild. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->firstChild();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_lastChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_lastChild(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_lastChild. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->lastChild();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_previousSibling) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_previousSibling(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_previousSibling. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->previousSibling();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_nextSibling) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_nextSibling(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_nextSibling. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->nextSibling();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_previousNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_previousNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_previousNode. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->previousNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_nextNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_nextNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_nextNode. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->nextNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_setCurrentNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMTreeWalker_setCurrentNode(self,currentNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_setCurrentNode. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMTreeWalker_setCurrentNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setCurrentNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMTreeWalker_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMTreeWalker *arg1 = (XERCES_CPP_NAMESPACE::DOMTreeWalker *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMTreeWalker_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMTreeWalker_release. Expected _p_XERCES_CPP_NAMESPACE__DOMTreeWalker");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getNodeName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getNodeName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getNodeName. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getNodeName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getNodeValue) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getNodeValue(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getNodeValue. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getNodeValue();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getNodeType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        short result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getNodeType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getNodeType. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (short)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getNodeType();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getParentNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getParentNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getParentNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getParentNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getChildNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeList *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getChildNodes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getChildNodes. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeList *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getChildNodes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getFirstChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getFirstChild(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getFirstChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getFirstChild();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getLastChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getLastChild(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getLastChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getLastChild();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getPreviousSibling) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getPreviousSibling(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getPreviousSibling. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getPreviousSibling();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getNextSibling) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getNextSibling(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getNextSibling. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getNextSibling();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getAttributes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getAttributes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getAttributes. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getAttributes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getOwnerDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getOwnerDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getOwnerDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getOwnerDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_cloneNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool arg2 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_cloneNode(self,deep);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_cloneNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->cloneNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_insertBefore) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg3 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNode_insertBefore(self,newChild,refChild);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_insertBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_insertBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMNode_insertBefore. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->insertBefore(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_replaceChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg3 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNode_replaceChild(self,newChild,oldChild);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_replaceChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_replaceChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMNode_replaceChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->replaceChild(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_removeChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_removeChild(self,oldChild);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_removeChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_removeChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->removeChild(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_appendChild) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_appendChild(self,newChild);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_appendChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_appendChild. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->appendChild(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_hasChildNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_hasChildNodes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_hasChildNodes. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->hasChildNodes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_setNodeValue) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_setNodeValue(self,nodeValue);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_setNodeValue. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setNodeValue((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_normalize) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_normalize(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_normalize. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->normalize();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_isSupported) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNode_isSupported(self,feature,version);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_isSupported. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->isSupported((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getNamespaceURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getNamespaceURI(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getNamespaceURI. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getNamespaceURI();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getPrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getPrefix(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getPrefix. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getPrefix();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getLocalName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getLocalName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getLocalName. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getLocalName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_setPrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_setPrefix(self,prefix);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_setPrefix. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setPrefix((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_hasAttributes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_hasAttributes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_hasAttributes. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->hasAttributes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_isSameNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_isSameNode(self,other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_isSameNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_isSameNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->isSameNode((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_isEqualNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_isEqualNode(self,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_isEqualNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_isEqualNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->isEqualNode((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_setUserData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        void *arg3 = (void *) 0 ;
        XERCES_CPP_NAMESPACE::DOMUserDataHandler *arg4 = (XERCES_CPP_NAMESPACE::DOMUserDataHandler *) 0 ;
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMNode_setUserData(self,key,data,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_setUserData. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, 0,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMNode_setUserData. Expected _p_void");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMUserDataHandler,0) < 0) {
                SWIG_croak("Type error in argument 4 of DOMNode_setUserData. Expected _p_XERCES_CPP_NAMESPACE__DOMUserDataHandler");
            }
        }
        {
            try {
                result = (void *)(arg1)->setUserData((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getUserData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_getUserData(self,key);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getUserData. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (void *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getUserData((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getBaseURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getBaseURI(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getBaseURI. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getBaseURI();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_compareTreePosition) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        short result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_compareTreePosition(self,other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_compareTreePosition. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_compareTreePosition. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (short)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->compareTreePosition((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getTextContent) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_getTextContent(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getTextContent. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->getTextContent();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_setTextContent) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_setTextContent(self,textContent);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_setTextContent. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setTextContent((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_lookupNamespacePrefix) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        bool arg3 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNode_lookupNamespacePrefix(self,namespaceURI,useDefault);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_lookupNamespacePrefix. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->lookupNamespacePrefix((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_isDefaultNamespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_isDefaultNamespace(self,namespaceURI);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_isDefaultNamespace. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->isDefaultNamespace((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_lookupNamespaceURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_lookupNamespaceURI(self,prefix);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_lookupNamespaceURI. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNode const *)arg1)->lookupNamespaceURI((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_getInterface) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_getInterface(self,feature);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_getInterface. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->getInterface((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNode_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_release. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_operator_equal_to) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_operator_equal_to(self,other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_operator_equal_to. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE_DOMNode_operator_ee___(arg1,(XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNode_operator_not_equal_to) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNode *arg1 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNode_operator_not_equal_to(self,other);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNode_operator_not_equal_to. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNode_operator_not_equal_to. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)XERCES_CPP_NAMESPACE_DOMNode_operator_Ne___(arg1,(XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMAttr) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMAttr(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMAttr. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_getName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_getName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_getName. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->getName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_getSpecified) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_getSpecified(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_getSpecified. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->getSpecified();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_getValue) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_getValue(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_getValue. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->getValue();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_setValue) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMAttr_setValue(self,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_setValue. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setValue((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_getOwnerElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_getOwnerElement(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_getOwnerElement. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->getOwnerElement();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_isId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_isId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_isId. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->isId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMAttr_getTypeInfo) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMAttr *arg1 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XERCES_CPP_NAMESPACE::DOMTypeInfo *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMAttr_getTypeInfo(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMAttr_getTypeInfo. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMTypeInfo *)((XERCES_CPP_NAMESPACE::DOMAttr const *)arg1)->getTypeInfo();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTypeInfo,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMCharacterData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMCharacterData(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMCharacterData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_getData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMCharacterData_getData(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_getData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMCharacterData const *)arg1)->getData();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_getLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMCharacterData_getLength(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_getLength. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        {
            try {
                result = (XMLSize_t)((XERCES_CPP_NAMESPACE::DOMCharacterData const *)arg1)->getLength();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_substringData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLSize_t arg2 ;
        XMLSize_t arg3 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMCharacterData_substringData(self,offset,count);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_substringData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        arg3 = (XMLSize_t) SvUV(ST(2));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMCharacterData const *)arg1)->substringData(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_appendData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMCharacterData_appendData(self,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_appendData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->appendData((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_insertData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLSize_t arg2 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMCharacterData_insertData(self,offset,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_insertData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->insertData(arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_deleteData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLSize_t arg2 ;
        XMLSize_t arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMCharacterData_deleteData(self,offset,count);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_deleteData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        arg3 = (XMLSize_t) SvUV(ST(2));
        {
            try {
                (arg1)->deleteData(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_replaceData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLSize_t arg2 ;
        XMLSize_t arg3 ;
        XMLCh *arg4 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMCharacterData_replaceData(self,offset,count,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_replaceData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        arg3 = (XMLSize_t) SvUV(ST(2));
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->replaceData(arg2,arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMCharacterData_setData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCharacterData *arg1 = (XERCES_CPP_NAMESPACE::DOMCharacterData *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMCharacterData_setData(self,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMCharacterData_setData. Expected _p_XERCES_CPP_NAMESPACE__DOMCharacterData");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setData((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMText(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMText. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMText_splitText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        XMLSize_t arg2 ;
        XERCES_CPP_NAMESPACE::DOMText *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMText_splitText(self,offset);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMText_splitText. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMText *)(arg1)->splitText(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMText_getIsWhitespaceInElementContent) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMText_getIsWhitespaceInElementContent(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMText_getIsWhitespaceInElementContent. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMText const *)arg1)->getIsWhitespaceInElementContent();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMText_getWholeText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMText_getWholeText(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMText_getWholeText. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        {
            try {
                result = (XMLCh *)(arg1)->getWholeText();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMText_replaceWholeText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMText *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMText_replaceWholeText(self,content);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMText_replaceWholeText. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMText *)(arg1)->replaceWholeText((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMText_isIgnorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMText *arg1 = (XERCES_CPP_NAMESPACE::DOMText *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMText_isIgnorableWhitespace(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMText_isIgnorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__DOMText");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMText const *)arg1)->isIgnorableWhitespace();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMCDATASection) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMCDATASection *arg1 = (XERCES_CPP_NAMESPACE::DOMCDATASection *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMCDATASection(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMCDATASection. Expected _p_XERCES_CPP_NAMESPACE__DOMCDATASection");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMComment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMComment *arg1 = (XERCES_CPP_NAMESPACE::DOMComment *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMComment(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMComment,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMComment. Expected _p_XERCES_CPP_NAMESPACE__DOMComment");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createElement(self,tagName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createElement. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)(arg1)->createElement((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createDocumentFragment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentFragment *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_createDocumentFragment(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createDocumentFragment. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentFragment *)(arg1)->createDocumentFragment();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createTextNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMText *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createTextNode(self,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createTextNode. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMText *)(arg1)->createTextNode((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createComment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMComment *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createComment(self,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createComment. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMComment *)(arg1)->createComment((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMComment,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createCDATASection) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMCDATASection *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createCDATASection(self,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createCDATASection. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMCDATASection *)(arg1)->createCDATASection((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createProcessingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMProcessingInstruction *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMDocument_createProcessingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createProcessingInstruction. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMProcessingInstruction *)(arg1)->createProcessingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createAttribute(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)(arg1)->createAttribute((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createEntityReference) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMEntityReference *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createEntityReference(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createEntityReference. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMEntityReference *)(arg1)->createEntityReference((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityReference,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getDoctype) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentType *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getDoctype(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getDoctype. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentType *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getDoctype();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getImplementation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMImplementation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getImplementation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getImplementation. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementation *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getImplementation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getDocumentElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getDocumentElement(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getDocumentElement. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getDocumentElement();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getElementsByTagName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeList *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_getElementsByTagName(self,tagname);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getElementsByTagName. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeList *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getElementsByTagName((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_importNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        bool arg3 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMDocument_importNode(self,importedNode,deep);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_importNode. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMDocument_importNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->importNode(arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createElementNS__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMDocument_createElementNS(self,namespaceURI,qualifiedName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createElementNS. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)(arg1)->createElementNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMDocument_createAttributeNS(self,namespaceURI,qualifiedName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)(arg1)->createAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getElementsByTagNameNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeList *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMDocument_getElementsByTagNameNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getElementsByTagNameNS. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeList *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getElementsByTagNameNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getElementById) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_getElementById(self,elementId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getElementById. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getElementById((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getActualEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getActualEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getActualEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getActualEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setActualEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setActualEncoding(self,actualEncoding);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setActualEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setActualEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setEncoding(self,encoding);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getStandalone) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getStandalone(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getStandalone. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getStandalone();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setStandalone) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setStandalone(self,standalone);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setStandalone. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setStandalone(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getVersion) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getVersion(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getVersion. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getVersion();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setVersion) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setVersion(self,version);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setVersion. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setVersion((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getDocumentURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getDocumentURI(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getDocumentURI. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getDocumentURI();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setDocumentURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setDocumentURI(self,documentURI);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setDocumentURI. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setDocumentURI((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getStrictErrorChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getStrictErrorChecking(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getStrictErrorChecking. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getStrictErrorChecking();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_setStrictErrorChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_setStrictErrorChecking(self,strictErrorChecking);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_setStrictErrorChecking. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setStrictErrorChecking(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_renameNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XMLCh *arg4 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMDocument_renameNode(self,n,namespaceURI,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_renameNode. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMDocument_renameNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->renameNode(arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_adoptNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_adoptNode(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_adoptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMDocument_adoptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->adoptNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_normalizeDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_normalizeDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_normalizeDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                (arg1)->normalizeDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_getDOMConfiguration) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMConfiguration *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_getDOMConfiguration(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_getDOMConfiguration. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMConfiguration *)((XERCES_CPP_NAMESPACE::DOMDocument const *)arg1)->getDOMConfiguration();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMConfiguration,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMEntity *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createEntity. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMEntity *)(arg1)->createEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createDocumentType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentType *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createDocumentType(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createDocumentType. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentType *)(arg1)->createDocumentType((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createNotation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNotation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMDocument_createNotation(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createNotation. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNotation *)(arg1)->createNotation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createElementNS__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XMLSSize_t arg4 ;
        XMLSSize_t arg5 ;
        XERCES_CPP_NAMESPACE::DOMElement *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 5) || (items > 5)) {
            SWIG_croak("Usage: DOMDocument_createElementNS(self,namespaceURI,qualifiedName,lineNum,columnNum);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_createElementNS. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (XMLSSize_t) SvIV(ST(3));
        arg5 = (XMLSSize_t) SvIV(ST(4));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMElement *)(arg1)->createElementNS((XMLCh const *)arg2,(XMLCh const *)arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_createElementNS) {
    dXSARGS;
    
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMDocument_createElementNS__SWIG_0); return;
                }
            }
        }
    }
    if (items == 5) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        {
                            _v = SvIOK(ST(4)) ? 1 : 0;
                        }
                        if (_v) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMDocument_createElementNS__SWIG_1); return;
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'DOMDocument_createElementNS'");
    XSRETURN(0);
}

XS(_wrap_DOMDocument_toDOMNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_toDOMNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_toDOMNode. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)XERCES_CPP_NAMESPACE_DOMDocument_toDOMNode(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocument_toDOMDocumentTraversal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocument *arg1 = (XERCES_CPP_NAMESPACE::DOMDocument *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentTraversal *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocument_toDOMDocumentTraversal(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocument_toDOMDocumentTraversal. Expected _p_XERCES_CPP_NAMESPACE__DOMDocument");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentTraversal *)XERCES_CPP_NAMESPACE_DOMDocument_toDOMDocumentTraversal(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMDocumentFragment) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentFragment *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentFragment *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMDocumentFragment(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMDocumentFragment. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentFragment");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMDocumentType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMDocumentType(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMDocumentType. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getName. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getEntities) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getEntities(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getEntities. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getEntities();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getNotations) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getNotations(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getNotations. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getNotations();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMDocumentType_getInternalSubset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg1 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMDocumentType_getInternalSubset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMDocumentType_getInternalSubset. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMDocumentType const *)arg1)->getInternalSubset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMImplementationLS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationLS *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationLS *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMImplementationLS(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMImplementationLS. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationLS");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationLS_createDOMBuilder) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationLS *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationLS *) 0 ;
        short arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg4 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::DOMBuilder *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: DOMImplementationLS_createDOMBuilder(self,mode,schemaType,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementationLS_createDOMBuilder. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationLS");
            }
        }
        arg2 = (short) SvIV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        if (items > 3) {
            {
                if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 4 of DOMImplementationLS_createDOMBuilder. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMBuilder *)(arg1)->createDOMBuilder(arg2,(XMLCh const *)arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0);
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationLS_createDOMWriter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationLS *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationLS *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::DOMWriter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: DOMImplementationLS_createDOMWriter(self,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementationLS_createDOMWriter. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationLS");
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of DOMImplementationLS_createDOMWriter. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMWriter *)(arg1)->createDOMWriter(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationLS_createDOMInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationLS *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationLS *) 0 ;
        XERCES_CPP_NAMESPACE::DOMInputSource *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMImplementationLS_createDOMInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementationLS_createDOMInputSource. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationLS");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMInputSource *)(arg1)->createDOMInputSource();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMImplementation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMImplementation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMImplementation. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_hasFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMImplementation_hasFeature(self,feature,version);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementation_hasFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMImplementation const *)arg1)->hasFeature((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_createDocumentType) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XMLCh *arg4 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentType *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMImplementation_createDocumentType(self,qualifiedName,publicId,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementation_createDocumentType. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocumentType *)(arg1)->createDocumentType((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_createDocument__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocumentType *arg4 = (XERCES_CPP_NAMESPACE::DOMDocumentType *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg5 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 5)) {
            SWIG_croak("Usage: DOMImplementation_createDocument(self,namespaceURI,qualifiedName,doctype,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementation_createDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(3), (void **) &arg4, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType,0) < 0) {
                SWIG_croak("Type error in argument 4 of DOMImplementation_createDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMDocumentType");
            }
        }
        if (items > 4) {
            {
                if (SWIG_ConvertPtr(ST(4), (void **) &arg5, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 5 of DOMImplementation_createDocument. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->createDocument((XMLCh const *)arg2,(XMLCh const *)arg3,arg4,arg5);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_getInterface) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMImplementation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMImplementation_getInterface(self,feature);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementation_getInterface. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementation *)(arg1)->getInterface((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_createDocument__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementation *) 0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 2)) {
            SWIG_croak("Usage: DOMImplementation_createDocument(self,manager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementation_createDocument. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementation");
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of DOMImplementation_createDocument. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->createDocument(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementation_createDocument) {
    dXSARGS;
    
    if ((items >= 1) && (items <= 2)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            if (items <= 1) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMImplementation_createDocument__SWIG_1); return;
            }
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMImplementation_createDocument__SWIG_1); return;
            }
        }
    }
    if ((items >= 4) && (items <= 5)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    {
                        void *tmp;
                        if (SWIG_ConvertPtr(ST(3), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType, 0) == -1) {
                            _v = 0;
                        }else {
                            _v = 1;
                        }
                    }
                    if (_v) {
                        if (items <= 4) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMImplementation_createDocument__SWIG_0); return;
                        }
                        {
                            void *tmp;
                            if (SWIG_ConvertPtr(ST(4), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager, 0) == -1) {
                                _v = 0;
                            }else {
                                _v = 1;
                            }
                        }
                        if (_v) {
                            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMImplementation_createDocument__SWIG_0); return;
                        }
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'DOMImplementation_createDocument'");
    XSRETURN(0);
}

XS(_wrap_DOMImplementation_getImplementation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: DOMImplementation_getImplementation();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementation *)XERCES_CPP_NAMESPACE::DOMImplementation::getImplementation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMElement) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMElement(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMElement. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getTagName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMElement_getTagName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getTagName. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getTagName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_getAttribute(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getAttribute((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getAttributeNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_getAttributeNode(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getAttributeNode((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getElementsByTagName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeList *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_getElementsByTagName(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getElementsByTagName. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeList *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getElementsByTagName((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_setAttribute(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setAttribute((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setAttributeNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *arg2 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_setAttributeNode(self,newAttr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMElement_setAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)(arg1)->setAttributeNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_removeAttributeNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *arg2 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_removeAttributeNode(self,oldAttr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_removeAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMElement_removeAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)(arg1)->removeAttributeNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_removeAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_removeAttribute(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_removeAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->removeAttribute((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_getAttributeNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XMLCh *arg4 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMElement_setAttributeNS(self,namespaceURI,qualifiedName,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(3))||SvIOK(ST(3))||SvNOK(ST(3))) {
                arg4 = Perl2XMLString(ST(3));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3,(XMLCh const *)arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        {
            delete[] arg4;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_removeAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_removeAttributeNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_removeAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->removeAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getAttributeNodeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_getAttributeNodeNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getAttributeNodeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getAttributeNodeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setAttributeNodeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *arg2 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_setAttributeNodeNS(self,newAttr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setAttributeNodeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMElement_setAttributeNodeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMAttr *)(arg1)->setAttributeNodeNS(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getElementsByTagNameNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNodeList *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_getElementsByTagNameNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getElementsByTagNameNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNodeList *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getElementsByTagNameNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_hasAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_hasAttribute(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_hasAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->hasAttribute((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_hasAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_hasAttributeNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_hasAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->hasAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setIdAttribute) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_setIdAttribute(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setIdAttribute. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setIdAttribute((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setIdAttributeNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMElement_setIdAttributeNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setIdAttributeNS. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setIdAttributeNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_setIdAttributeNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XERCES_CPP_NAMESPACE::DOMAttr *arg2 = (XERCES_CPP_NAMESPACE::DOMAttr *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMElement_setIdAttributeNode(self,idAttr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_setIdAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMElement_setIdAttributeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMAttr");
            }
        }
        {
            try {
                (arg1)->setIdAttributeNode((XERCES_CPP_NAMESPACE::DOMAttr const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMElement_getTypeInfo) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMElement *arg1 = (XERCES_CPP_NAMESPACE::DOMElement *) 0 ;
        XERCES_CPP_NAMESPACE::DOMTypeInfo *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMElement_getTypeInfo(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMElement_getTypeInfo. Expected _p_XERCES_CPP_NAMESPACE__DOMElement");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMTypeInfo *)((XERCES_CPP_NAMESPACE::DOMElement const *)arg1)->getTypeInfo();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTypeInfo,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMEntity(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMEntity. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getNotationName) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getNotationName(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getNotationName. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getNotationName();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getActualEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getActualEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getActualEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getActualEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_setActualEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMEntity_setActualEncoding(self,actualEncoding);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_setActualEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setActualEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_setEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMEntity_setEncoding(self,encoding);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_setEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_getVersion) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMEntity_getVersion(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_getVersion. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMEntity const *)arg1)->getVersion();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMEntity_setVersion) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntity *arg1 = (XERCES_CPP_NAMESPACE::DOMEntity *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMEntity_setVersion(self,version);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMEntity_setVersion. Expected _p_XERCES_CPP_NAMESPACE__DOMEntity");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setVersion((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMEntityReference) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMEntityReference *arg1 = (XERCES_CPP_NAMESPACE::DOMEntityReference *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMEntityReference(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityReference,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMEntityReference. Expected _p_XERCES_CPP_NAMESPACE__DOMEntityReference");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNamedNodeMap) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNamedNodeMap(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNamedNodeMap. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_setNamedItem) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNamedNodeMap_setNamedItem(self,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_setNamedItem. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNamedNodeMap_setNamedItem. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->setNamedItem(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_item) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLSize_t arg2 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNamedNodeMap_item(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_item. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNamedNodeMap const *)arg1)->item(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_getNamedItem) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNamedNodeMap_getNamedItem(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_getNamedItem. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNamedNodeMap const *)arg1)->getNamedItem((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_getLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNamedNodeMap_getLength(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_getLength. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            try {
                result = (XMLSize_t)((XERCES_CPP_NAMESPACE::DOMNamedNodeMap const *)arg1)->getLength();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_removeNamedItem) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNamedNodeMap_removeNamedItem(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_removeNamedItem. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->removeNamedItem((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_getNamedItemNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNamedNodeMap_getNamedItemNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_getNamedItemNS. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNamedNodeMap const *)arg1)->getNamedItemNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_setNamedItemNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNamedNodeMap_setNamedItemNS(self,arg);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_setNamedItemNS. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMNamedNodeMap_setNamedItemNS. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->setNamedItemNS(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNamedNodeMap_removeNamedItemNS) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNamedNodeMap *arg1 = (XERCES_CPP_NAMESPACE::DOMNamedNodeMap *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XMLCh *arg3 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMNamedNodeMap_removeNamedItemNS(self,namespaceURI,localName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNamedNodeMap_removeNamedItemNS. Expected _p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)(arg1)->removeNamedItemNS((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNodeList) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeList *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeList *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNodeList(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNodeList. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeList");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeList_item) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeList *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeList *) 0 ;
        XMLSize_t arg2 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMNodeList_item(self,index);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeList_item. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeList");
            }
        }
        arg2 = (XMLSize_t) SvUV(ST(1));
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMNodeList const *)arg1)->item(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNodeList_getLength) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNodeList *arg1 = (XERCES_CPP_NAMESPACE::DOMNodeList *) 0 ;
        XMLSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNodeList_getLength(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNodeList_getLength. Expected _p_XERCES_CPP_NAMESPACE__DOMNodeList");
            }
        }
        {
            try {
                result = (XMLSize_t)((XERCES_CPP_NAMESPACE::DOMNodeList const *)arg1)->getLength();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMNotation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNotation *arg1 = (XERCES_CPP_NAMESPACE::DOMNotation *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMNotation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMNotation. Expected _p_XERCES_CPP_NAMESPACE__DOMNotation");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNotation_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNotation *arg1 = (XERCES_CPP_NAMESPACE::DOMNotation *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNotation_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNotation_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__DOMNotation");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNotation const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMNotation_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMNotation *arg1 = (XERCES_CPP_NAMESPACE::DOMNotation *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMNotation_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMNotation_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__DOMNotation");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMNotation const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMProcessingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMProcessingInstruction *arg1 = (XERCES_CPP_NAMESPACE::DOMProcessingInstruction *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMProcessingInstruction(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMProcessingInstruction. Expected _p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMProcessingInstruction_getTarget) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMProcessingInstruction *arg1 = (XERCES_CPP_NAMESPACE::DOMProcessingInstruction *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMProcessingInstruction_getTarget(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMProcessingInstruction_getTarget. Expected _p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMProcessingInstruction const *)arg1)->getTarget();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMProcessingInstruction_getData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMProcessingInstruction *arg1 = (XERCES_CPP_NAMESPACE::DOMProcessingInstruction *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMProcessingInstruction_getData(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMProcessingInstruction_getData. Expected _p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMProcessingInstruction const *)arg1)->getData();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMProcessingInstruction_setData) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMProcessingInstruction *arg1 = (XERCES_CPP_NAMESPACE::DOMProcessingInstruction *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMProcessingInstruction_setData(self,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMProcessingInstruction_setData. Expected _p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setData((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMBuilder) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMBuilder(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMBuilder. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getErrorHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMErrorHandler *)(arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getErrorHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMErrorHandler *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getErrorHandler) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getErrorHandler__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getErrorHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'DOMBuilder_getErrorHandler'");
    XSRETURN(0);
}

XS(_wrap_DOMBuilder_getEntityResolver__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMEntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMEntityResolver *)(arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getEntityResolver__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMEntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMEntityResolver *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getEntityResolver) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getEntityResolver__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getEntityResolver__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'DOMBuilder_getEntityResolver'");
    XSRETURN(0);
}

XS(_wrap_DOMBuilder_getFilter__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMBuilderFilter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMBuilderFilter *)(arg1)->getFilter();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getFilter__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMBuilderFilter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMBuilderFilter *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getFilter();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getFilter) {
    dXSARGS;
    
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getFilter__SWIG_0); return;
        }
    }
    if (items == 1) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_getFilter__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'DOMBuilder_getFilter'");
    XSRETURN(0);
}

XS(_wrap_DOMBuilder_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::DOMErrorHandler *) (XERCES_CPP_NAMESPACE::DOMErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_setEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMEntityResolver *arg2 = (XERCES_CPP_NAMESPACE::DOMEntityResolver *) (XERCES_CPP_NAMESPACE::DOMEntityResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_setEntityResolver(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__DOMEntityResolver");
            }
        }
        {
            try {
                (arg1)->setEntityResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_setFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMBuilderFilter *arg2 = (XERCES_CPP_NAMESPACE::DOMBuilderFilter *) (XERCES_CPP_NAMESPACE::DOMBuilderFilter *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_setFilter(self,filter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_setFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_setFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilderFilter");
            }
        }
        {
            try {
                (arg1)->setFilter(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_setFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMBuilder_setFeature(self,name,state);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_setFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                (arg1)->setFeature((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_getFeature(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getFeature((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_canSetFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool arg3 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMBuilder_canSetFeature(self,name,state);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_canSetFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->canSetFeature((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_parse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMInputSource *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_parse(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_parse. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_parse. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->parse((XERCES_CPP_NAMESPACE::DOMInputSource const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_parseURI__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_parseURI(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_parseURI. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->parseURI((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_parseURI__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_parseURI(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_parseURI. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->parseURI((char const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_parseURI) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_parseURI__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_parseURI__SWIG_1); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'DOMBuilder_parseURI'");
    XSRETURN(0);
}

XS(_wrap_DOMBuilder_parseWithContext) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMInputSource *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg3 = (XERCES_CPP_NAMESPACE::DOMNode *) (XERCES_CPP_NAMESPACE::DOMNode *)0 ;
        short arg4 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 4) || (items > 4)) {
            SWIG_croak("Usage: DOMBuilder_parseWithContext(self,source,contextNode,action);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_parseWithContext. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_parseWithContext. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMBuilder_parseWithContext. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        arg4 = (short) SvIV(ST(3));
        {
            try {
                (arg1)->parseWithContext((XERCES_CPP_NAMESPACE::DOMInputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getProperty) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        void *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_getProperty(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getProperty. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (void *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getProperty((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_void,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_setProperty) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        void *arg3 = (void *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMBuilder_setProperty(self,name,value);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_setProperty. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, 0,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMBuilder_setProperty. Expected _p_void");
            }
        }
        {
            try {
                (arg1)->setProperty((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_release. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_resetDocumentPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_resetDocumentPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_resetDocumentPool. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                (arg1)->resetDocumentPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_loadGrammar__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::DOMInputSource *arg2 = 0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: DOMBuilder_loadGrammar(self,source,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMBuilder_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XERCES_CPP_NAMESPACE::DOMInputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_loadGrammar__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: DOMBuilder_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_loadGrammar__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        char *arg2 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: DOMBuilder_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_loadGrammar) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_0); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_2); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_DOMBuilder_loadGrammar__SWIG_2); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'DOMBuilder_loadGrammar'");
    XSRETURN(0);
}

XS(_wrap_DOMBuilder_getGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_getGrammar(self,nameSpaceKey);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getGrammar((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getRootGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getRootGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getRootGrammar. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getRootGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getURIText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMBuilder_getURIText(self,uriId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getURIText. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getURIText(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_resetCachedGrammarPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_resetCachedGrammarPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_resetCachedGrammarPool. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                (arg1)->resetCachedGrammarPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMBuilder_getSrcOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMBuilder *arg1 = (XERCES_CPP_NAMESPACE::DOMBuilder *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMBuilder_getSrcOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMBuilder_getSrcOffset. Expected _p_XERCES_CPP_NAMESPACE__DOMBuilder");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::DOMBuilder const *)arg1)->getSrcOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationRegistry_getDOMImplementation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XMLCh *arg1 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMImplementation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMImplementationRegistry_getDOMImplementation(features);");
        }
        {
            if (SvPOK(ST(0))||SvIOK(ST(0))||SvNOK(ST(0))) {
                arg1 = Perl2XMLString(ST(0));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementation *)XERCES_CPP_NAMESPACE::DOMImplementationRegistry::getDOMImplementation((XMLCh const *)arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0);
        {
            delete[] arg1;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg1;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationRegistry_addSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationSource *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMImplementationRegistry_addSource(source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementationRegistry_addSource. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationSource");
            }
        }
        {
            try {
                XERCES_CPP_NAMESPACE::DOMImplementationRegistry::addSource(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_DOMImplementationRegistry) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationRegistry *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_DOMImplementationRegistry();");
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementationRegistry *)new XERCES_CPP_NAMESPACE::DOMImplementationRegistry();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMImplementationRegistry) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationRegistry *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationRegistry *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMImplementationRegistry(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMImplementationRegistry. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMImplementationSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationSource *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMImplementationSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMImplementationSource. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMImplementationSource_getDOMImplementation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMImplementationSource *arg1 = (XERCES_CPP_NAMESPACE::DOMImplementationSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) 0 ;
        XERCES_CPP_NAMESPACE::DOMImplementation *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMImplementationSource_getDOMImplementation(self,features);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMImplementationSource_getDOMImplementation. Expected _p_XERCES_CPP_NAMESPACE__DOMImplementationSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMImplementation *)((XERCES_CPP_NAMESPACE::DOMImplementationSource const *)arg1)->getDOMImplementation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMInputSource) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMInputSource(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMInputSource. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_getEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_getEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_getEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->getEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_getPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_getPublicId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_getPublicId. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->getPublicId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_getSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_getSystemId(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_getSystemId. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->getSystemId();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_getBaseURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_getBaseURI(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_getBaseURI. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->getBaseURI();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_setEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMInputSource_setEncoding(self,encodingStr);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_setEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_setPublicId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMInputSource_setPublicId(self,publicId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_setPublicId. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setPublicId((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_setSystemId) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMInputSource_setSystemId(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_setSystemId. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setSystemId((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_setBaseURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMInputSource_setBaseURI(self,baseURI);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_setBaseURI. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setBaseURI((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_makeStream) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        XERCES_CPP_NAMESPACE::BinInputStream *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_makeStream(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_makeStream. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::BinInputStream *)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->makeStream();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__BinInputStream,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_setIssueFatalErrorIfNotFound) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMInputSource_setIssueFatalErrorIfNotFound(self,flag);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_setIssueFatalErrorIfNotFound. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setIssueFatalErrorIfNotFound(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_getIssueFatalErrorIfNotFound) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_getIssueFatalErrorIfNotFound(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_getIssueFatalErrorIfNotFound. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMInputSource const *)arg1)->getIssueFatalErrorIfNotFound();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMInputSource_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMInputSource *arg1 = (XERCES_CPP_NAMESPACE::DOMInputSource *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMInputSource_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMInputSource_release. Expected _p_XERCES_CPP_NAMESPACE__DOMInputSource");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMLocator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMLocator. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_getLineNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMLocator_getLineNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_getLineNumber. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::DOMLocator const *)arg1)->getLineNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_getColumnNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMLocator_getColumnNumber(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_getColumnNumber. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::DOMLocator const *)arg1)->getColumnNumber();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_getOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMLocator_getOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_getOffset. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                result = (XMLSSize_t)((XERCES_CPP_NAMESPACE::DOMLocator const *)arg1)->getOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_getErrorNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMLocator_getErrorNode(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_getErrorNode. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMNode *)((XERCES_CPP_NAMESPACE::DOMLocator const *)arg1)->getErrorNode();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            swig_type_info *ty = SWIG_TypeDynamicCast(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void **) &result);
            ST(argvi) = sv_newmortal();
            SWIG_MakePtr(ST(argvi++), (void *) result, ty,0);
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_getURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMLocator_getURI(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_getURI. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMLocator const *)arg1)->getURI();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_setLineNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMLocator_setLineNumber(self,lineNumber);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_setLineNumber. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        arg2 = (XMLSSize_t) SvIV(ST(1));
        {
            try {
                (arg1)->setLineNumber(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_setColumnNumber) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMLocator_setColumnNumber(self,columnNumber);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_setColumnNumber. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        arg2 = (XMLSSize_t) SvIV(ST(1));
        {
            try {
                (arg1)->setColumnNumber(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_setOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLSSize_t arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMLocator_setOffset(self,offset);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_setOffset. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        arg2 = (XMLSSize_t) SvIV(ST(1));
        {
            try {
                (arg1)->setOffset(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_setErrorNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) (XERCES_CPP_NAMESPACE::DOMNode *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMLocator_setErrorNode(self,errorNode);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_setErrorNode. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMLocator_setErrorNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                (arg1)->setErrorNode(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMLocator_setURI) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMLocator *arg1 = (XERCES_CPP_NAMESPACE::DOMLocator *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMLocator_setURI(self,uri);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMLocator_setURI. Expected _p_XERCES_CPP_NAMESPACE__DOMLocator");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setURI((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMWriter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMWriter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMWriter. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_canSetFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool arg3 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMWriter_canSetFeature(self,featName,state);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_canSetFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->canSetFeature((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_setFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMWriter_setFeature(self,featName,state);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_setFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (bool) SvIV(ST(2));
        {
            try {
                (arg1)->setFeature((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_getFeature) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_getFeature(self,featName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_getFeature. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->getFeature((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_setEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_setEncoding(self,encoding);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_setEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setEncoding((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_setNewLine) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_setNewLine(self,newLine);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_setNewLine. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setNewLine((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XERCES_CPP_NAMESPACE::DOMErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::DOMErrorHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_setErrorHandler(self,errorHandler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMWriter_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_setFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        DOMWriterFilter *arg2 = (DOMWriterFilter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_setFilter(self,filter);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_setFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_DOMWriterFilter,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMWriter_setFilter. Expected _p_DOMWriterFilter");
            }
        }
        {
            try {
                (arg1)->setFilter(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_getEncoding) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriter_getEncoding(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_getEncoding. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->getEncoding();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_getNewLine) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriter_getNewLine(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_getNewLine. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->getNewLine();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_getErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XERCES_CPP_NAMESPACE::DOMErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriter_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMErrorHandler *)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_getFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        DOMWriterFilter *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriter_getFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_getFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                result = (DOMWriterFilter *)((XERCES_CPP_NAMESPACE::DOMWriter const *)arg1)->getFilter();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_DOMWriterFilter,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_writeNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XERCES_CPP_NAMESPACE::XMLFormatTarget *arg2 = (XERCES_CPP_NAMESPACE::XMLFormatTarget *) (XERCES_CPP_NAMESPACE::XMLFormatTarget *)0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: DOMWriter_writeNode(self,destination,nodeToWrite);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_writeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMWriter_writeNode. Expected _p_XERCES_CPP_NAMESPACE__XMLFormatTarget");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 3 of DOMWriter_writeNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (bool)(arg1)->writeNode(arg2,(XERCES_CPP_NAMESPACE::DOMNode const &)*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_writeToString) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriter_writeToString(self,nodeToWrite);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_writeToString. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMWriter_writeToString. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (XMLCh *)(arg1)->writeToString((XERCES_CPP_NAMESPACE::DOMNode const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriter_release) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriter_release(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriter_release. Expected _p_XERCES_CPP_NAMESPACE__DOMWriter");
            }
        }
        {
            try {
                (arg1)->release();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_DOMWriterFilter) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriterFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriterFilter *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_DOMWriterFilter(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_DOMWriterFilter. Expected _p_XERCES_CPP_NAMESPACE__DOMWriterFilter");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriterFilter_acceptNode) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriterFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriterFilter *) 0 ;
        XERCES_CPP_NAMESPACE::DOMNode *arg2 = (XERCES_CPP_NAMESPACE::DOMNode *) 0 ;
        short result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriterFilter_acceptNode(self,node);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriterFilter_acceptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMWriterFilter");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode,0) < 0) {
                SWIG_croak("Type error in argument 2 of DOMWriterFilter_acceptNode. Expected _p_XERCES_CPP_NAMESPACE__DOMNode");
            }
        }
        {
            try {
                result = (short)((XERCES_CPP_NAMESPACE::DOMWriterFilter const *)arg1)->acceptNode((XERCES_CPP_NAMESPACE::DOMNode const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriterFilter_getWhatToShow) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriterFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriterFilter *) 0 ;
        unsigned long result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: DOMWriterFilter_getWhatToShow(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriterFilter_getWhatToShow. Expected _p_XERCES_CPP_NAMESPACE__DOMWriterFilter");
            }
        }
        {
            try {
                result = (unsigned long)((XERCES_CPP_NAMESPACE::DOMWriterFilter const *)arg1)->getWhatToShow();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_DOMWriterFilter_setWhatToShow) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::DOMWriterFilter *arg1 = (XERCES_CPP_NAMESPACE::DOMWriterFilter *) 0 ;
        unsigned long arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: DOMWriterFilter_setWhatToShow(self,toShow);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter,0) < 0) {
                SWIG_croak("Type error in argument 1 of DOMWriterFilter_setWhatToShow. Expected _p_XERCES_CPP_NAMESPACE__DOMWriterFilter");
            }
        }
        arg2 = (unsigned long) SvUV(ST(1));
        {
            try {
                (arg1)->setWhatToShow(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_AbstractDOMParser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_AbstractDOMParser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_AbstractDOMParser. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_reset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_reset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_reset. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                (arg1)->reset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_adoptDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_adoptDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_adoptDocument. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->adoptDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getDocument) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::DOMDocument *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getDocument(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getDocument. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::DOMDocument *)(arg1)->getDocument();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getValidator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLValidator *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getValidator(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getValidator. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                {
                    XERCES_CPP_NAMESPACE::XMLValidator const &_result_ref = ((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getValidator();
                    result = (XERCES_CPP_NAMESPACE::XMLValidator *) &_result_ref;
                }
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getValidationScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getValidationScheme(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getValidationScheme. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getValidationScheme();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getDoSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getDoSchema(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getDoSchema. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getDoSchema();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getValidationSchemaFullChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getValidationSchemaFullChecking(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getValidationSchemaFullChecking. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getValidationSchemaFullChecking();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getErrorCount) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getErrorCount(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getErrorCount. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (int)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getErrorCount();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getDoNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getDoNamespaces(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getDoNamespaces. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getDoNamespaces();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getExitOnFirstFatalError(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getExitOnFirstFatalError();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getValidationConstraintFatal(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getValidationConstraintFatal();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getCreateEntityReferenceNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getCreateEntityReferenceNodes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getCreateEntityReferenceNodes. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getCreateEntityReferenceNodes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getIncludeIgnorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getIncludeIgnorableWhitespace(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getIncludeIgnorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getIncludeIgnorableWhitespace();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getExternalSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getExternalSchemaLocation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getExternalSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getExternalSchemaLocation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getExternalNoNamespaceSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getExternalNoNamespaceSchemaLocation(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getExternalNoNamespaceSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getExternalNoNamespaceSchemaLocation();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        SecurityManager *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getSecurityManager(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (SecurityManager *)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getSecurityManager();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SecurityManager,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getLoadExternalDTD(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getLoadExternalDTD();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getCreateCommentNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getCreateCommentNodes(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getCreateCommentNodes. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getCreateCommentNodes();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getCalculateSrcOfs(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getCalculateSrcOfs();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getStandardUriConformant(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getStandardUriConformant();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setDoNamespaces) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setDoNamespaces(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setDoNamespaces. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoNamespaces(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setExitOnFirstFatalError) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setExitOnFirstFatalError(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setExitOnFirstFatalError. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setExitOnFirstFatalError(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setValidationConstraintFatal) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setValidationConstraintFatal(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setValidationConstraintFatal. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationConstraintFatal(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setCreateEntityReferenceNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setCreateEntityReferenceNodes(self,create);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setCreateEntityReferenceNodes. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCreateEntityReferenceNodes(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setIncludeIgnorableWhitespace) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setIncludeIgnorableWhitespace(self,include);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setIncludeIgnorableWhitespace. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setIncludeIgnorableWhitespace(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setValidationScheme) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        int arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setValidationScheme(self,newScheme);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setValidationScheme. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (int) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationScheme((XERCES_CPP_NAMESPACE::AbstractDOMParser::ValSchemes )arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setDoSchema) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setDoSchema(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setDoSchema. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setDoSchema(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setValidationSchemaFullChecking) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setValidationSchemaFullChecking(self,schemaFullChecking);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setValidationSchemaFullChecking. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setValidationSchemaFullChecking(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setExternalSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setExternalSchemaLocation(self,schemaLocation);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setExternalSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setExternalSchemaLocation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setExternalNoNamespaceSchemaLocation) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setExternalNoNamespaceSchemaLocation(self,noNamespaceSchemaLocation);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setExternalNoNamespaceSchemaLocation. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->setExternalNoNamespaceSchemaLocation((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setSecurityManager) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        SecurityManager *arg2 = (SecurityManager *) (SecurityManager *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setSecurityManager(self,securityManager);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setSecurityManager. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_SecurityManager,0) < 0) {
                SWIG_croak("Type error in argument 2 of AbstractDOMParser_setSecurityManager. Expected _p_SecurityManager");
            }
        }
        {
            try {
                (arg1)->setSecurityManager(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setLoadExternalDTD) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setLoadExternalDTD(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setLoadExternalDTD. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setLoadExternalDTD(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setCreateCommentNodes) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setCreateCommentNodes(self,create);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setCreateCommentNodes. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCreateCommentNodes(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setCalculateSrcOfs) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setCalculateSrcOfs(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setCalculateSrcOfs. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setCalculateSrcOfs(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setStandardUriConformant) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setStandardUriConformant(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setStandardUriConformant. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setStandardUriConformant(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_useScanner) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_useScanner(self,scannerName);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_useScanner. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->useScanner((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parse__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_parse(self,source);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parse. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of AbstractDOMParser_parse. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            try {
                (arg1)->parse((XERCES_CPP_NAMESPACE::InputSource const &)*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parse__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parse. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->parse((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parse__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        char *arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_parse(self,systemId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parse. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            try {
                (arg1)->parse((char const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parse) {
    dXSARGS;
    
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parse__SWIG_0); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parse__SWIG_1); return;
            }
        }
    }
    if (items == 2) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parse__SWIG_2); return;
            }
        }
    }
    
    croak("No matching function for overloaded 'AbstractDOMParser_parse'");
    XSRETURN(0);
}

XS(_wrap_AbstractDOMParser_parseFirst__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: AbstractDOMParser_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XMLCh const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parseFirst__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        char *arg2 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: AbstractDOMParser_parseFirst(self,systemId,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((char const *)arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parseFirst__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg3 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: AbstractDOMParser_parseFirst(self,source,toFill);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(2), (void **) &arg3, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 3 of AbstractDOMParser_parseFirst. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseFirst((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,*arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parseFirst) {
    dXSARGS;
    
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parseFirst__SWIG_2); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parseFirst__SWIG_0); return;
                }
            }
        }
    }
    if (items == 3) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    void *tmp;
                    if (SWIG_ConvertPtr(ST(2), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, 0) == -1) {
                        _v = 0;
                    }else {
                        _v = 1;
                    }
                }
                if (_v) {
                    (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_AbstractDOMParser_parseFirst__SWIG_1); return;
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'AbstractDOMParser_parseFirst'");
    XSRETURN(0);
}

XS(_wrap_AbstractDOMParser_parseNext) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_parseNext(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parseNext. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of AbstractDOMParser_parseNext. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                result = (bool)(arg1)->parseNext(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_parseReset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::XMLPScanToken *arg2 = 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_parseReset(self,token);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_parseReset. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken,0) < 0) {
                SWIG_croak("Type error in argument 2 of AbstractDOMParser_parseReset. Expected _p_XERCES_CPP_NAMESPACE__XMLPScanToken");
            }
        }
        {
            try {
                (arg1)->parseReset(*arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_getExpandEntityReferences) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: AbstractDOMParser_getExpandEntityReferences(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_getExpandEntityReferences. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::AbstractDOMParser const *)arg1)->getExpandEntityReferences();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_AbstractDOMParser_setExpandEntityReferences) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::AbstractDOMParser *arg1 = (XERCES_CPP_NAMESPACE::AbstractDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: AbstractDOMParser_setExpandEntityReferences(self,expand);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of AbstractDOMParser_setExpandEntityReferences. Expected _p_XERCES_CPP_NAMESPACE__AbstractDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->setExpandEntityReferences(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_XercesDOMParser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XMLValidator *arg1 = (XERCES_CPP_NAMESPACE::XMLValidator *) (XERCES_CPP_NAMESPACE::XMLValidator *)0 ;
        XERCES_CPP_NAMESPACE::MemoryManager *arg2 = (XERCES_CPP_NAMESPACE::MemoryManager *) (XERCES_CPP_NAMESPACE::MemoryManager *)XERCES_CPP_NAMESPACE::XMLPlatformUtils::fgMemoryManager ;
        XERCES_CPP_NAMESPACE::XercesDOMParser *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 2)) {
            SWIG_croak("Usage: new_XercesDOMParser(valToAdopt,manager);");
        }
        if (items > 0) {
            {
                if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator,0) < 0) {
                    SWIG_croak("Type error in argument 1 of new_XercesDOMParser. Expected _p_XERCES_CPP_NAMESPACE__XMLValidator");
                }
            }
        }
        if (items > 1) {
            {
                if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemoryManager,0) < 0) {
                    SWIG_croak("Type error in argument 2 of new_XercesDOMParser. Expected _p_XERCES_CPP_NAMESPACE__MemoryManager");
                }
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::XercesDOMParser *)new XERCES_CPP_NAMESPACE::XercesDOMParser(arg1,arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_delete_XercesDOMParser) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_XercesDOMParser(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_XercesDOMParser. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_getErrorHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::ErrorHandler *)(arg1)->getErrorHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_getEntityResolver(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::EntityResolver *)(arg1)->getEntityResolver();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_isCachingGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_isCachingGrammarFromParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_isCachingGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XercesDOMParser const *)arg1)->isCachingGrammarFromParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_isUsingCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        bool result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_isUsingCachedGrammarInParse(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_isUsingCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (bool)((XERCES_CPP_NAMESPACE::XercesDOMParser const *)arg1)->isUsingCachedGrammarInParse();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setiv(ST(argvi++), (IV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_getGrammar(self,nameSpaceKey);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getGrammar. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getGrammar((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getRootGrammar) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_getRootGrammar(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getRootGrammar. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->getRootGrammar();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getURIText) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        unsigned int arg2 ;
        XMLCh *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_getURIText(self,uriId);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getURIText. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            try {
                result = (XMLCh *)((XERCES_CPP_NAMESPACE::XercesDOMParser const *)arg1)->getURIText(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        {
            ST(argvi) = XMLString2Perl(result);
            ++argvi;
        }
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_getSrcOffset) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        unsigned int result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_getSrcOffset(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_getSrcOffset. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                result = (unsigned int)((XERCES_CPP_NAMESPACE::XercesDOMParser const *)arg1)->getSrcOffset();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        sv_setuv(ST(argvi++), (UV) result);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_setErrorHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::ErrorHandler *arg2 = (XERCES_CPP_NAMESPACE::ErrorHandler *) (XERCES_CPP_NAMESPACE::ErrorHandler *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_setErrorHandler(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler,0) < 0) {
                SWIG_croak("Type error in argument 2 of XercesDOMParser_setErrorHandler. Expected _p_XERCES_CPP_NAMESPACE__ErrorHandler");
            }
        }
        {
            try {
                (arg1)->setErrorHandler(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_setEntityResolver) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::EntityResolver *arg2 = (XERCES_CPP_NAMESPACE::EntityResolver *) (XERCES_CPP_NAMESPACE::EntityResolver *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_setEntityResolver(self,handler);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver,0) < 0) {
                SWIG_croak("Type error in argument 2 of XercesDOMParser_setEntityResolver. Expected _p_XERCES_CPP_NAMESPACE__EntityResolver");
            }
        }
        {
            try {
                (arg1)->setEntityResolver(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_cacheGrammarFromParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_cacheGrammarFromParse(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_cacheGrammarFromParse. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->cacheGrammarFromParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_useCachedGrammarInParse) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        bool arg2 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: XercesDOMParser_useCachedGrammarInParse(self,newState);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_useCachedGrammarInParse. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        arg2 = (bool) SvIV(ST(1));
        {
            try {
                (arg1)->useCachedGrammarInParse(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_resetDocumentPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_resetDocumentPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_resetDocumentPool. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                (arg1)->resetDocumentPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_error) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        unsigned int arg2 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int arg4 ;
        XMLCh *arg5 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg6 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg7 = (XMLCh *) (XMLCh *)0 ;
        XMLSSize_t arg8 ;
        XMLSSize_t arg9 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 9) || (items > 9)) {
            SWIG_croak("Usage: XercesDOMParser_error(self,errCode,msgDomain,errType,errorText,systemId,publicId,lineNum,colNum);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_error. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        arg2 = (unsigned int) SvUV(ST(1));
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg4 = (int) SvIV(ST(3));
        {
            if (SvPOK(ST(4))||SvIOK(ST(4))||SvNOK(ST(4))) {
                arg5 = Perl2XMLString(ST(4));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(5))||SvIOK(ST(5))||SvNOK(ST(5))) {
                arg6 = Perl2XMLString(ST(5));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(6))||SvIOK(ST(6))||SvNOK(ST(6))) {
                arg7 = Perl2XMLString(ST(6));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg8 = (XMLSSize_t) SvIV(ST(7));
        arg9 = (XMLSSize_t) SvIV(ST(8));
        {
            try {
                (arg1)->error(arg2,(XMLCh const *)arg3,(XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrTypes )arg4,(XMLCh const *)arg5,(XMLCh const *)arg6,(XMLCh const *)arg7,arg8,arg9);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg3;
        }
        {
            delete[] arg5;
        }
        {
            delete[] arg6;
        }
        {
            delete[] arg7;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_resetErrors. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_loadGrammar__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XERCES_CPP_NAMESPACE::InputSource *arg2 = 0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XercesDOMParser_loadGrammar(self,source,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource,0) < 0) {
                SWIG_croak("Type error in argument 2 of XercesDOMParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__InputSource");
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XERCES_CPP_NAMESPACE::InputSource const &)*arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_loadGrammar__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XercesDOMParser_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((XMLCh const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_loadGrammar__SWIG_2) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        char *arg2 ;
        short arg3 ;
        bool arg4 = (bool) (bool)false ;
        XERCES_CPP_NAMESPACE::Grammar *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 4)) {
            SWIG_croak("Usage: XercesDOMParser_loadGrammar(self,systemId,grammarType,toCache);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_loadGrammar. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        if (!SvOK((SV*) ST(1))) arg2 = 0;
        else arg2 = (char *) SvPV(ST(1), PL_na);
        arg3 = (short) SvIV(ST(2));
        if (items > 3) {
            arg4 = (bool) SvIV(ST(3));
        }
        {
            try {
                result = (XERCES_CPP_NAMESPACE::Grammar *)(arg1)->loadGrammar((char const *)arg2,arg3,arg4);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_XercesDOMParser_loadGrammar) {
    dXSARGS;
    
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                void *tmp;
                if (SWIG_ConvertPtr(ST(1), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, 0) == -1) {
                    _v = 0;
                }else {
                    _v = 1;
                }
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_0); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_0); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_1); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_1); return;
                    }
                }
            }
        }
    }
    if ((items >= 3) && (items <= 4)) {
        int _v;
        {
            void *tmp;
            if (SWIG_ConvertPtr(ST(0), (void **) &tmp, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser, 0) == -1) {
                _v = 0;
            }else {
                _v = 1;
            }
        }
        if (_v) {
            {
                _v = SvPOK(ST(1)) ? 1 : 0;
            }
            if (_v) {
                {
                    _v = SvIOK(ST(2)) ? 1 : 0;
                }
                if (_v) {
                    if (items <= 3) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_2); return;
                    }
                    {
                        _v = SvIOK(ST(3)) ? 1 : 0;
                    }
                    if (_v) {
                        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_XercesDOMParser_loadGrammar__SWIG_2); return;
                    }
                }
            }
        }
    }
    
    croak("No matching function for overloaded 'XercesDOMParser_loadGrammar'");
    XSRETURN(0);
}

XS(_wrap_XercesDOMParser_resetCachedGrammarPool) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        XERCES_CPP_NAMESPACE::XercesDOMParser *arg1 = (XERCES_CPP_NAMESPACE::XercesDOMParser *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: XercesDOMParser_resetCachedGrammarPool(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser,0) < 0) {
                SWIG_croak("Type error in argument 1 of XercesDOMParser_resetCachedGrammarPool. Expected _p_XERCES_CPP_NAMESPACE__XercesDOMParser");
            }
        }
        {
            try {
                (arg1)->resetCachedGrammarPool();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlErrorCallbackHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlErrorCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_PerlErrorCallbackHandler();");
        }
        {
            try {
                result = (PerlErrorCallbackHandler *)new PerlErrorCallbackHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlErrorCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlErrorCallbackHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        SV *arg1 = (SV *) 0 ;
        PerlErrorCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_PerlErrorCallbackHandler(obj);");
        }
        {
            arg1 = ST(0);
        }
        {
            try {
                result = (PerlErrorCallbackHandler *)new PerlErrorCallbackHandler(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlErrorCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlErrorCallbackHandler) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlErrorCallbackHandler__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            _v = SvOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlErrorCallbackHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_PerlErrorCallbackHandler'");
    XSRETURN(0);
}

XS(_wrap_delete_PerlErrorCallbackHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlErrorCallbackHandler *arg1 = (PerlErrorCallbackHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_PerlErrorCallbackHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlErrorCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_PerlErrorCallbackHandler. Expected _p_PerlErrorCallbackHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlErrorCallbackHandler_set_callback_obj) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlErrorCallbackHandler *arg1 = (PerlErrorCallbackHandler *) 0 ;
        SV *arg2 = (SV *) 0 ;
        SV *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlErrorCallbackHandler_set_callback_obj(self,SV *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlErrorCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlErrorCallbackHandler_set_callback_obj. Expected _p_PerlErrorCallbackHandler");
            }
        }
        {
            arg2 = ST(1);
        }
        {
            try {
                result = (SV *)(arg1)->set_callback_obj(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SV,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlErrorCallbackHandler_resetErrors) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlErrorCallbackHandler *arg1 = (PerlErrorCallbackHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: PerlErrorCallbackHandler_resetErrors(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlErrorCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlErrorCallbackHandler_resetErrors. Expected _p_PerlErrorCallbackHandler");
            }
        }
        {
            try {
                (arg1)->resetErrors();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlDocumentCallbackHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_PerlDocumentCallbackHandler();");
        }
        {
            try {
                result = (PerlDocumentCallbackHandler *)new PerlDocumentCallbackHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlDocumentCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlDocumentCallbackHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        SV *arg1 = (SV *) 0 ;
        PerlDocumentCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_PerlDocumentCallbackHandler(obj);");
        }
        {
            arg1 = ST(0);
        }
        {
            try {
                result = (PerlDocumentCallbackHandler *)new PerlDocumentCallbackHandler(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlDocumentCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlDocumentCallbackHandler) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlDocumentCallbackHandler__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            _v = SvOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlDocumentCallbackHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_PerlDocumentCallbackHandler'");
    XSRETURN(0);
}

XS(_wrap_delete_PerlDocumentCallbackHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *arg1 = (PerlDocumentCallbackHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_PerlDocumentCallbackHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlDocumentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_PerlDocumentCallbackHandler. Expected _p_PerlDocumentCallbackHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlDocumentCallbackHandler_set_callback_obj) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *arg1 = (PerlDocumentCallbackHandler *) 0 ;
        SV *arg2 = (SV *) 0 ;
        SV *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlDocumentCallbackHandler_set_callback_obj(self,SV *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlDocumentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlDocumentCallbackHandler_set_callback_obj. Expected _p_PerlDocumentCallbackHandler");
            }
        }
        {
            arg2 = ST(1);
        }
        {
            try {
                result = (SV *)(arg1)->set_callback_obj(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SV,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlDocumentCallbackHandler_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *arg1 = (PerlDocumentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: PerlDocumentCallbackHandler_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlDocumentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlDocumentCallbackHandler_characters. Expected _p_PerlDocumentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlDocumentCallbackHandler_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *arg1 = (PerlDocumentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: PerlDocumentCallbackHandler_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlDocumentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlDocumentCallbackHandler_processingInstruction. Expected _p_PerlDocumentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlDocumentCallbackHandler_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlDocumentCallbackHandler *arg1 = (PerlDocumentCallbackHandler *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlDocumentCallbackHandler_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlDocumentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlDocumentCallbackHandler_setDocumentLocator. Expected _p_PerlDocumentCallbackHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of PerlDocumentCallbackHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlContentCallbackHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_PerlContentCallbackHandler();");
        }
        {
            try {
                result = (PerlContentCallbackHandler *)new PerlContentCallbackHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlContentCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlContentCallbackHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        SV *arg1 = (SV *) 0 ;
        PerlContentCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_PerlContentCallbackHandler(obj);");
        }
        {
            arg1 = ST(0);
        }
        {
            try {
                result = (PerlContentCallbackHandler *)new PerlContentCallbackHandler(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlContentCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlContentCallbackHandler) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlContentCallbackHandler__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            _v = SvOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlContentCallbackHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_PerlContentCallbackHandler'");
    XSRETURN(0);
}

XS(_wrap_delete_PerlContentCallbackHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_PerlContentCallbackHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_PerlContentCallbackHandler. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_set_callback_obj) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        SV *arg2 = (SV *) 0 ;
        SV *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_set_callback_obj(self,SV *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_set_callback_obj. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            arg2 = ST(1);
        }
        {
            try {
                result = (SV *)(arg1)->set_callback_obj(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SV,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_characters) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        unsigned int arg3 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_characters(self,chars,length);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_characters. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        arg3 = (unsigned int) SvUV(ST(2));
        {
            try {
                (arg1)->characters((XMLCh const *)arg2,arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_processingInstruction) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_processingInstruction(self,target,data);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_processingInstruction. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->processingInstruction((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_setDocumentLocator) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XERCES_CPP_NAMESPACE::Locator *arg2 = (XERCES_CPP_NAMESPACE::Locator *) (XERCES_CPP_NAMESPACE::Locator *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_setDocumentLocator(self,locator);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_setDocumentLocator. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SWIG_ConvertPtr(ST(1), (void **) &arg2, SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator,0) < 0) {
                SWIG_croak("Type error in argument 2 of PerlContentCallbackHandler_setDocumentLocator. Expected _p_XERCES_CPP_NAMESPACE__Locator");
            }
        }
        {
            try {
                (arg1)->setDocumentLocator((XERCES_CPP_NAMESPACE::Locator const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_startPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        XMLCh *arg3 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 3) || (items > 3)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_startPrefixMapping(self,prefix,uri);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_startPrefixMapping. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            if (SvPOK(ST(2))||SvIOK(ST(2))||SvNOK(ST(2))) {
                arg3 = Perl2XMLString(ST(2));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->startPrefixMapping((XMLCh const *)arg2,(XMLCh const *)arg3);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        {
            delete[] arg3;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_endPrefixMapping) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_endPrefixMapping(self,prefix);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_endPrefixMapping. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->endPrefixMapping((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlContentCallbackHandler_skippedEntity) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlContentCallbackHandler *arg1 = (PerlContentCallbackHandler *) 0 ;
        XMLCh *arg2 = (XMLCh *) (XMLCh *)0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlContentCallbackHandler_skippedEntity(self,name);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlContentCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlContentCallbackHandler_skippedEntity. Expected _p_PerlContentCallbackHandler");
            }
        }
        {
            if (SvPOK(ST(1))||SvIOK(ST(1))||SvNOK(ST(1))) {
                arg2 = Perl2XMLString(ST(1));
            }else {
                croak("Type error in argument 2 of $name, Expected perl-string.");
                XSRETURN(1);
            }
        }
        {
            try {
                (arg1)->skippedEntity((XMLCh const *)arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        {
            delete[] arg2;
        }
        XSRETURN(argvi);
        fail:
        {
            delete[] arg2;
        }
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlEntityResolverHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlEntityResolverHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_PerlEntityResolverHandler();");
        }
        {
            try {
                result = (PerlEntityResolverHandler *)new PerlEntityResolverHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlEntityResolverHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlEntityResolverHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        SV *arg1 = (SV *) 0 ;
        PerlEntityResolverHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_PerlEntityResolverHandler(obj);");
        }
        {
            arg1 = ST(0);
        }
        {
            try {
                result = (PerlEntityResolverHandler *)new PerlEntityResolverHandler(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlEntityResolverHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlEntityResolverHandler) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlEntityResolverHandler__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            _v = SvOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlEntityResolverHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_PerlEntityResolverHandler'");
    XSRETURN(0);
}

XS(_wrap_delete_PerlEntityResolverHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlEntityResolverHandler *arg1 = (PerlEntityResolverHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_PerlEntityResolverHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlEntityResolverHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_PerlEntityResolverHandler. Expected _p_PerlEntityResolverHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlEntityResolverHandler_set_callback_obj) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlEntityResolverHandler *arg1 = (PerlEntityResolverHandler *) 0 ;
        SV *arg2 = (SV *) 0 ;
        SV *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlEntityResolverHandler_set_callback_obj(self,SV *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlEntityResolverHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlEntityResolverHandler_set_callback_obj. Expected _p_PerlEntityResolverHandler");
            }
        }
        {
            arg2 = ST(1);
        }
        {
            try {
                result = (SV *)(arg1)->set_callback_obj(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SV,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlNodeFilterCallbackHandler__SWIG_0) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlNodeFilterCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 0) || (items > 0)) {
            SWIG_croak("Usage: new_PerlNodeFilterCallbackHandler();");
        }
        {
            try {
                result = (PerlNodeFilterCallbackHandler *)new PerlNodeFilterCallbackHandler();
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlNodeFilterCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlNodeFilterCallbackHandler__SWIG_1) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        SV *arg1 = (SV *) 0 ;
        PerlNodeFilterCallbackHandler *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: new_PerlNodeFilterCallbackHandler(obj);");
        }
        {
            arg1 = ST(0);
        }
        {
            try {
                result = (PerlNodeFilterCallbackHandler *)new PerlNodeFilterCallbackHandler(arg1);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_PerlNodeFilterCallbackHandler,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_new_PerlNodeFilterCallbackHandler) {
    dXSARGS;
    
    if (items == 0) {
        (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlNodeFilterCallbackHandler__SWIG_0); return;
    }
    if (items == 1) {
        int _v;
        {
            _v = SvOK(ST(0)) ? 1 : 0;
        }
        if (_v) {
            (*PL_markstack_ptr++);SWIG_CALLXS(_wrap_new_PerlNodeFilterCallbackHandler__SWIG_1); return;
        }
    }
    
    croak("No matching function for overloaded 'new_PerlNodeFilterCallbackHandler'");
    XSRETURN(0);
}

XS(_wrap_delete_PerlNodeFilterCallbackHandler) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlNodeFilterCallbackHandler *arg1 = (PerlNodeFilterCallbackHandler *) 0 ;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 1) || (items > 1)) {
            SWIG_croak("Usage: delete_PerlNodeFilterCallbackHandler(self);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlNodeFilterCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of delete_PerlNodeFilterCallbackHandler. Expected _p_PerlNodeFilterCallbackHandler");
            }
        }
        {
            try {
                delete arg1;
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

XS(_wrap_PerlNodeFilterCallbackHandler_set_callback_obj) {
    char _swigmsg[SWIG_MAX_ERRMSG] = "";
    const char *_swigerr = _swigmsg;
    {
        PerlNodeFilterCallbackHandler *arg1 = (PerlNodeFilterCallbackHandler *) 0 ;
        SV *arg2 = (SV *) 0 ;
        SV *result;
        int argvi = 0;
        dXSARGS;
        
        if ((items < 2) || (items > 2)) {
            SWIG_croak("Usage: PerlNodeFilterCallbackHandler_set_callback_obj(self,SV *);");
        }
        {
            if (SWIG_ConvertPtr(ST(0), (void **) &arg1, SWIGTYPE_p_PerlNodeFilterCallbackHandler,0) < 0) {
                SWIG_croak("Type error in argument 1 of PerlNodeFilterCallbackHandler_set_callback_obj. Expected _p_PerlNodeFilterCallbackHandler");
            }
        }
        {
            arg2 = ST(1);
        }
        {
            try {
                result = (SV *)(arg1)->set_callback_obj(arg2);
                
            }
            catch (const XMLException& e)
            {
                makeXMLException(e);
            }
            catch (const DOMException& e)
            {
                makeDOMException(e);
            }
            catch (...)
            {
                croak("%s", "Handling Unknown exception");
            }
        }
        ST(argvi) = sv_newmortal();
        SWIG_MakePtr(ST(argvi++), (void *) result, SWIGTYPE_p_SV,0);
        XSRETURN(argvi);
        fail:
        (void) _swigerr;
    }
    croak(_swigerr);
}

/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static void *_p_XERCES_CPP_NAMESPACE__DOMWriterFilterTo_p_XERCES_CPP_NAMESPACE__DOMNodeFilter(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNodeFilter *)  ((XERCES_CPP_NAMESPACE::DOMWriterFilter *) x));
}
static void *_p_PerlNodeFilterCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__DOMNodeFilter(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNodeFilter *)  ((PerlNodeFilterCallbackHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMElementTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMElement *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMDocumentFragmentTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMDocumentFragment *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMAttrTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMAttr *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCharacterDataTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMCharacterData *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMTextTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *) (XERCES_CPP_NAMESPACE::DOMCharacterData *) ((XERCES_CPP_NAMESPACE::DOMText *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMDocumentTypeTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMDocumentType *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCommentTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *) (XERCES_CPP_NAMESPACE::DOMCharacterData *) ((XERCES_CPP_NAMESPACE::DOMComment *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMProcessingInstructionTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMProcessingInstruction *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMDocument *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMEntityTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMEntity *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMEntityReferenceTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMEntityReference *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *) (XERCES_CPP_NAMESPACE::DOMCharacterData *)(XERCES_CPP_NAMESPACE::DOMText *) ((XERCES_CPP_NAMESPACE::DOMCDATASection *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMNotationTo_p_XERCES_CPP_NAMESPACE__DOMNode(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMNode *)  ((XERCES_CPP_NAMESPACE::DOMNotation *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXNotSupportedExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::SAXException *)  ((XERCES_CPP_NAMESPACE::SAXNotSupportedException *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::SAXException *)  ((XERCES_CPP_NAMESPACE::SAXNotRecognizedException *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParseExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::SAXException *)  ((XERCES_CPP_NAMESPACE::SAXParseException *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMRangeExceptionTo_p_XERCES_CPP_NAMESPACE__DOMException(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMException *)  ((XERCES_CPP_NAMESPACE::DOMRangeException *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLErrorReporter *)  ((XERCES_CPP_NAMESPACE::SAXParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLErrorReporter *)  ((XERCES_CPP_NAMESPACE::AbstractDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLErrorReporter *) (XERCES_CPP_NAMESPACE::AbstractDOMParser *) ((XERCES_CPP_NAMESPACE::XercesDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMDocumentTraversal *)  ((XERCES_CPP_NAMESPACE::DOMDocument *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__AbstractDOMParser(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::AbstractDOMParser *)  ((XERCES_CPP_NAMESPACE::XercesDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__EntityResolver(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::EntityResolver *)  ((XERCES_CPP_NAMESPACE::HandlerBase *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__EntityResolver(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::EntityResolver *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_PerlEntityResolverHandlerTo_p_XERCES_CPP_NAMESPACE__EntityResolver(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::EntityResolver *)  ((PerlEntityResolverHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLEntityHandler *)  ((XERCES_CPP_NAMESPACE::SAXParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLEntityHandler *)  ((XERCES_CPP_NAMESPACE::AbstractDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLEntityHandler *) (XERCES_CPP_NAMESPACE::AbstractDOMParser *) ((XERCES_CPP_NAMESPACE::XercesDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLDocumentHandler *)  ((XERCES_CPP_NAMESPACE::SAXParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLDocumentHandler *)  ((XERCES_CPP_NAMESPACE::AbstractDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLDocumentHandler *) (XERCES_CPP_NAMESPACE::AbstractDOMParser *) ((XERCES_CPP_NAMESPACE::XercesDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__DeclHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DeclHandler *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__LexicalHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::LexicalHandler *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__ContentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::ContentHandler *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_PerlContentCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__ContentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::ContentHandler *)  ((PerlContentCallbackHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__ErrorHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::ErrorHandler *)  ((XERCES_CPP_NAMESPACE::HandlerBase *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__ErrorHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::ErrorHandler *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_PerlErrorCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__ErrorHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::ErrorHandler *)  ((PerlErrorCallbackHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__DocumentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DocumentHandler *)  ((XERCES_CPP_NAMESPACE::HandlerBase *) x));
}
static void *_p_PerlDocumentCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__DocumentHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DocumentHandler *)  ((PerlDocumentCallbackHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__DTDHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DTDHandler *)  ((XERCES_CPP_NAMESPACE::HandlerBase *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__DTDHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DTDHandler *)  ((XERCES_CPP_NAMESPACE::DefaultHandler *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DocTypeHandler *)  ((XERCES_CPP_NAMESPACE::SAXParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DocTypeHandler *)  ((XERCES_CPP_NAMESPACE::AbstractDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DocTypeHandler *) (XERCES_CPP_NAMESPACE::AbstractDOMParser *) ((XERCES_CPP_NAMESPACE::XercesDOMParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMText(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMText *)  ((XERCES_CPP_NAMESPACE::DOMCDATASection *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMImplementationTo_p_XERCES_CPP_NAMESPACE__DOMImplementationLS(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMImplementationLS *)  ((XERCES_CPP_NAMESPACE::DOMImplementation *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMTextTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMCharacterData *)  ((XERCES_CPP_NAMESPACE::DOMText *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCommentTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMCharacterData *)  ((XERCES_CPP_NAMESPACE::DOMComment *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMCharacterData *) (XERCES_CPP_NAMESPACE::DOMText *) ((XERCES_CPP_NAMESPACE::DOMCDATASection *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__MemBufInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::InputSource *)  ((XERCES_CPP_NAMESPACE::MemBufInputSource *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__StdInInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::InputSource *)  ((XERCES_CPP_NAMESPACE::StdInInputSource *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__LocalFileInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::InputSource *)  ((XERCES_CPP_NAMESPACE::LocalFileInputSource *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__URLInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::InputSource *)  ((XERCES_CPP_NAMESPACE::URLInputSource *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__Parser(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::Parser *)  ((XERCES_CPP_NAMESPACE::SAXParser *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMDocumentRange(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::DOMDocumentRange *)  ((XERCES_CPP_NAMESPACE::DOMDocument *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__MemBufFormatTargetTo_p_XERCES_CPP_NAMESPACE__XMLFormatTarget(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLFormatTarget *)  ((XERCES_CPP_NAMESPACE::MemBufFormatTarget *) x));
}
static void *_p_XERCES_CPP_NAMESPACE__StdOutFormatTargetTo_p_XERCES_CPP_NAMESPACE__XMLFormatTarget(void *x) {
    return (void *)((XERCES_CPP_NAMESPACE::XMLFormatTarget *)  ((XERCES_CPP_NAMESPACE::StdOutFormatTarget *) x));
}
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNodeIterator[] = {{"XML::Xerces::DOMNodeIterator", 0, "XERCES_CPP_NAMESPACE::DOMNodeIterator *", 0},{"XML::Xerces::DOMNodeIterator"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMDocument[] = {{"XML::Xerces::DOMDocument", 0, "XERCES_CPP_NAMESPACE::DOMDocument *", 0},{"XML::Xerces::DOMDocument"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMImplementation[] = {{"XML::Xerces::DOMImplementation", 0, "XERCES_CPP_NAMESPACE::DOMImplementation *", 0},{"XML::Xerces::DOMImplementation"},{0}};
static swig_type_info _swigt__p_XMLCh[] = {{"_p_XMLCh", 0, "XMLCh const []", 0},{"_p_XMLCh"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry[] = {{"XML::Xerces::DOMImplementationRegistry", 0, "XERCES_CPP_NAMESPACE::DOMImplementationRegistry *", 0},{"XML::Xerces::DOMImplementationRegistry"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMConfiguration[] = {{"_p_XERCES_CPP_NAMESPACE__DOMConfiguration", 0, "XERCES_CPP_NAMESPACE::DOMConfiguration *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMConfiguration"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLFormatter[] = {{"XML::Xerces::XMLFormatter", 0, "XERCES_CPP_NAMESPACE::XMLFormatter *", 0},{"XML::Xerces::XMLFormatter"},{0}};
static swig_type_info _swigt__p_size_t[] = {{"_p_size_t", 0, "size_t *", 0},{"_p_size_t"},{0}};
static swig_type_info _swigt__p_XMLAttr[] = {{"_p_XMLAttr", 0, "XMLAttr *", 0},{"_p_XMLAttr"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLReaderFactory[] = {{"XML::Xerces::XMLReaderFactory", 0, "XERCES_CPP_NAMESPACE::XMLReaderFactory *", 0},{"XML::Xerces::XMLReaderFactory"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__AttributeList[] = {{"XML::Xerces::AttributeList", 0, "XERCES_CPP_NAMESPACE::AttributeList *", 0},{"XML::Xerces::AttributeList"},{0}};
static swig_type_info _swigt__p_XMLBuffer[] = {{"_p_XMLBuffer", 0, "XMLBuffer *", 0},{"_p_XMLBuffer"},{0}};
static swig_type_info _swigt__p_bool[] = {{"_p_bool", 0, "bool *", 0},{"_p_bool"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNodeFilter[] = {{"XML::Xerces::DOMNodeFilter", 0, "XERCES_CPP_NAMESPACE::DOMNodeFilter *", 0},{"XML::Xerces::DOMWriterFilter", _p_XERCES_CPP_NAMESPACE__DOMWriterFilterTo_p_XERCES_CPP_NAMESPACE__DOMNodeFilter},{"_p_DOMWriterFilter", _p_XERCES_CPP_NAMESPACE__DOMWriterFilterTo_p_XERCES_CPP_NAMESPACE__DOMNodeFilter},{"XML::Xerces::DOMNodeFilter"},{"XML::Xerces::PerlNodeFilterCallbackHandler", _p_PerlNodeFilterCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__DOMNodeFilter},{0}};
static swig_type_info _swigt__p_XMLNotationDecl[] = {{"_p_XMLNotationDecl", 0, "XMLNotationDecl *", 0},{"_p_XMLNotationDecl"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLUni[] = {{"XML::Xerces::XMLUni", 0, "XERCES_CPP_NAMESPACE::XMLUni *", 0},{"XML::Xerces::XMLUni"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLExcepts[] = {{"XML::Xerces::XMLExcepts", 0, "XERCES_CPP_NAMESPACE::XMLExcepts *", 0},{"XML::Xerces::XMLExcepts"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentType[] = {{"XML::Xerces::DOMDocumentType", 0, "XERCES_CPP_NAMESPACE::DOMDocumentType *", 0},{"XML::Xerces::DOMDocumentType"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNode[] = {{"XML::Xerces::DOMNode", 0, "XERCES_CPP_NAMESPACE::DOMNode *", 0},{"XML::Xerces::DOMAttr", _p_XERCES_CPP_NAMESPACE__DOMAttrTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMNotation", _p_XERCES_CPP_NAMESPACE__DOMNotationTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMText", _p_XERCES_CPP_NAMESPACE__DOMTextTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMDocumentFragment", _p_XERCES_CPP_NAMESPACE__DOMDocumentFragmentTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMCDATASection", _p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMEntityReference", _p_XERCES_CPP_NAMESPACE__DOMEntityReferenceTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMEntity", _p_XERCES_CPP_NAMESPACE__DOMEntityTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMCharacterData", _p_XERCES_CPP_NAMESPACE__DOMCharacterDataTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMDocumentType", _p_XERCES_CPP_NAMESPACE__DOMDocumentTypeTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMComment", _p_XERCES_CPP_NAMESPACE__DOMCommentTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMNode"},{"XML::Xerces::DOMDocument", _p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMElement", _p_XERCES_CPP_NAMESPACE__DOMElementTo_p_XERCES_CPP_NAMESPACE__DOMNode},{"XML::Xerces::DOMProcessingInstruction", _p_XERCES_CPP_NAMESPACE__DOMProcessingInstructionTo_p_XERCES_CPP_NAMESPACE__DOMNode},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLElementDecl[] = {{"_p_XERCES_CPP_NAMESPACE__XMLElementDecl", 0, "XERCES_CPP_NAMESPACE::XMLElementDecl *", 0},{"_p_XERCES_CPP_NAMESPACE__XMLElementDecl"},{0}};
static swig_type_info _swigt__p_void[] = {{"_p_void", 0, "void *", 0},{"_FileHandle"},{"_p_void"},{0}};
static swig_type_info _swigt__p_p_void[] = {{"_p_p_void", 0, "void **", 0},{"_p_p_void"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMRange[] = {{"XML::Xerces::DOMRange", 0, "XERCES_CPP_NAMESPACE::DOMRange *", 0},{"XML::Xerces::DOMRange"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMEntityReference[] = {{"XML::Xerces::DOMEntityReference", 0, "XERCES_CPP_NAMESPACE::DOMEntityReference *", 0},{"XML::Xerces::DOMEntityReference"},{0}};
static swig_type_info _swigt__p_int[] = {{"_p_int", 0, "int *", 0},{"_p_int"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNotation[] = {{"XML::Xerces::DOMNotation", 0, "XERCES_CPP_NAMESPACE::DOMNotation *", 0},{"XML::Xerces::DOMNotation"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAXParseException[] = {{"XML::Xerces::SAXParseException", 0, "XERCES_CPP_NAMESPACE::SAXParseException *", 0},{"XML::Xerces::SAXParseException"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException[] = {{"XML::Xerces::SAXNotRecognizedException", 0, "XERCES_CPP_NAMESPACE::SAXNotRecognizedException *", 0},{"XML::Xerces::SAXNotRecognizedException"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAXNotSupportedException[] = {{"XML::Xerces::SAXNotSupportedException", 0, "XERCES_CPP_NAMESPACE::SAXNotSupportedException *", 0},{"XML::Xerces::SAXNotSupportedException"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLException[] = {{"XML::Xerces::XMLException", 0, "XERCES_CPP_NAMESPACE::XMLException *", 0},{"XML::Xerces::XMLException"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAXException[] = {{"XML::Xerces::SAXException", 0, "XERCES_CPP_NAMESPACE::SAXException *", 0},{"XML::Xerces::SAXException"},{"XML::Xerces::SAXNotSupportedException", _p_XERCES_CPP_NAMESPACE__SAXNotSupportedExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException},{"XML::Xerces::SAXNotRecognizedException", _p_XERCES_CPP_NAMESPACE__SAXNotRecognizedExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException},{"XML::Xerces::SAXParseException", _p_XERCES_CPP_NAMESPACE__SAXParseExceptionTo_p_XERCES_CPP_NAMESPACE__SAXException},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMException[] = {{"XML::Xerces::DOMException", 0, "XERCES_CPP_NAMESPACE::DOMException *", 0},{"XML::Xerces::DOMException"},{"XML::Xerces::DOMRangeException", _p_XERCES_CPP_NAMESPACE__DOMRangeExceptionTo_p_XERCES_CPP_NAMESPACE__DOMException},{0}};
static swig_type_info _swigt__p_XMLErrorReporter[] = {{"_p_XMLErrorReporter", 0, "XMLErrorReporter *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"XML::Xerces::AbstractDOMParser", _p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"_p_XMLErrorReporter"},{"XML::Xerces::XMLErrorReporter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLErrorReporter[] = {{"XML::Xerces::XMLErrorReporter", 0, "XERCES_CPP_NAMESPACE::XMLErrorReporter *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"XML::Xerces::AbstractDOMParser", _p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLErrorReporter},{"XML::Xerces::XMLErrorReporter"},{"_p_XMLErrorReporter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMRangeException[] = {{"XML::Xerces::DOMRangeException", 0, "XERCES_CPP_NAMESPACE::DOMRangeException *", 0},{"XML::Xerces::DOMRangeException"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLDeleter[] = {{"XML::Xerces::XMLDeleter", 0, "XERCES_CPP_NAMESPACE::XMLDeleter *", 0},{"XML::Xerces::XMLDeleter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__Attributes[] = {{"XML::Xerces::Attributes", 0, "XERCES_CPP_NAMESPACE::Attributes *", 0},{"XML::Xerces::Attributes"},{0}};
static swig_type_info _swigt__FileHandle[] = {{"_FileHandle", 0, "FileHandle", 0},{"_FileHandle"},{"_p_void"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal[] = {{"XML::Xerces::DOMDocumentTraversal", 0, "XERCES_CPP_NAMESPACE::DOMDocumentTraversal *", 0},{"XML::Xerces::DOMDocumentTraversal"},{"XML::Xerces::DOMDocument", _p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__Parser[] = {{"XML::Xerces::Parser", 0, "XERCES_CPP_NAMESPACE::Parser *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__Parser},{"XML::Xerces::Parser"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__AbstractDOMParser[] = {{"XML::Xerces::AbstractDOMParser", 0, "XERCES_CPP_NAMESPACE::AbstractDOMParser *", 0},{"XML::Xerces::AbstractDOMParser"},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__AbstractDOMParser},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLScanner[] = {{"XML::Xerces::XMLScanner", 0, "XERCES_CPP_NAMESPACE::XMLScanner *", 0},{"XML::Xerces::XMLScanner"},{0}};
static swig_type_info _swigt__p_XMLReader__XMLVersion[] = {{"_p_XMLReader__XMLVersion", 0, "XMLReader::XMLVersion *", 0},{"_p_XMLReader__XMLVersion"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMAttr[] = {{"XML::Xerces::DOMAttr", 0, "XERCES_CPP_NAMESPACE::DOMAttr *", 0},{"XML::Xerces::DOMAttr"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMBuilder[] = {{"XML::Xerces::DOMBuilder", 0, "XERCES_CPP_NAMESPACE::DOMBuilder *", 0},{"XML::Xerces::DOMBuilder"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XercesDOMParser[] = {{"XML::Xerces::XercesDOMParser", 0, "XERCES_CPP_NAMESPACE::XercesDOMParser *", 0},{"XML::Xerces::XercesDOMParser"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLURL[] = {{"XML::Xerces::XMLURL", 0, "XERCES_CPP_NAMESPACE::XMLURL *", 0},{"XML::Xerces::XMLURL"},{0}};
static swig_type_info _swigt__p_XMLAttDef[] = {{"_p_XMLAttDef", 0, "XMLAttDef *", 0},{"_p_XMLAttDef"},{0}};
static swig_type_info _swigt__p_p_XERCES_CPP_NAMESPACE__QName[] = {{"_p_p_XERCES_CPP_NAMESPACE__QName", 0, "XERCES_CPP_NAMESPACE::QName **", 0},{"_p_p_XERCES_CPP_NAMESPACE__QName"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__QName[] = {{"XML::Xerces::QName", 0, "XERCES_CPP_NAMESPACE::QName *", 0},{"XML::Xerces::QName"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__EntityResolver[] = {{"XML::Xerces::EntityResolver", 0, "XERCES_CPP_NAMESPACE::EntityResolver *", 0},{"XML::Xerces::EntityResolver"},{"XML::Xerces::HandlerBase", _p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__EntityResolver},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__EntityResolver},{"XML::Xerces::PerlEntityResolverHandler", _p_PerlEntityResolverHandlerTo_p_XERCES_CPP_NAMESPACE__EntityResolver},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__GrammarResolver[] = {{"_p_XERCES_CPP_NAMESPACE__GrammarResolver", 0, "XERCES_CPP_NAMESPACE::GrammarResolver *", 0},{"_p_XERCES_CPP_NAMESPACE__GrammarResolver"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMEntityResolver[] = {{"_p_XERCES_CPP_NAMESPACE__DOMEntityResolver", 0, "XERCES_CPP_NAMESPACE::DOMEntityResolver *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMEntityResolver"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMBuilderFilter[] = {{"_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter", 0, "XERCES_CPP_NAMESPACE::DOMBuilderFilter *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMBuilderFilter"},{0}};
static swig_type_info _swigt__p_DOMWriterFilter[] = {{"_p_DOMWriterFilter", 0, "DOMWriterFilter *", 0},{"_p_DOMWriterFilter"},{"XML::Xerces::DOMWriterFilter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMWriterFilter[] = {{"XML::Xerces::DOMWriterFilter", 0, "XERCES_CPP_NAMESPACE::DOMWriterFilter *", 0},{"XML::Xerces::DOMWriterFilter"},{"_p_DOMWriterFilter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DefaultHandler[] = {{"XML::Xerces::DefaultHandler", 0, "XERCES_CPP_NAMESPACE::DefaultHandler *", 0},{"XML::Xerces::DefaultHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLEntityHandler[] = {{"XML::Xerces::XMLEntityHandler", 0, "XERCES_CPP_NAMESPACE::XMLEntityHandler *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler},{"XML::Xerces::AbstractDOMParser", _p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLEntityHandler},{"XML::Xerces::XMLEntityHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLDocumentHandler[] = {{"XML::Xerces::XMLDocumentHandler", 0, "XERCES_CPP_NAMESPACE::XMLDocumentHandler *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler},{"XML::Xerces::AbstractDOMParser", _p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler},{"XML::Xerces::XMLDocumentHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DeclHandler[] = {{"XML::Xerces::DeclHandler", 0, "XERCES_CPP_NAMESPACE::DeclHandler *", 0},{"XML::Xerces::DeclHandler"},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__DeclHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__LexicalHandler[] = {{"XML::Xerces::LexicalHandler", 0, "XERCES_CPP_NAMESPACE::LexicalHandler *", 0},{"XML::Xerces::LexicalHandler"},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__LexicalHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__ContentHandler[] = {{"XML::Xerces::ContentHandler", 0, "XERCES_CPP_NAMESPACE::ContentHandler *", 0},{"XML::Xerces::ContentHandler"},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__ContentHandler},{"XML::Xerces::PerlContentCallbackHandler", _p_PerlContentCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__ContentHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__ErrorHandler[] = {{"XML::Xerces::ErrorHandler", 0, "XERCES_CPP_NAMESPACE::ErrorHandler *", 0},{"XML::Xerces::HandlerBase", _p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__ErrorHandler},{"XML::Xerces::ErrorHandler"},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__ErrorHandler},{"XML::Xerces::PerlErrorCallbackHandler", _p_PerlErrorCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__ErrorHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DocumentHandler[] = {{"XML::Xerces::DocumentHandler", 0, "XERCES_CPP_NAMESPACE::DocumentHandler *", 0},{"XML::Xerces::HandlerBase", _p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__DocumentHandler},{"XML::Xerces::DocumentHandler"},{"XML::Xerces::PerlDocumentCallbackHandler", _p_PerlDocumentCallbackHandlerTo_p_XERCES_CPP_NAMESPACE__DocumentHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DTDHandler[] = {{"XML::Xerces::DTDHandler", 0, "XERCES_CPP_NAMESPACE::DTDHandler *", 0},{"XML::Xerces::HandlerBase", _p_XERCES_CPP_NAMESPACE__HandlerBaseTo_p_XERCES_CPP_NAMESPACE__DTDHandler},{"XML::Xerces::DTDHandler"},{"XML::Xerces::DefaultHandler", _p_XERCES_CPP_NAMESPACE__DefaultHandlerTo_p_XERCES_CPP_NAMESPACE__DTDHandler},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DocTypeHandler[] = {{"XML::Xerces::DocTypeHandler", 0, "XERCES_CPP_NAMESPACE::DocTypeHandler *", 0},{"XML::Xerces::SAXParser", _p_XERCES_CPP_NAMESPACE__SAXParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler},{"XML::Xerces::AbstractDOMParser", _p_XERCES_CPP_NAMESPACE__AbstractDOMParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler},{"XML::Xerces::XercesDOMParser", _p_XERCES_CPP_NAMESPACE__XercesDOMParserTo_p_XERCES_CPP_NAMESPACE__DocTypeHandler},{"XML::Xerces::DocTypeHandler"},{0}};
static swig_type_info _swigt__p_PanicHandler[] = {{"_p_PanicHandler", 0, "PanicHandler *", 0},{"_p_PanicHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMUserDataHandler[] = {{"_p_XERCES_CPP_NAMESPACE__DOMUserDataHandler", 0, "XERCES_CPP_NAMESPACE::DOMUserDataHandler *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMUserDataHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMErrorHandler[] = {{"_p_XERCES_CPP_NAMESPACE__DOMErrorHandler", 0, "XERCES_CPP_NAMESPACE::DOMErrorHandler *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMErrorHandler"},{0}};
static swig_type_info _swigt__p_PerlErrorCallbackHandler[] = {{"XML::Xerces::PerlErrorCallbackHandler", 0, "PerlErrorCallbackHandler *", 0},{"XML::Xerces::PerlErrorCallbackHandler"},{0}};
static swig_type_info _swigt__p_PerlDocumentCallbackHandler[] = {{"XML::Xerces::PerlDocumentCallbackHandler", 0, "PerlDocumentCallbackHandler *", 0},{"XML::Xerces::PerlDocumentCallbackHandler"},{0}};
static swig_type_info _swigt__p_PerlContentCallbackHandler[] = {{"XML::Xerces::PerlContentCallbackHandler", 0, "PerlContentCallbackHandler *", 0},{"XML::Xerces::PerlContentCallbackHandler"},{0}};
static swig_type_info _swigt__p_PerlEntityResolverHandler[] = {{"XML::Xerces::PerlEntityResolverHandler", 0, "PerlEntityResolverHandler *", 0},{"XML::Xerces::PerlEntityResolverHandler"},{0}};
static swig_type_info _swigt__p_PerlNodeFilterCallbackHandler[] = {{"XML::Xerces::PerlNodeFilterCallbackHandler", 0, "PerlNodeFilterCallbackHandler *", 0},{"XML::Xerces::PerlNodeFilterCallbackHandler"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMTreeWalker[] = {{"XML::Xerces::DOMTreeWalker", 0, "XERCES_CPP_NAMESPACE::DOMTreeWalker *", 0},{"XML::Xerces::DOMTreeWalker"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMText[] = {{"XML::Xerces::DOMText", 0, "XERCES_CPP_NAMESPACE::DOMText *", 0},{"XML::Xerces::DOMText"},{"XML::Xerces::DOMCDATASection", _p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMText},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationLS[] = {{"XML::Xerces::DOMImplementationLS", 0, "XERCES_CPP_NAMESPACE::DOMImplementationLS *", 0},{"XML::Xerces::DOMImplementation", _p_XERCES_CPP_NAMESPACE__DOMImplementationTo_p_XERCES_CPP_NAMESPACE__DOMImplementationLS},{"XML::Xerces::DOMImplementationLS"},{0}};
static swig_type_info _swigt__p_XMLValid__Codes[] = {{"_p_XMLValid__Codes", 0, "XMLValid::Codes *", 0},{"_p_XMLValid__Codes"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLStringPool[] = {{"_p_XERCES_CPP_NAMESPACE__XMLStringPool", 0, "XERCES_CPP_NAMESPACE::XMLStringPool *", 0},{"_p_XERCES_CPP_NAMESPACE__XMLStringPool"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMTypeInfo[] = {{"_p_XERCES_CPP_NAMESPACE__DOMTypeInfo", 0, "XERCES_CPP_NAMESPACE::DOMTypeInfo *", 0},{"_p_XERCES_CPP_NAMESPACE__DOMTypeInfo"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLMsgLoader[] = {{"_p_XERCES_CPP_NAMESPACE__XMLMsgLoader", 0, "XERCES_CPP_NAMESPACE::XMLMsgLoader *", 0},{"_p_XERCES_CPP_NAMESPACE__XMLMsgLoader"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__MemoryManager[] = {{"_p_XERCES_CPP_NAMESPACE__MemoryManager", 0, "XERCES_CPP_NAMESPACE::MemoryManager *", 0},{"_p_XERCES_CPP_NAMESPACE__MemoryManager"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLBufferMgr[] = {{"_p_XERCES_CPP_NAMESPACE__XMLBufferMgr", 0, "XERCES_CPP_NAMESPACE::XMLBufferMgr *", 0},{"_p_XERCES_CPP_NAMESPACE__XMLBufferMgr"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__Locator[] = {{"XML::Xerces::Locator", 0, "XERCES_CPP_NAMESPACE::Locator *", 0},{"XML::Xerces::Locator"},{0}};
static swig_type_info _swigt__p_SecurityManager[] = {{"_p_SecurityManager", 0, "SecurityManager *", 0},{"_p_SecurityManager"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMLocator[] = {{"XML::Xerces::DOMLocator", 0, "XERCES_CPP_NAMESPACE::DOMLocator *", 0},{"XML::Xerces::DOMLocator"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMCharacterData[] = {{"XML::Xerces::DOMCharacterData", 0, "XERCES_CPP_NAMESPACE::DOMCharacterData *", 0},{"XML::Xerces::DOMCharacterData"},{"XML::Xerces::DOMText", _p_XERCES_CPP_NAMESPACE__DOMTextTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData},{"XML::Xerces::DOMComment", _p_XERCES_CPP_NAMESPACE__DOMCommentTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData},{"XML::Xerces::DOMCDATASection", _p_XERCES_CPP_NAMESPACE__DOMCDATASectionTo_p_XERCES_CPP_NAMESPACE__DOMCharacterData},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentFragment[] = {{"XML::Xerces::DOMDocumentFragment", 0, "XERCES_CPP_NAMESPACE::DOMDocumentFragment *", 0},{"XML::Xerces::DOMDocumentFragment"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__BinInputStream[] = {{"_p_XERCES_CPP_NAMESPACE__BinInputStream", 0, "XERCES_CPP_NAMESPACE::BinInputStream *", 0},{"_p_XERCES_CPP_NAMESPACE__BinInputStream"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__URLInputSource[] = {{"XML::Xerces::URLInputSource", 0, "XERCES_CPP_NAMESPACE::URLInputSource *", 0},{"XML::Xerces::URLInputSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__LocalFileInputSource[] = {{"XML::Xerces::LocalFileInputSource", 0, "XERCES_CPP_NAMESPACE::LocalFileInputSource *", 0},{"XML::Xerces::LocalFileInputSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__StdInInputSource[] = {{"XML::Xerces::StdInInputSource", 0, "XERCES_CPP_NAMESPACE::StdInInputSource *", 0},{"XML::Xerces::StdInInputSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__MemBufInputSource[] = {{"XML::Xerces::MemBufInputSource", 0, "XERCES_CPP_NAMESPACE::MemBufInputSource *", 0},{"XML::Xerces::MemBufInputSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__InputSource[] = {{"XML::Xerces::InputSource", 0, "XERCES_CPP_NAMESPACE::InputSource *", 0},{"XML::Xerces::InputSource"},{"XML::Xerces::MemBufInputSource", _p_XERCES_CPP_NAMESPACE__MemBufInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource},{"XML::Xerces::StdInInputSource", _p_XERCES_CPP_NAMESPACE__StdInInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource},{"XML::Xerces::LocalFileInputSource", _p_XERCES_CPP_NAMESPACE__LocalFileInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource},{"XML::Xerces::URLInputSource", _p_XERCES_CPP_NAMESPACE__URLInputSourceTo_p_XERCES_CPP_NAMESPACE__InputSource},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap[] = {{"XML::Xerces::DOMNamedNodeMap", 0, "XERCES_CPP_NAMESPACE::DOMNamedNodeMap *", 0},{"XML::Xerces::DOMNamedNodeMap"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMInputSource[] = {{"XML::Xerces::DOMInputSource", 0, "XERCES_CPP_NAMESPACE::DOMInputSource *", 0},{"XML::Xerces::DOMInputSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationSource[] = {{"XML::Xerces::DOMImplementationSource", 0, "XERCES_CPP_NAMESPACE::DOMImplementationSource *", 0},{"XML::Xerces::DOMImplementationSource"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__ReaderMgr[] = {{"_p_XERCES_CPP_NAMESPACE__ReaderMgr", 0, "XERCES_CPP_NAMESPACE::ReaderMgr *", 0},{"_p_XERCES_CPP_NAMESPACE__ReaderMgr"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMNodeList[] = {{"XML::Xerces::DOMNodeList", 0, "XERCES_CPP_NAMESPACE::DOMNodeList *", 0},{"XML::Xerces::DOMNodeList"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__Grammar[] = {{"XML::Xerces::Grammar", 0, "XERCES_CPP_NAMESPACE::Grammar *", 0},{"XML::Xerces::Grammar"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAX2XMLReader[] = {{"XML::Xerces::SAX2XMLReader", 0, "XERCES_CPP_NAMESPACE::SAX2XMLReader *", 0},{"XML::Xerces::SAX2XMLReader"},{0}};
static swig_type_info _swigt__p_SV[] = {{"_p_SV", 0, "SV *", 0},{"_p_SV"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__SAXParser[] = {{"XML::Xerces::SAXParser", 0, "XERCES_CPP_NAMESPACE::SAXParser *", 0},{"XML::Xerces::SAXParser"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMComment[] = {{"XML::Xerces::DOMComment", 0, "XERCES_CPP_NAMESPACE::DOMComment *", 0},{"XML::Xerces::DOMComment"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__HandlerBase[] = {{"XML::Xerces::HandlerBase", 0, "XERCES_CPP_NAMESPACE::HandlerBase *", 0},{"XML::Xerces::HandlerBase"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLUri[] = {{"XML::Xerces::XMLUri", 0, "XERCES_CPP_NAMESPACE::XMLUri *", 0},{"XML::Xerces::XMLUri"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMWriter[] = {{"XML::Xerces::DOMWriter", 0, "XERCES_CPP_NAMESPACE::DOMWriter *", 0},{"XML::Xerces::DOMWriter"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentRange[] = {{"XML::Xerces::DOMDocumentRange", 0, "XERCES_CPP_NAMESPACE::DOMDocumentRange *", 0},{"XML::Xerces::DOMDocumentRange"},{"XML::Xerces::DOMDocument", _p_XERCES_CPP_NAMESPACE__DOMDocumentTo_p_XERCES_CPP_NAMESPACE__DOMDocumentRange},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLTranscoder[] = {{"_p_XERCES_CPP_NAMESPACE__XMLTranscoder", 0, "XERCES_CPP_NAMESPACE::XMLTranscoder *", 0},{"_p_XERCES_CPP_NAMESPACE__XMLTranscoder"},{0}};
static swig_type_info _swigt__p_unsigned_int[] = {{"_p_unsigned_int", 0, "unsigned int *", 0},{"_p_unsigned_int"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__StdOutFormatTarget[] = {{"XML::Xerces::StdOutFormatTarget", 0, "XERCES_CPP_NAMESPACE::StdOutFormatTarget *", 0},{"XML::Xerces::StdOutFormatTarget"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__MemBufFormatTarget[] = {{"XML::Xerces::MemBufFormatTarget", 0, "XERCES_CPP_NAMESPACE::MemBufFormatTarget *", 0},{"XML::Xerces::MemBufFormatTarget"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLFormatTarget[] = {{"XML::Xerces::XMLFormatTarget", 0, "XERCES_CPP_NAMESPACE::XMLFormatTarget *", 0},{"XML::Xerces::XMLFormatTarget"},{"XML::Xerces::MemBufFormatTarget", _p_XERCES_CPP_NAMESPACE__MemBufFormatTargetTo_p_XERCES_CPP_NAMESPACE__XMLFormatTarget},{"XML::Xerces::StdOutFormatTarget", _p_XERCES_CPP_NAMESPACE__StdOutFormatTargetTo_p_XERCES_CPP_NAMESPACE__XMLFormatTarget},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction[] = {{"XML::Xerces::DOMProcessingInstruction", 0, "XERCES_CPP_NAMESPACE::DOMProcessingInstruction *", 0},{"XML::Xerces::DOMProcessingInstruction"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMCDATASection[] = {{"XML::Xerces::DOMCDATASection", 0, "XERCES_CPP_NAMESPACE::DOMCDATASection *", 0},{"XML::Xerces::DOMCDATASection"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__HexBin[] = {{"XML::Xerces::HexBin", 0, "XERCES_CPP_NAMESPACE::HexBin *", 0},{"XML::Xerces::HexBin"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__Base64[] = {{"XML::Xerces::Base64", 0, "XERCES_CPP_NAMESPACE::Base64 *", 0},{"XML::Xerces::Base64"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLPScanToken[] = {{"XML::Xerces::XMLPScanToken", 0, "XERCES_CPP_NAMESPACE::XMLPScanToken *", 0},{"XML::Xerces::XMLPScanToken"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLPlatformUtils[] = {{"XML::Xerces::XMLPlatformUtils", 0, "XERCES_CPP_NAMESPACE::XMLPlatformUtils *", 0},{"XML::Xerces::XMLPlatformUtils"},{0}};
static swig_type_info _swigt__p_PanicHandler__PanicReasons[] = {{"_p_PanicHandler__PanicReasons", 0, "PanicHandler::PanicReasons *", 0},{"_p_PanicHandler__PanicReasons"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__XMLValidator[] = {{"XML::Xerces::XMLValidator", 0, "XERCES_CPP_NAMESPACE::XMLValidator *", 0},{"XML::Xerces::XMLValidator"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMElement[] = {{"XML::Xerces::DOMElement", 0, "XERCES_CPP_NAMESPACE::DOMElement *", 0},{"XML::Xerces::DOMElement"},{0}};
static swig_type_info _swigt__p_XERCES_CPP_NAMESPACE__DOMEntity[] = {{"XML::Xerces::DOMEntity", 0, "XERCES_CPP_NAMESPACE::DOMEntity *", 0},{"XML::Xerces::DOMEntity"},{0}};

static swig_type_info *swig_types_initial[] = {
_swigt__p_XERCES_CPP_NAMESPACE__DOMNodeIterator, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMDocument, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMImplementation, 
_swigt__p_XMLCh, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMConfiguration, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLFormatter, 
_swigt__p_size_t, 
_swigt__p_XMLAttr, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLReaderFactory, 
_swigt__p_XERCES_CPP_NAMESPACE__AttributeList, 
_swigt__p_XMLBuffer, 
_swigt__p_bool, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMNodeFilter, 
_swigt__p_XMLNotationDecl, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLUni, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLExcepts, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentType, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMNode, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLElementDecl, 
_swigt__p_void, 
_swigt__p_p_void, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMRange, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMEntityReference, 
_swigt__p_int, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMNotation, 
_swigt__p_XERCES_CPP_NAMESPACE__SAXParseException, 
_swigt__p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException, 
_swigt__p_XERCES_CPP_NAMESPACE__SAXNotSupportedException, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLException, 
_swigt__p_XERCES_CPP_NAMESPACE__SAXException, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMException, 
_swigt__p_XMLErrorReporter, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLErrorReporter, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMRangeException, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLDeleter, 
_swigt__p_XERCES_CPP_NAMESPACE__Attributes, 
_swigt__FileHandle, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal, 
_swigt__p_XERCES_CPP_NAMESPACE__Parser, 
_swigt__p_XERCES_CPP_NAMESPACE__AbstractDOMParser, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLScanner, 
_swigt__p_XMLReader__XMLVersion, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMAttr, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMBuilder, 
_swigt__p_XERCES_CPP_NAMESPACE__XercesDOMParser, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLURL, 
_swigt__p_XMLAttDef, 
_swigt__p_p_XERCES_CPP_NAMESPACE__QName, 
_swigt__p_XERCES_CPP_NAMESPACE__QName, 
_swigt__p_XERCES_CPP_NAMESPACE__EntityResolver, 
_swigt__p_XERCES_CPP_NAMESPACE__GrammarResolver, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMEntityResolver, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMBuilderFilter, 
_swigt__p_DOMWriterFilter, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMWriterFilter, 
_swigt__p_XERCES_CPP_NAMESPACE__DefaultHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLEntityHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLDocumentHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DeclHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__LexicalHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__ContentHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__ErrorHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DocumentHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DTDHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DocTypeHandler, 
_swigt__p_PanicHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMUserDataHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMErrorHandler, 
_swigt__p_PerlErrorCallbackHandler, 
_swigt__p_PerlDocumentCallbackHandler, 
_swigt__p_PerlContentCallbackHandler, 
_swigt__p_PerlEntityResolverHandler, 
_swigt__p_PerlNodeFilterCallbackHandler, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMTreeWalker, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMText, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationLS, 
_swigt__p_XMLValid__Codes, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLStringPool, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMTypeInfo, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLMsgLoader, 
_swigt__p_XERCES_CPP_NAMESPACE__MemoryManager, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLBufferMgr, 
_swigt__p_XERCES_CPP_NAMESPACE__Locator, 
_swigt__p_SecurityManager, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMLocator, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMCharacterData, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentFragment, 
_swigt__p_XERCES_CPP_NAMESPACE__BinInputStream, 
_swigt__p_XERCES_CPP_NAMESPACE__URLInputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__LocalFileInputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__StdInInputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__MemBufInputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__InputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMInputSource, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMImplementationSource, 
_swigt__p_XERCES_CPP_NAMESPACE__ReaderMgr, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMNodeList, 
_swigt__p_XERCES_CPP_NAMESPACE__Grammar, 
_swigt__p_XERCES_CPP_NAMESPACE__SAX2XMLReader, 
_swigt__p_SV, 
_swigt__p_XERCES_CPP_NAMESPACE__SAXParser, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMComment, 
_swigt__p_XERCES_CPP_NAMESPACE__HandlerBase, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLUri, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMWriter, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMDocumentRange, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLTranscoder, 
_swigt__p_unsigned_int, 
_swigt__p_XERCES_CPP_NAMESPACE__StdOutFormatTarget, 
_swigt__p_XERCES_CPP_NAMESPACE__MemBufFormatTarget, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLFormatTarget, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMCDATASection, 
_swigt__p_XERCES_CPP_NAMESPACE__HexBin, 
_swigt__p_XERCES_CPP_NAMESPACE__Base64, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLPScanToken, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLPlatformUtils, 
_swigt__p_PanicHandler__PanicReasons, 
_swigt__p_XERCES_CPP_NAMESPACE__XMLValidator, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMElement, 
_swigt__p_XERCES_CPP_NAMESPACE__DOMEntity, 
0
};

/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_constant_info swig_constants[] = {
{ SWIG_INT,     (char *) SWIG_prefix "XMLURL_File", (long) XERCES_CPP_NAMESPACE::XMLURL::File, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLURL_HTTP", (long) XERCES_CPP_NAMESPACE::XMLURL::HTTP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLURL_FTP", (long) XERCES_CPP_NAMESPACE::XMLURL::FTP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLURL_Protocols_Count", (long) XERCES_CPP_NAMESPACE::XMLURL::Protocols_Count, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLURL_Unknown", (long) XERCES_CPP_NAMESPACE::XMLURL::Unknown, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NoError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NoError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_W_LowBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::W_LowBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Scan_CouldNotOpenSource_Warning", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Scan_CouldNotOpenSource_Warning, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_GC_ExistingGrammar", (long) XERCES_CPP_NAMESPACE::XMLExcepts::GC_ExistingGrammar, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_W_HighBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::W_HighBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_F_LowBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::F_LowBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Array_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Array_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Array_BadNewSize", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Array_BadNewSize, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_AttrList_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::AttrList_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_AttDef_BadAttType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::AttDef_BadAttType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_AttDef_BadDefAttType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::AttDef_BadDefAttType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Bitset_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Bitset_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Bitset_NotEqualSize", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Bitset_NotEqualSize, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_BufMgr_NoMoreBuffers", (long) XERCES_CPP_NAMESPACE::XMLExcepts::BufMgr_NoMoreBuffers, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_BufMgr_BufferNotInPool", (long) XERCES_CPP_NAMESPACE::XMLExcepts::BufMgr_BufferNotInPool, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CPtr_PointerIsZero", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CPtr_PointerIsZero, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_BinOpHadUnaryType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_BinOpHadUnaryType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_MustBeMixedOrChildren", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_MustBeMixedOrChildren, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_NoPCDATAHere", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_NoPCDATAHere, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_NotValidForSpecType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_NotValidForSpecType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_UnaryOpHadBinType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_UnaryOpHadBinType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_UnknownCMType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_UnknownCMType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_UnknownCMSpecType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_UnknownCMSpecType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_NoParentCSN", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_NoParentCSN, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_CM_NotValidSpecTypeForNode", (long) XERCES_CPP_NAMESPACE::XMLExcepts::CM_NotValidSpecTypeForNode, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DTD_UnknownCreateReason", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DTD_UnknownCreateReason, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_ElemStack_EmptyStack", (long) XERCES_CPP_NAMESPACE::XMLExcepts::ElemStack_EmptyStack, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_ElemStack_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::ElemStack_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_ElemStack_StackUnderflow", (long) XERCES_CPP_NAMESPACE::XMLExcepts::ElemStack_StackUnderflow, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_ElemStack_NoParentPushed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::ElemStack_NoParentPushed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Enum_NoMoreElements", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Enum_NoMoreElements, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotOpenFile", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotOpenFile, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotGetCurPos", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotGetCurPos, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotCloseFile", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotCloseFile, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotSeekToEnd", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotSeekToEnd, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotSeekToPos", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotSeekToPos, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotDupHandle", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotDupHandle, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotReadFromFile", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotReadFromFile, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotWriteToFile", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotWriteToFile, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotResetFile", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotResetFile, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotGetSize", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotGetSize, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_CouldNotGetBasePathName", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_CouldNotGetBasePathName, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_File_BasePathUnderflow", (long) XERCES_CPP_NAMESPACE::XMLExcepts::File_BasePathUnderflow, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_ParseInProgress", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_ParseInProgress, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_NoDTDValidator", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_NoDTDValidator, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_CouldNotOpenDTD", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_CouldNotOpenDTD, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_CouldNotOpenExtEntity", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_CouldNotOpenExtEntity, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_UnexpectedEOF", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_UnexpectedEOF, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_HshTbl_ZeroModulus", (long) XERCES_CPP_NAMESPACE::XMLExcepts::HshTbl_ZeroModulus, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_HshTbl_BadHashFromKey", (long) XERCES_CPP_NAMESPACE::XMLExcepts::HshTbl_BadHashFromKey, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_HshTbl_NoSuchKeyExists", (long) XERCES_CPP_NAMESPACE::XMLExcepts::HshTbl_NoSuchKeyExists, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Mutex_CouldNotCreate", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Mutex_CouldNotCreate, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Mutex_CouldNotClose", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Mutex_CouldNotClose, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Mutex_CouldNotLock", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Mutex_CouldNotLock, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Mutex_CouldNotUnlock", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Mutex_CouldNotUnlock, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Mutex_CouldNotDestroy", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Mutex_CouldNotDestroy, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_InternalError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_InternalError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_LengthError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_LengthError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_InitFailed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_InitFailed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_TargetResolution", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_TargetResolution, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_CreateSocket", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_CreateSocket, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_ConnSocket", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_ConnSocket, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_WriteSocket", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_WriteSocket, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NetAcc_ReadSocket", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NetAcc_ReadSocket, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Pool_ElemAlreadyExists", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Pool_ElemAlreadyExists, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Pool_BadHashFromKey", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Pool_BadHashFromKey, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Pool_InvalidId", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Pool_InvalidId, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Pool_ZeroModulus", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Pool_ZeroModulus, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_RdrMgr_ReaderIdNotFound", (long) XERCES_CPP_NAMESPACE::XMLExcepts::RdrMgr_ReaderIdNotFound, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Reader_BadAutoEncoding", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Reader_BadAutoEncoding, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Reader_CouldNotDecodeFirstLine", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Reader_CouldNotDecodeFirstLine, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Reader_EOIInMultiSeq", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Reader_EOIInMultiSeq, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Reader_SrcOfsNotSupported", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Reader_SrcOfsNotSupported, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Reader_EncodingStrRequired", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Reader_EncodingStrRequired, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Scan_CouldNotOpenSource", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Scan_CouldNotOpenSource, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Scan_UnbalancedStartEnd", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Scan_UnbalancedStartEnd, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Scan_BadPScanToken", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Scan_BadPScanToken, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Stack_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Stack_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Stack_EmptyStack", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Stack_EmptyStack, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Str_ZeroSizedTargetBuf", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Str_ZeroSizedTargetBuf, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Str_UnknownRadix", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Str_UnknownRadix, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Str_TargetBufTooSmall", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Str_TargetBufTooSmall, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Str_StartIndexPastEnd", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Str_StartIndexPastEnd, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Str_ConvertOverflow", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Str_ConvertOverflow, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Strm_StdErrWriteFailure", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Strm_StdErrWriteFailure, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Strm_StdOutWriteFailure", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Strm_StdOutWriteFailure, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Strm_ConWriteFailure", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Strm_ConWriteFailure, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_StrPool_IllegalId", (long) XERCES_CPP_NAMESPACE::XMLExcepts::StrPool_IllegalId, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_CouldNotCreateDefCvtr", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_CouldNotCreateDefCvtr, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_InvalidSizeReq", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_InvalidSizeReq, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_Unrepresentable", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_Unrepresentable, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_NotValidForEncoding", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_NotValidForEncoding, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_BadBlockSize", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_BadBlockSize, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_BadSrcSeq", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_BadSrcSeq, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_BadSrcCP", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_BadSrcCP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_BadTrailingSurrogate", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_BadTrailingSurrogate, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Trans_CantCreateCvtrFor", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Trans_CantCreateCvtrFor, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_MalformedURL", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_MalformedURL, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_UnsupportedProto", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_UnsupportedProto, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_UnsupportedProto1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_UnsupportedProto1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_OnlyLocalHost", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_OnlyLocalHost, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_NoProtocolPresent", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_NoProtocolPresent, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_ExpectingTwoSlashes", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_ExpectingTwoSlashes, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_IncorrectEscapedCharRef", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_IncorrectEscapedCharRef, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_UnterminatedHostComponent", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_UnterminatedHostComponent, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_RelativeBaseURL", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_RelativeBaseURL, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_BaseUnderflow", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_BaseUnderflow, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_URL_BadPortField", (long) XERCES_CPP_NAMESPACE::XMLExcepts::URL_BadPortField, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_UTF8_FormatError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::UTF8_FormatError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Vector_BadIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Vector_BadIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Val_InvalidElemId", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Val_InvalidElemId, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Val_CantHaveIntSS", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Val_CantHaveIntSS, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLRec_UnknownEncoding", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLRec_UnknownEncoding, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Parse1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Parse1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Parse2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Parse2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Next1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Next1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Next2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Next2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Next3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Next3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Next4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Next4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Factor6", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Factor6, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Atom1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Atom1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Atom2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Atom2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Atom3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Atom3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Atom4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Atom4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Atom5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Atom5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_CC6", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_CC6, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Ope1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Ope1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Ope2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Ope2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Ope3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Ope3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Descape1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Descape1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Descape2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Descape2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Descape3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Descape3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Descape4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Descape4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Descape5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Descape5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Process1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Process1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Process2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Process2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Quantifier1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Quantifier1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Quantifier2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Quantifier2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Quantifier3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Quantifier3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Quantifier4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Quantifier4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Parser_Quantifier5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Parser_Quantifier5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Gen_NoSchemaValidator", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Gen_NoSchemaValidator, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XUTIL_UnCopyableNodeType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XUTIL_UnCopyableNodeType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_SubGrpComparator_NGR", (long) XERCES_CPP_NAMESPACE::XMLExcepts::SubGrpComparator_NGR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_Len", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_Len, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_maxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_maxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_minLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_minLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_NonNeg_Len", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_NonNeg_Len, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_NonNeg_maxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_NonNeg_maxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_NonNeg_minLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_NonNeg_minLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Len_maxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Len_maxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Len_minLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Len_minLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxLen_minLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxLen_minLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_bool_Pattern", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_bool_Pattern, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_Tag", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_Tag, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Len_baseLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Len_baseLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minLen_baseminLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minLen_baseminLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minLen_basemaxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minLen_basemaxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxLen_basemaxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxLen_basemaxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxLen_baseminLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxLen_baseminLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Len_baseMinLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Len_baseMinLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Len_baseMaxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Len_baseMaxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minLen_baseLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minLen_baseLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxLen_baseLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxLen_baseLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_enum_base", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_enum_base, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_WS", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_WS, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_WS_collapse", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_WS_collapse, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_WS_replace", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_WS_replace, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_MaxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_MaxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_MaxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_MaxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_MinIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_MinIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_MinExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_MinExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_TotalDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_TotalDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Invalid_FractDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Invalid_FractDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_PosInt_TotalDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_PosInt_TotalDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_NonNeg_FractDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_NonNeg_FractDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_max_Incl_Excl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_max_Incl_Excl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_min_Incl_Excl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_min_Incl_Excl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_TotDigit_FractDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_TotDigit_FractDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_base_maxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_base_maxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_base_maxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_base_maxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_base_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_base_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_base_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_base_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_base_maxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_base_maxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_base_maxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_base_maxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_base_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_base_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_base_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_base_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_base_maxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_base_maxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_base_maxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_base_maxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_base_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_base_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_base_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_base_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_base_maxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_base_maxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_base_maxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_base_maxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_base_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_base_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_base_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_base_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_notFromBase", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_notFromBase, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_notFromBase", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_notFromBase, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_notFromBase", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_notFromBase, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_notFromBase", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_notFromBase, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_totalDigit_base_totalDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_totalDigit_base_totalDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_fractDigit_base_totalDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_fractDigit_base_totalDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_fractDigit_base_fractDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_fractDigit_base_fractDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxIncl_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxIncl_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxExcl_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxExcl_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minIncl_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minIncl_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minExcl_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minExcl_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_totalDigit_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_totalDigit_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_fractDigit_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_fractDigit_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_maxLen_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_maxLen_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_minLen_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_minLen_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_len_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_len_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_whitespace_base_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_whitespace_base_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_internalError_fixed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_internalError_fixed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_List_Null_baseValidator", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_List_Null_baseValidator, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Union_Null_memberTypeValidators", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Union_Null_memberTypeValidators, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Union_Null_baseValidator", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Union_Null_baseValidator, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_FACET_Union_invalid_baseValidatorType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::FACET_Union_invalid_baseValidatorType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_NotMatch_Pattern", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_NotMatch_Pattern, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_Not_Base64", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_Not_Base64, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_Not_HexBin", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_Not_HexBin, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_GT_maxLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_GT_maxLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_LT_minLen", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_LT_minLen, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_NE_Len", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_NE_Len, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_NotIn_Enumeration", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_NotIn_Enumeration, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_totalDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_totalDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_fractDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_fractDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_maxIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_maxIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_maxExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_maxExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_minIncl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_minIncl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_exceed_minExcl", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_exceed_minExcl, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_WS_replaced", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_WS_replaced, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_WS_collapsed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_WS_collapsed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_Invalid_NCName", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_Invalid_NCName, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_Invalid_Name", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_Invalid_Name, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_ID_Not_Unique", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_ID_Not_Unique, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_ENTITY_Invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_ENTITY_Invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_QName_Invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_QName_Invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_NOTATION_Invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_NOTATION_Invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_no_match_memberType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_no_match_memberType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_VALUE_URI_Malformed", (long) XERCES_CPP_NAMESPACE::XMLExcepts::VALUE_URI_Malformed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_emptyString", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_emptyString, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_WSString", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_WSString, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_2ManyDecPoint", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_2ManyDecPoint, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_Inv_chars", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_Inv_chars, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_null_ptr", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_null_ptr, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_Empty", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_Empty, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_for_GenURI_Only", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_for_GenURI_Only, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_Invalid_EscapeSequence", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_Invalid_EscapeSequence, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_Invalid_Char", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_Invalid_Char, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_Set_Null", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_Set_Null, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_Not_Conformant", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_Not_Conformant, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_No_Scheme", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_No_Scheme, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_NullHost", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_NullHost, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_NullPath", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_NullPath, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_Component_inPath", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_Component_inPath, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_URI_PortNo_Invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_URI_PortNo_Invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_DBL_FLT_maxNeg", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_DBL_FLT_maxNeg, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_DBL_FLT_maxPos", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_DBL_FLT_maxPos, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_DBL_FLT_minNegPos", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_DBL_FLT_minNegPos, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_DBL_FLT_InvalidType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_DBL_FLT_InvalidType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XMLNUM_DBL_FLT_No_Exponent", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XMLNUM_DBL_FLT_No_Exponent, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_Result_Not_Set", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_Result_Not_Set, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_CompactRangesError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_CompactRangesError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_MergeRangesTypeMismatch", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_MergeRangesTypeMismatch, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_SubtractRangesError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_SubtractRangesError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_IntersectRangesError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_IntersectRangesError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_ComplementRangesInvalidArg", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_ComplementRangesInvalidArg, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_InvalidCategoryName", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_InvalidCategoryName, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_KeywordNotFound", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_KeywordNotFound, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_BadRefNo", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_BadRefNo, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_UnknownOption", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_UnknownOption, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_UnknownTokenType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_UnknownTokenType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_RangeTokenGetError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_RangeTokenGetError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_NotSupported", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_NotSupported, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_InvalidChildIndex", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_InvalidChildIndex, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_RepPatMatchesZeroString", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_RepPatMatchesZeroString, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Regex_InvalidRepPattern", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Regex_InvalidRepPattern, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NEL_RepeatedCalls", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NEL_RepeatedCalls, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_RethrowError", (long) XERCES_CPP_NAMESPACE::XMLExcepts::RethrowError, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_Out_Of_Memory", (long) XERCES_CPP_NAMESPACE::XMLExcepts::Out_Of_Memory, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DV_InvalidOperation", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DV_InvalidOperation, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoAttrSelector", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoAttrSelector, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoUnionAtStart", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoUnionAtStart, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoMultipleUnion", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoMultipleUnion, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_MissingAttr", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_MissingAttr, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_ExpectedToken1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_ExpectedToken1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_PrefixNoURI", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_PrefixNoURI, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoDoubleColon", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoDoubleColon, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_ExpectedStep1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_ExpectedStep1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_ExpectedStep2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_ExpectedStep2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_ExpectedStep3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_ExpectedStep3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoForwardSlash", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoForwardSlash, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoDoubleForwardSlash", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoDoubleForwardSlash, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoForwardSlashAtStart", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoForwardSlashAtStart, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoSelectionOfRoot", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoSelectionOfRoot, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_EmptyExpr", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_EmptyExpr, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_NoUnionAtEnd", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_NoUnionAtEnd, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_InvalidChar", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_InvalidChar, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_TokenNotSupported", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_TokenNotSupported, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_XPath_FindSolution", (long) XERCES_CPP_NAMESPACE::XMLExcepts::XPath_FindSolution, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_Assert_Buffer_Fail", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_Assert_Buffer_Fail, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dt_missingT", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dt_missingT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_gDay_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_gDay_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_gMth_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_gMth_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_gMthDay_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_gMthDay_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_Start_dashP", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_Start_dashP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_noP", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_noP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_DashNotFirst", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_DashNotFirst, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_inv_b4T", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_inv_b4T, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_NoTimeAfterT", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_NoTimeAfterT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_NoElementAtAll", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_NoElementAtAll, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_dur_inv_seconds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_dur_inv_seconds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_date_incomplete", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_date_incomplete, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_date_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_date_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_time_incomplete", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_time_incomplete, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_time_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_time_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_ms_noDigit", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_ms_noDigit, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_ym_incomplete", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_ym_incomplete, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_ym_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_ym_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_year_tooShort", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_year_tooShort, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_year_leadingZero", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_year_leadingZero, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_ym_noMonth", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_ym_noMonth, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_tz_noUTCsign", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_tz_noUTCsign, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_tz_stuffAfterZ", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_tz_stuffAfterZ, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_tz_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_tz_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_year_zero", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_year_zero, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_mth_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_mth_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_day_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_day_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_hour_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_hour_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_min_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_min_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_second_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_second_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_DateTime_tz_hh_invalid", (long) XERCES_CPP_NAMESPACE::XMLExcepts::DateTime_tz_hh_invalid, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_EmptyBase", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_EmptyBase, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NSCompat1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NSCompat1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_OccurRangeE", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_OccurRangeE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK5", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK5, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK6", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK6, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NameTypeOK7", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NameTypeOK7, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_RecurseAsIfGroup", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_RecurseAsIfGroup, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_Recurse1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_Recurse1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_Recurse2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_Recurse2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_ForbiddenRes1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_ForbiddenRes1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_ForbiddenRes2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_ForbiddenRes2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_ForbiddenRes3", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_ForbiddenRes3, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_ForbiddenRes4", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_ForbiddenRes4, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NSSubset1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NSSubset1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NSSubset2", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NSSubset2, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_NSRecurseCheckCardinality1", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_NSRecurseCheckCardinality1, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_RecurseUnordered", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_RecurseUnordered, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_MapAndSum", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_MapAndSum, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_PD_InvalidContentType", (long) XERCES_CPP_NAMESPACE::XMLExcepts::PD_InvalidContentType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_NodeIDMap_GrowErr", (long) XERCES_CPP_NAMESPACE::XMLExcepts::NodeIDMap_GrowErr, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_F_HighBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::F_HighBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_E_LowBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::E_LowBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLExcepts_E_HighBounds", (long) XERCES_CPP_NAMESPACE::XMLExcepts::E_HighBounds, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_NoEscapes", (long) XERCES_CPP_NAMESPACE::XMLFormatter::NoEscapes, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_StdEscapes", (long) XERCES_CPP_NAMESPACE::XMLFormatter::StdEscapes, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_AttrEscapes", (long) XERCES_CPP_NAMESPACE::XMLFormatter::AttrEscapes, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_CharEscapes", (long) XERCES_CPP_NAMESPACE::XMLFormatter::CharEscapes, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_EscapeFlags_Count", (long) XERCES_CPP_NAMESPACE::XMLFormatter::EscapeFlags_Count, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_DefaultEscape", (long) XERCES_CPP_NAMESPACE::XMLFormatter::DefaultEscape, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_UnRep_Fail", (long) XERCES_CPP_NAMESPACE::XMLFormatter::UnRep_Fail, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_UnRep_CharRef", (long) XERCES_CPP_NAMESPACE::XMLFormatter::UnRep_CharRef, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_UnRep_Replace", (long) XERCES_CPP_NAMESPACE::XMLFormatter::UnRep_Replace, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLFormatter_DefaultUnRep", (long) XERCES_CPP_NAMESPACE::XMLFormatter::DefaultUnRep, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Decl_Text", (long) XERCES_CPP_NAMESPACE::XMLScanner::Decl_Text, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Decl_XML", (long) XERCES_CPP_NAMESPACE::XMLScanner::Decl_XML, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_EntityExp_Pushed", (long) XERCES_CPP_NAMESPACE::XMLScanner::EntityExp_Pushed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_EntityExp_Returned", (long) XERCES_CPP_NAMESPACE::XMLScanner::EntityExp_Returned, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_EntityExp_Failed", (long) XERCES_CPP_NAMESPACE::XMLScanner::EntityExp_Failed, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_CData", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_CData, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_CharData", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_CharData, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_Comment", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_Comment, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_EndTag", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_EndTag, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_EOF", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_EOF, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_PI", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_PI, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_StartTag", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_StartTag, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Token_Unknown", (long) XERCES_CPP_NAMESPACE::XMLScanner::Token_Unknown, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Val_Never", (long) XERCES_CPP_NAMESPACE::XMLScanner::Val_Never, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Val_Always", (long) XERCES_CPP_NAMESPACE::XMLScanner::Val_Always, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLScanner_Val_Auto", (long) XERCES_CPP_NAMESPACE::XMLScanner::Val_Auto, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLErrorReporter_ErrType_Warning", (long) XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrType_Warning, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLErrorReporter_ErrType_Error", (long) XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrType_Error, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLErrorReporter_ErrType_Fatal", (long) XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrType_Fatal, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "XMLErrorReporter_ErrTypes_Unknown", (long) XERCES_CPP_NAMESPACE::XMLErrorReporter::ErrTypes_Unknown, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAX2XMLReader_Val_Never", (long) XERCES_CPP_NAMESPACE::SAX2XMLReader::Val_Never, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAX2XMLReader_Val_Always", (long) XERCES_CPP_NAMESPACE::SAX2XMLReader::Val_Always, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAX2XMLReader_Val_Auto", (long) XERCES_CPP_NAMESPACE::SAX2XMLReader::Val_Auto, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAXParser_Val_Never", (long) XERCES_CPP_NAMESPACE::SAXParser::Val_Never, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAXParser_Val_Always", (long) XERCES_CPP_NAMESPACE::SAXParser::Val_Always, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "SAXParser_Val_Auto", (long) XERCES_CPP_NAMESPACE::SAXParser::Val_Auto, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "Grammar_DTDGrammarType", (long) XERCES_CPP_NAMESPACE::Grammar::DTDGrammarType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "Grammar_SchemaGrammarType", (long) XERCES_CPP_NAMESPACE::Grammar::SchemaGrammarType, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "Grammar_UNKNOWN_SCOPE", (long) XERCES_CPP_NAMESPACE::Grammar::UNKNOWN_SCOPE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "Grammar_TOP_LEVEL_SCOPE", (long) XERCES_CPP_NAMESPACE::Grammar::TOP_LEVEL_SCOPE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INDEX_SIZE_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INDEX_SIZE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_DOMSTRING_SIZE_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::DOMSTRING_SIZE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_HIERARCHY_REQUEST_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::HIERARCHY_REQUEST_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_WRONG_DOCUMENT_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::WRONG_DOCUMENT_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INVALID_CHARACTER_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INVALID_CHARACTER_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_NO_DATA_ALLOWED_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::NO_DATA_ALLOWED_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_NO_MODIFICATION_ALLOWED_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_NOT_FOUND_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::NOT_FOUND_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_NOT_SUPPORTED_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::NOT_SUPPORTED_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INUSE_ATTRIBUTE_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INUSE_ATTRIBUTE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INVALID_STATE_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INVALID_STATE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_SYNTAX_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::SYNTAX_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INVALID_MODIFICATION_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INVALID_MODIFICATION_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_NAMESPACE_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::NAMESPACE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_INVALID_ACCESS_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::INVALID_ACCESS_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMException_VALIDATION_ERR", (long) XERCES_CPP_NAMESPACE::DOMException::VALIDATION_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_FILTER_ACCEPT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::FILTER_ACCEPT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_FILTER_REJECT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::FILTER_REJECT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_FILTER_SKIP", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::FILTER_SKIP, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_ALL", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_ALL, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_ELEMENT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_ELEMENT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_ATTRIBUTE", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_ATTRIBUTE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_TEXT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_TEXT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_CDATA_SECTION", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_CDATA_SECTION, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_ENTITY_REFERENCE", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_ENTITY_REFERENCE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_ENTITY", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_ENTITY, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_PROCESSING_INSTRUCTION", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_PROCESSING_INSTRUCTION, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_COMMENT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_COMMENT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_DOCUMENT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_DOCUMENT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_DOCUMENT_TYPE", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_DOCUMENT_TYPE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_DOCUMENT_FRAGMENT", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_DOCUMENT_FRAGMENT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNodeFilter_SHOW_NOTATION", (long) XERCES_CPP_NAMESPACE::DOMNodeFilter::SHOW_NOTATION, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRange_START_TO_START", (long) XERCES_CPP_NAMESPACE::DOMRange::START_TO_START, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRange_START_TO_END", (long) XERCES_CPP_NAMESPACE::DOMRange::START_TO_END, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRange_END_TO_END", (long) XERCES_CPP_NAMESPACE::DOMRange::END_TO_END, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRange_END_TO_START", (long) XERCES_CPP_NAMESPACE::DOMRange::END_TO_START, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRangeException_BAD_BOUNDARYPOINTS_ERR", (long) XERCES_CPP_NAMESPACE::DOMRangeException::BAD_BOUNDARYPOINTS_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMRangeException_INVALID_NODE_TYPE_ERR", (long) XERCES_CPP_NAMESPACE::DOMRangeException::INVALID_NODE_TYPE_ERR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_ELEMENT_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::ELEMENT_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_ATTRIBUTE_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::ATTRIBUTE_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TEXT_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::TEXT_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_CDATA_SECTION_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::CDATA_SECTION_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_ENTITY_REFERENCE_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::ENTITY_REFERENCE_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_ENTITY_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::ENTITY_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_PROCESSING_INSTRUCTION_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::PROCESSING_INSTRUCTION_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_COMMENT_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::COMMENT_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_DOCUMENT_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::DOCUMENT_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_DOCUMENT_TYPE_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::DOCUMENT_TYPE_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_DOCUMENT_FRAGMENT_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::DOCUMENT_FRAGMENT_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_NOTATION_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::NOTATION_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_PRECEDING", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_PRECEDING, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_FOLLOWING", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_FOLLOWING, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_ANCESTOR", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_ANCESTOR, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_DESCENDANT", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_DESCENDANT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_EQUIVALENT", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_EQUIVALENT, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_SAME_NODE", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_SAME_NODE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMNode_TREE_POSITION_DISCONNECTED", (long) XERCES_CPP_NAMESPACE::DOMNode::TREE_POSITION_DISCONNECTED, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMImplementationLS_MODE_SYNCHRONOUS", (long) XERCES_CPP_NAMESPACE::DOMImplementationLS::MODE_SYNCHRONOUS, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMImplementationLS_MODE_ASYNCHRONOUS", (long) XERCES_CPP_NAMESPACE::DOMImplementationLS::MODE_ASYNCHRONOUS, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMBuilder_ACTION_REPLACE", (long) XERCES_CPP_NAMESPACE::DOMBuilder::ACTION_REPLACE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMBuilder_ACTION_APPEND_AS_CHILDREN", (long) XERCES_CPP_NAMESPACE::DOMBuilder::ACTION_APPEND_AS_CHILDREN, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMBuilder_ACTION_INSERT_AFTER", (long) XERCES_CPP_NAMESPACE::DOMBuilder::ACTION_INSERT_AFTER, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "DOMBuilder_ACTION_INSERT_BEFORE", (long) XERCES_CPP_NAMESPACE::DOMBuilder::ACTION_INSERT_BEFORE, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "AbstractDOMParser_Val_Never", (long) XERCES_CPP_NAMESPACE::AbstractDOMParser::Val_Never, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "AbstractDOMParser_Val_Always", (long) XERCES_CPP_NAMESPACE::AbstractDOMParser::Val_Always, 0, 0, 0},
{ SWIG_INT,     (char *) SWIG_prefix "AbstractDOMParser_Val_Auto", (long) XERCES_CPP_NAMESPACE::AbstractDOMParser::Val_Auto, 0, 0, 0},
{0}
};
#ifdef __cplusplus
}
#endif
static swig_variable_info swig_variables[] = {
    { "XML::Xercesc::DEBUG_UTF8_OUT", MAGIC_CLASS _wrap_set_DEBUG_UTF8_OUT, MAGIC_CLASS _wrap_val_DEBUG_UTF8_OUT,0 },
    { "XML::Xercesc::DEBUG_UTF8_IN", MAGIC_CLASS _wrap_set_DEBUG_UTF8_IN, MAGIC_CLASS _wrap_val_DEBUG_UTF8_IN,0 },
    { "XML::Xercesc::XMLUni_fgAnyString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgAnyString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgAttListString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgAttListString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgCommentString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgCommentString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgCDATAString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgCDATAString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDefaultString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDefaultString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDocTypeString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDocTypeString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEBCDICEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEBCDICEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgElemString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgElemString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEmptyString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEmptyString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEntitString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEntitString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEntityString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEntityString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEntitiesString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEntitiesString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEnumerationString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEnumerationString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgExceptDomain", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgExceptDomain,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgFixedString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgFixedString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM037EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM037EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM037EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM037EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM1140EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM1140EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM1140EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM1140EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM1140EncodingString3", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM1140EncodingString3,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIBM1140EncodingString4", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIBM1140EncodingString4,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIESString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIESString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIDString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIDString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIDRefString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIDRefString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIDRefsString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIDRefsString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgImpliedString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgImpliedString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIgnoreString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIgnoreString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIncludeString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIncludeString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString3", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString3,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString4", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString4,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString5", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString5,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString6", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString6,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString7", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString7,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString8", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString8,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString9", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString9,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString10", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString10,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString11", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString11,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgISO88591EncodingString12", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgISO88591EncodingString12,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgLocalHostString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgLocalHostString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNoString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNoString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNotationString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNotationString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNDATAString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNDATAString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNmTokenString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNmTokenString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNmTokensString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNmTokensString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgPCDATAString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgPCDATAString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgPIString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgPIString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgPubIDString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgPubIDString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgRefString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgRefString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgRequiredString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgRequiredString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgStandaloneString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgStandaloneString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgVersion1_0", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgVersion1_0,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgVersion1_1", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgVersion1_1,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSysIDString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSysIDString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUnknownURIName", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUnknownURIName,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4EncodingString3", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4EncodingString3,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4BEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4BEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4BEncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4BEncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4LEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4LEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUCS4LEncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUCS4LEncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUSASCIIEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUSASCIIEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUSASCIIEncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUSASCIIEncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUSASCIIEncodingString3", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUSASCIIEncodingString3,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUSASCIIEncodingString4", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUSASCIIEncodingString4,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF8EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF8EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF8EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF8EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16EncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16EncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16EncodingString3", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16EncodingString3,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16EncodingString4", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16EncodingString4,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16EncodingString5", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16EncodingString5,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16BEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16BEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16BEncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16BEncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16LEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16LEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTF16LEncodingString2", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTF16LEncodingString2,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgVersionString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgVersionString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgValidityDomain", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgValidityDomain,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgWin1252EncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgWin1252EncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLChEncodingString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLChEncodingString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDOMMsgDomain", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDOMMsgDomain,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringSpace", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringSpace,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringHTab", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringHTab,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringCR", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringCR,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringLF", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringLF,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringSpaceU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringSpaceU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringHTabU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringHTabU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringCRU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringCRU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLStringLFU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLStringLFU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringSpace", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringSpace,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringHTab", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringHTab,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringLF", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringLF,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringCR", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringCR,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringSpaceU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringSpaceU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringHTabU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringHTabU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringLFU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringLFU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLDeclStringCRU", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLDeclStringCRU,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLNSString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLNSString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLNSColonString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLNSColonString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLNSURIName", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLNSURIName,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLErrDomain", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLErrDomain,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLURIName", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLURIName,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgYesString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgYesString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgZeroLenString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgZeroLenString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDTDEntityString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDTDEntityString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgAmp", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgAmp,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgLT", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgLT,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgGT", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgGT,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgQuot", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgQuot,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgApos", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgApos,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgWFXMLScanner", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgWFXMLScanner,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIGXMLScanner", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIGXMLScanner,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSGXMLScanner", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSGXMLScanner,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDGXMLScanner", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDGXMLScanner,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgArrayIndexOutOfBoundsException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgArrayIndexOutOfBoundsException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEmptyStackException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEmptyStackException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIllegalArgumentException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIllegalArgumentException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgInvalidCastException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgInvalidCastException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgIOException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgIOException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNoSuchElementException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNoSuchElementException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNullPointerException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNullPointerException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXMLPlatformUtilsException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXMLPlatformUtilsException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgRuntimeException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgRuntimeException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgTranscodingException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgTranscodingException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUnexpectedEOFException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUnexpectedEOFException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUnsupportedEncodingException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUnsupportedEncodingException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgUTFDataFormatException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgUTFDataFormatException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNetAccessorException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNetAccessorException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgMalformedURLException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgMalformedURLException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNumberFormatException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNumberFormatException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgParseException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgParseException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgInvalidDatatypeFacetException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgInvalidDatatypeFacetException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgInvalidDatatypeValueException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgInvalidDatatypeValueException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSchemaDateTimeException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSchemaDateTimeException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXPathException_Name", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXPathException_Name,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNegINFString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNegINFString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNegZeroString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNegZeroString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgPosZeroString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgPosZeroString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgPosINFString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgPosINFString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNaNString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNaNString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgEString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgEString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgZeroString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgZeroString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgNullString", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgNullString,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesDynamic", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesDynamic,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesSchema", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesSchema,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesSchemaFullChecking", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesSchemaFullChecking,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesSchemaExternalSchemaLocation", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesSchemaExternalSchemaLocation,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesSchemaExternalNoNameSpaceSchemaLocation", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesSchemaExternalNoNameSpaceSchemaLocation,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesSecurityManager", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesSecurityManager,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesLoadExternalDTD", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesLoadExternalDTD,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesContinueAfterFatalError", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesContinueAfterFatalError,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesValidationErrorAsFatal", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesValidationErrorAsFatal,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesUserAdoptsDOMDocument", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesUserAdoptsDOMDocument,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesCacheGrammarFromParse", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesCacheGrammarFromParse,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesUseCachedGrammarInParse", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesUseCachedGrammarInParse,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesScannerName", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesScannerName,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesCalculateSrcOfs", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesCalculateSrcOfs,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercesStandardUriConformant", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercesStandardUriConformant,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSAX2CoreValidation", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSAX2CoreValidation,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSAX2CoreNameSpaces", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSAX2CoreNameSpaces,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgSAX2CoreNameSpacePrefixes", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgSAX2CoreNameSpacePrefixes,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMCanonicalForm", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMCanonicalForm,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMCDATASections", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMCDATASections,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMComments", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMComments,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMCharsetOverridesXMLEncoding", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMCharsetOverridesXMLEncoding,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMDatatypeNormalization", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMDatatypeNormalization,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMEntities", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMEntities,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMInfoset", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMInfoset,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMNamespaces", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMNamespaces,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMNamespaceDeclarations", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMNamespaceDeclarations,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMSupportedMediatypesOnly", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMSupportedMediatypesOnly,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMValidateIfSchema", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMValidateIfSchema,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMValidation", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMValidation,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWhitespaceInElementContent", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWhitespaceInElementContent,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTCanonicalForm", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTCanonicalForm,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTDiscardDefaultContent", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTDiscardDefaultContent,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTEntities", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTEntities,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTFormatPrettyPrint", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTFormatPrettyPrint,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTNormalizeCharacters", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTNormalizeCharacters,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTSplitCdataSections", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTSplitCdataSections,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTValidation", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTValidation,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTWhitespaceInElementContent", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTWhitespaceInElementContent,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgDOMWRTBOM", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgDOMWRTBOM,&SWIGTYPE_p_XMLCh },
    { "XML::Xercesc::XMLUni_fgXercescDefaultLocale", MAGIC_CLASS swig_magic_readonly, MAGIC_CLASS _wrap_val_XMLUni_fgXercescDefaultLocale,0 },
{0}
};
static swig_command_info swig_commands[] = {
{"XML::Xercesc::delete_XMLDeleter", _wrap_delete_XMLDeleter},
{"XML::Xercesc::XMLPlatformUtils_Initialize", _wrap_XMLPlatformUtils_Initialize},
{"XML::Xercesc::XMLPlatformUtils_Terminate", _wrap_XMLPlatformUtils_Terminate},
{"XML::Xercesc::XMLPlatformUtils_panic", _wrap_XMLPlatformUtils_panic},
{"XML::Xercesc::XMLPlatformUtils_curFilePos", _wrap_XMLPlatformUtils_curFilePos},
{"XML::Xercesc::XMLPlatformUtils_closeFile", _wrap_XMLPlatformUtils_closeFile},
{"XML::Xercesc::XMLPlatformUtils_fileSize", _wrap_XMLPlatformUtils_fileSize},
{"XML::Xercesc::XMLPlatformUtils_openFile", _wrap_XMLPlatformUtils_openFile},
{"XML::Xercesc::XMLPlatformUtils_openFileToWrite", _wrap_XMLPlatformUtils_openFileToWrite},
{"XML::Xercesc::XMLPlatformUtils_openStdInHandle", _wrap_XMLPlatformUtils_openStdInHandle},
{"XML::Xercesc::XMLPlatformUtils_readFileBuffer", _wrap_XMLPlatformUtils_readFileBuffer},
{"XML::Xercesc::XMLPlatformUtils_writeBufferToFile", _wrap_XMLPlatformUtils_writeBufferToFile},
{"XML::Xercesc::XMLPlatformUtils_resetFile", _wrap_XMLPlatformUtils_resetFile},
{"XML::Xercesc::XMLPlatformUtils_getFullPath", _wrap_XMLPlatformUtils_getFullPath},
{"XML::Xercesc::XMLPlatformUtils_getCurrentDirectory", _wrap_XMLPlatformUtils_getCurrentDirectory},
{"XML::Xercesc::XMLPlatformUtils_removeDotSlash", _wrap_XMLPlatformUtils_removeDotSlash},
{"XML::Xercesc::XMLPlatformUtils_removeDotDotSlash", _wrap_XMLPlatformUtils_removeDotDotSlash},
{"XML::Xercesc::XMLPlatformUtils_isRelative", _wrap_XMLPlatformUtils_isRelative},
{"XML::Xercesc::XMLPlatformUtils_weavePaths", _wrap_XMLPlatformUtils_weavePaths},
{"XML::Xercesc::XMLPlatformUtils_getCurrentMillis", _wrap_XMLPlatformUtils_getCurrentMillis},
{"XML::Xercesc::XMLPlatformUtils_closeMutex", _wrap_XMLPlatformUtils_closeMutex},
{"XML::Xercesc::XMLPlatformUtils_lockMutex", _wrap_XMLPlatformUtils_lockMutex},
{"XML::Xercesc::XMLPlatformUtils_makeMutex", _wrap_XMLPlatformUtils_makeMutex},
{"XML::Xercesc::XMLPlatformUtils_unlockMutex", _wrap_XMLPlatformUtils_unlockMutex},
{"XML::Xercesc::XMLPlatformUtils_loadMsgSet", _wrap_XMLPlatformUtils_loadMsgSet},
{"XML::Xercesc::XMLPlatformUtils_compareAndSwap", _wrap_XMLPlatformUtils_compareAndSwap},
{"XML::Xercesc::XMLPlatformUtils_atomicIncrement", _wrap_XMLPlatformUtils_atomicIncrement},
{"XML::Xercesc::XMLPlatformUtils_atomicDecrement", _wrap_XMLPlatformUtils_atomicDecrement},
{"XML::Xercesc::XMLPlatformUtils_recognizeNEL", _wrap_XMLPlatformUtils_recognizeNEL},
{"XML::Xercesc::XMLPlatformUtils_isNELRecognized", _wrap_XMLPlatformUtils_isNELRecognized},
{"XML::Xercesc::XMLPlatformUtils_strictIANAEncoding", _wrap_XMLPlatformUtils_strictIANAEncoding},
{"XML::Xercesc::XMLPlatformUtils_isStrictIANAEncoding", _wrap_XMLPlatformUtils_isStrictIANAEncoding},
{"XML::Xercesc::XMLPlatformUtils_alignPointerForNewBlockAllocation", _wrap_XMLPlatformUtils_alignPointerForNewBlockAllocation},
{"XML::Xercesc::new_XMLPlatformUtils", _wrap_new_XMLPlatformUtils},
{"XML::Xercesc::delete_XMLPlatformUtils", _wrap_delete_XMLPlatformUtils},
{"XML::Xercesc::XMLURL_lookupByName", _wrap_XMLURL_lookupByName},
{"XML::Xercesc::new_XMLURL", _wrap_new_XMLURL},
{"XML::Xercesc::delete_XMLURL", _wrap_delete_XMLURL},
{"XML::Xercesc::XMLURL_operator_assignment", _wrap_XMLURL_operator_assignment},
{"XML::Xercesc::XMLURL_operator_equal_to", _wrap_XMLURL_operator_equal_to},
{"XML::Xercesc::XMLURL_operator_not_equal_to", _wrap_XMLURL_operator_not_equal_to},
{"XML::Xercesc::XMLURL_getFragment", _wrap_XMLURL_getFragment},
{"XML::Xercesc::XMLURL_getHost", _wrap_XMLURL_getHost},
{"XML::Xercesc::XMLURL_getPassword", _wrap_XMLURL_getPassword},
{"XML::Xercesc::XMLURL_getPath", _wrap_XMLURL_getPath},
{"XML::Xercesc::XMLURL_getPortNum", _wrap_XMLURL_getPortNum},
{"XML::Xercesc::XMLURL_getProtocol", _wrap_XMLURL_getProtocol},
{"XML::Xercesc::XMLURL_getProtocolName", _wrap_XMLURL_getProtocolName},
{"XML::Xercesc::XMLURL_getQuery", _wrap_XMLURL_getQuery},
{"XML::Xercesc::XMLURL_getURLText", _wrap_XMLURL_getURLText},
{"XML::Xercesc::XMLURL_getUser", _wrap_XMLURL_getUser},
{"XML::Xercesc::XMLURL_getMemoryManager", _wrap_XMLURL_getMemoryManager},
{"XML::Xercesc::XMLURL_setURL", _wrap_XMLURL_setURL},
{"XML::Xercesc::XMLURL_isRelative", _wrap_XMLURL_isRelative},
{"XML::Xercesc::XMLURL_hasInvalidChar", _wrap_XMLURL_hasInvalidChar},
{"XML::Xercesc::XMLURL_makeNewStream", _wrap_XMLURL_makeNewStream},
{"XML::Xercesc::XMLURL_makeRelativeTo", _wrap_XMLURL_makeRelativeTo},
{"XML::Xercesc::new_XMLUri", _wrap_new_XMLUri},
{"XML::Xercesc::XMLUri_operator_assignment", _wrap_XMLUri_operator_assignment},
{"XML::Xercesc::delete_XMLUri", _wrap_delete_XMLUri},
{"XML::Xercesc::XMLUri_getUriText", _wrap_XMLUri_getUriText},
{"XML::Xercesc::XMLUri_getScheme", _wrap_XMLUri_getScheme},
{"XML::Xercesc::XMLUri_getUserInfo", _wrap_XMLUri_getUserInfo},
{"XML::Xercesc::XMLUri_getHost", _wrap_XMLUri_getHost},
{"XML::Xercesc::XMLUri_getPort", _wrap_XMLUri_getPort},
{"XML::Xercesc::XMLUri_getPath", _wrap_XMLUri_getPath},
{"XML::Xercesc::XMLUri_getQueryString", _wrap_XMLUri_getQueryString},
{"XML::Xercesc::XMLUri_getFragment", _wrap_XMLUri_getFragment},
{"XML::Xercesc::XMLUri_setScheme", _wrap_XMLUri_setScheme},
{"XML::Xercesc::XMLUri_setUserInfo", _wrap_XMLUri_setUserInfo},
{"XML::Xercesc::XMLUri_setHost", _wrap_XMLUri_setHost},
{"XML::Xercesc::XMLUri_setPort", _wrap_XMLUri_setPort},
{"XML::Xercesc::XMLUri_setPath", _wrap_XMLUri_setPath},
{"XML::Xercesc::XMLUri_setQueryString", _wrap_XMLUri_setQueryString},
{"XML::Xercesc::XMLUri_setFragment", _wrap_XMLUri_setFragment},
{"XML::Xercesc::XMLUri_isURIString", _wrap_XMLUri_isURIString},
{"XML::Xercesc::new_QName", _wrap_new_QName},
{"XML::Xercesc::delete_QName", _wrap_delete_QName},
{"XML::Xercesc::QName_getPrefix", _wrap_QName_getPrefix},
{"XML::Xercesc::QName_getLocalPart", _wrap_QName_getLocalPart},
{"XML::Xercesc::QName_getRawName", _wrap_QName_getRawName},
{"XML::Xercesc::QName_getMemoryManager", _wrap_QName_getMemoryManager},
{"XML::Xercesc::QName_setName", _wrap_QName_setName},
{"XML::Xercesc::QName_setPrefix", _wrap_QName_setPrefix},
{"XML::Xercesc::QName_setLocalPart", _wrap_QName_setLocalPart},
{"XML::Xercesc::QName_setNPrefix", _wrap_QName_setNPrefix},
{"XML::Xercesc::QName_setNLocalPart", _wrap_QName_setNLocalPart},
{"XML::Xercesc::QName_setURI", _wrap_QName_setURI},
{"XML::Xercesc::QName_setValues", _wrap_QName_setValues},
{"XML::Xercesc::QName_operator_equal_to", _wrap_QName_operator_equal_to},
{"XML::Xercesc::QName_cleanUp", _wrap_QName_cleanUp},
{"XML::Xercesc::HexBin_getDataLength", _wrap_HexBin_getDataLength},
{"XML::Xercesc::HexBin_isArrayByteHex", _wrap_HexBin_isArrayByteHex},
{"XML::Xercesc::delete_HexBin", _wrap_delete_HexBin},
{"XML::Xercesc::Base64_encode", _wrap_Base64_encode},
{"XML::Xercesc::Base64_decode", _wrap_Base64_decode},
{"XML::Xercesc::Base64_getDataLength", _wrap_Base64_getDataLength},
{"XML::Xercesc::delete_Base64", _wrap_delete_Base64},
{"XML::Xercesc::new_XMLExcepts", _wrap_new_XMLExcepts},
{"XML::Xercesc::delete_XMLExcepts", _wrap_delete_XMLExcepts},
{"XML::Xercesc::delete_XMLException", _wrap_delete_XMLException},
{"XML::Xercesc::XMLException_getType", _wrap_XMLException_getType},
{"XML::Xercesc::XMLException_getCode", _wrap_XMLException_getCode},
{"XML::Xercesc::XMLException_getMessage", _wrap_XMLException_getMessage},
{"XML::Xercesc::XMLException_getSrcFile", _wrap_XMLException_getSrcFile},
{"XML::Xercesc::XMLException_getSrcLine", _wrap_XMLException_getSrcLine},
{"XML::Xercesc::XMLException_getErrorType", _wrap_XMLException_getErrorType},
{"XML::Xercesc::XMLException_setPosition", _wrap_XMLException_setPosition},
{"XML::Xercesc::XMLException_operator_assignment", _wrap_XMLException_operator_assignment},
{"XML::Xercesc::XMLException_reinitMsgMutex", _wrap_XMLException_reinitMsgMutex},
{"XML::Xercesc::XMLException_reinitMsgLoader", _wrap_XMLException_reinitMsgLoader},
{"XML::Xercesc::delete_XMLValidator", _wrap_delete_XMLValidator},
{"XML::Xercesc::XMLValidator_checkContent", _wrap_XMLValidator_checkContent},
{"XML::Xercesc::XMLValidator_faultInAttr", _wrap_XMLValidator_faultInAttr},
{"XML::Xercesc::XMLValidator_preContentValidation", _wrap_XMLValidator_preContentValidation},
{"XML::Xercesc::XMLValidator_postParseValidation", _wrap_XMLValidator_postParseValidation},
{"XML::Xercesc::XMLValidator_reset", _wrap_XMLValidator_reset},
{"XML::Xercesc::XMLValidator_requiresNamespaces", _wrap_XMLValidator_requiresNamespaces},
{"XML::Xercesc::XMLValidator_validateAttrValue", _wrap_XMLValidator_validateAttrValue},
{"XML::Xercesc::XMLValidator_validateElement", _wrap_XMLValidator_validateElement},
{"XML::Xercesc::XMLValidator_getGrammar", _wrap_XMLValidator_getGrammar},
{"XML::Xercesc::XMLValidator_setGrammar", _wrap_XMLValidator_setGrammar},
{"XML::Xercesc::XMLValidator_handlesDTD", _wrap_XMLValidator_handlesDTD},
{"XML::Xercesc::XMLValidator_handlesSchema", _wrap_XMLValidator_handlesSchema},
{"XML::Xercesc::XMLValidator_setScannerInfo", _wrap_XMLValidator_setScannerInfo},
{"XML::Xercesc::XMLValidator_setErrorReporter", _wrap_XMLValidator_setErrorReporter},
{"XML::Xercesc::XMLValidator_emitError", _wrap_XMLValidator_emitError},
{"XML::Xercesc::XMLValidator_checkRootElement", _wrap_XMLValidator_checkRootElement},
{"XML::Xercesc::XMLValidator_reinitMsgMutex", _wrap_XMLValidator_reinitMsgMutex},
{"XML::Xercesc::XMLValidator_reinitMsgLoader", _wrap_XMLValidator_reinitMsgLoader},
{"XML::Xercesc::new_SAXException", _wrap_new_SAXException},
{"XML::Xercesc::delete_SAXException", _wrap_delete_SAXException},
{"XML::Xercesc::SAXException_operator_assignment", _wrap_SAXException_operator_assignment},
{"XML::Xercesc::SAXException_getMessage", _wrap_SAXException_getMessage},
{"XML::Xercesc::new_SAXNotSupportedException", _wrap_new_SAXNotSupportedException},
{"XML::Xercesc::delete_SAXNotSupportedException", _wrap_delete_SAXNotSupportedException},
{"XML::Xercesc::new_SAXNotRecognizedException", _wrap_new_SAXNotRecognizedException},
{"XML::Xercesc::delete_SAXNotRecognizedException", _wrap_delete_SAXNotRecognizedException},
{"XML::Xercesc::new_SAXParseException", _wrap_new_SAXParseException},
{"XML::Xercesc::delete_SAXParseException", _wrap_delete_SAXParseException},
{"XML::Xercesc::SAXParseException_operator_assignment", _wrap_SAXParseException_operator_assignment},
{"XML::Xercesc::SAXParseException_getColumnNumber", _wrap_SAXParseException_getColumnNumber},
{"XML::Xercesc::SAXParseException_getLineNumber", _wrap_SAXParseException_getLineNumber},
{"XML::Xercesc::SAXParseException_getPublicId", _wrap_SAXParseException_getPublicId},
{"XML::Xercesc::SAXParseException_getSystemId", _wrap_SAXParseException_getSystemId},
{"XML::Xercesc::delete_ErrorHandler", _wrap_delete_ErrorHandler},
{"XML::Xercesc::ErrorHandler_warning", _wrap_ErrorHandler_warning},
{"XML::Xercesc::ErrorHandler_error", _wrap_ErrorHandler_error},
{"XML::Xercesc::ErrorHandler_fatalError", _wrap_ErrorHandler_fatalError},
{"XML::Xercesc::ErrorHandler_resetErrors", _wrap_ErrorHandler_resetErrors},
{"XML::Xercesc::delete_DTDHandler", _wrap_delete_DTDHandler},
{"XML::Xercesc::DTDHandler_notationDecl", _wrap_DTDHandler_notationDecl},
{"XML::Xercesc::DTDHandler_unparsedEntityDecl", _wrap_DTDHandler_unparsedEntityDecl},
{"XML::Xercesc::DTDHandler_resetDocType", _wrap_DTDHandler_resetDocType},
{"XML::Xercesc::delete_DocumentHandler", _wrap_delete_DocumentHandler},
{"XML::Xercesc::DocumentHandler_characters", _wrap_DocumentHandler_characters},
{"XML::Xercesc::DocumentHandler_endDocument", _wrap_DocumentHandler_endDocument},
{"XML::Xercesc::DocumentHandler_endElement", _wrap_DocumentHandler_endElement},
{"XML::Xercesc::DocumentHandler_ignorableWhitespace", _wrap_DocumentHandler_ignorableWhitespace},
{"XML::Xercesc::DocumentHandler_processingInstruction", _wrap_DocumentHandler_processingInstruction},
{"XML::Xercesc::DocumentHandler_resetDocument", _wrap_DocumentHandler_resetDocument},
{"XML::Xercesc::DocumentHandler_setDocumentLocator", _wrap_DocumentHandler_setDocumentLocator},
{"XML::Xercesc::DocumentHandler_startDocument", _wrap_DocumentHandler_startDocument},
{"XML::Xercesc::DocumentHandler_startElement", _wrap_DocumentHandler_startElement},
{"XML::Xercesc::delete_EntityResolver", _wrap_delete_EntityResolver},
{"XML::Xercesc::EntityResolver_resolveEntity", _wrap_EntityResolver_resolveEntity},
{"XML::Xercesc::delete_AttributeList", _wrap_delete_AttributeList},
{"XML::Xercesc::AttributeList_getLength", _wrap_AttributeList_getLength},
{"XML::Xercesc::AttributeList_getName", _wrap_AttributeList_getName},
{"XML::Xercesc::AttributeList_getType", _wrap_AttributeList_getType},
{"XML::Xercesc::AttributeList_getType__overload__name", _wrap_AttributeList_getType__overload__name},
{"XML::Xercesc::AttributeList_getValue__overload__name", _wrap_AttributeList_getValue__overload__name},
{"XML::Xercesc::AttributeList_getValue", _wrap_AttributeList_getValue},
{"XML::Xercesc::HandlerBase_characters", _wrap_HandlerBase_characters},
{"XML::Xercesc::HandlerBase_endDocument", _wrap_HandlerBase_endDocument},
{"XML::Xercesc::HandlerBase_endElement", _wrap_HandlerBase_endElement},
{"XML::Xercesc::HandlerBase_ignorableWhitespace", _wrap_HandlerBase_ignorableWhitespace},
{"XML::Xercesc::HandlerBase_processingInstruction", _wrap_HandlerBase_processingInstruction},
{"XML::Xercesc::HandlerBase_resetDocument", _wrap_HandlerBase_resetDocument},
{"XML::Xercesc::HandlerBase_setDocumentLocator", _wrap_HandlerBase_setDocumentLocator},
{"XML::Xercesc::HandlerBase_startDocument", _wrap_HandlerBase_startDocument},
{"XML::Xercesc::HandlerBase_startElement", _wrap_HandlerBase_startElement},
{"XML::Xercesc::HandlerBase_resolveEntity", _wrap_HandlerBase_resolveEntity},
{"XML::Xercesc::HandlerBase_error", _wrap_HandlerBase_error},
{"XML::Xercesc::HandlerBase_fatalError", _wrap_HandlerBase_fatalError},
{"XML::Xercesc::HandlerBase_warning", _wrap_HandlerBase_warning},
{"XML::Xercesc::HandlerBase_resetErrors", _wrap_HandlerBase_resetErrors},
{"XML::Xercesc::HandlerBase_notationDecl", _wrap_HandlerBase_notationDecl},
{"XML::Xercesc::HandlerBase_resetDocType", _wrap_HandlerBase_resetDocType},
{"XML::Xercesc::HandlerBase_unparsedEntityDecl", _wrap_HandlerBase_unparsedEntityDecl},
{"XML::Xercesc::new_HandlerBase", _wrap_new_HandlerBase},
{"XML::Xercesc::delete_HandlerBase", _wrap_delete_HandlerBase},
{"XML::Xercesc::delete_Locator", _wrap_delete_Locator},
{"XML::Xercesc::Locator_getPublicId", _wrap_Locator_getPublicId},
{"XML::Xercesc::Locator_getSystemId", _wrap_Locator_getSystemId},
{"XML::Xercesc::Locator_getLineNumber", _wrap_Locator_getLineNumber},
{"XML::Xercesc::Locator_getColumnNumber", _wrap_Locator_getColumnNumber},
{"XML::Xercesc::delete_Attributes", _wrap_delete_Attributes},
{"XML::Xercesc::Attributes_getLength", _wrap_Attributes_getLength},
{"XML::Xercesc::Attributes_getURI", _wrap_Attributes_getURI},
{"XML::Xercesc::Attributes_getLocalName", _wrap_Attributes_getLocalName},
{"XML::Xercesc::Attributes_getQName", _wrap_Attributes_getQName},
{"XML::Xercesc::Attributes_getIndex", _wrap_Attributes_getIndex},
{"XML::Xercesc::Attributes_getType", _wrap_Attributes_getType},
{"XML::Xercesc::Attributes_getType__overload__name", _wrap_Attributes_getType__overload__name},
{"XML::Xercesc::Attributes_getValue", _wrap_Attributes_getValue},
{"XML::Xercesc::Attributes_getValue__overload__name", _wrap_Attributes_getValue__overload__name},
{"XML::Xercesc::delete_ContentHandler", _wrap_delete_ContentHandler},
{"XML::Xercesc::ContentHandler_characters", _wrap_ContentHandler_characters},
{"XML::Xercesc::ContentHandler_endDocument", _wrap_ContentHandler_endDocument},
{"XML::Xercesc::ContentHandler_endElement", _wrap_ContentHandler_endElement},
{"XML::Xercesc::ContentHandler_ignorableWhitespace", _wrap_ContentHandler_ignorableWhitespace},
{"XML::Xercesc::ContentHandler_processingInstruction", _wrap_ContentHandler_processingInstruction},
{"XML::Xercesc::ContentHandler_setDocumentLocator", _wrap_ContentHandler_setDocumentLocator},
{"XML::Xercesc::ContentHandler_startDocument", _wrap_ContentHandler_startDocument},
{"XML::Xercesc::ContentHandler_startElement", _wrap_ContentHandler_startElement},
{"XML::Xercesc::ContentHandler_startPrefixMapping", _wrap_ContentHandler_startPrefixMapping},
{"XML::Xercesc::ContentHandler_endPrefixMapping", _wrap_ContentHandler_endPrefixMapping},
{"XML::Xercesc::ContentHandler_skippedEntity", _wrap_ContentHandler_skippedEntity},
{"XML::Xercesc::delete_LexicalHandler", _wrap_delete_LexicalHandler},
{"XML::Xercesc::LexicalHandler_comment", _wrap_LexicalHandler_comment},
{"XML::Xercesc::LexicalHandler_endCDATA", _wrap_LexicalHandler_endCDATA},
{"XML::Xercesc::LexicalHandler_endDTD", _wrap_LexicalHandler_endDTD},
{"XML::Xercesc::LexicalHandler_endEntity", _wrap_LexicalHandler_endEntity},
{"XML::Xercesc::LexicalHandler_startCDATA", _wrap_LexicalHandler_startCDATA},
{"XML::Xercesc::LexicalHandler_startDTD", _wrap_LexicalHandler_startDTD},
{"XML::Xercesc::LexicalHandler_startEntity", _wrap_LexicalHandler_startEntity},
{"XML::Xercesc::delete_DeclHandler", _wrap_delete_DeclHandler},
{"XML::Xercesc::DeclHandler_elementDecl", _wrap_DeclHandler_elementDecl},
{"XML::Xercesc::DeclHandler_attributeDecl", _wrap_DeclHandler_attributeDecl},
{"XML::Xercesc::DeclHandler_internalEntityDecl", _wrap_DeclHandler_internalEntityDecl},
{"XML::Xercesc::DeclHandler_externalEntityDecl", _wrap_DeclHandler_externalEntityDecl},
{"XML::Xercesc::DefaultHandler_characters", _wrap_DefaultHandler_characters},
{"XML::Xercesc::DefaultHandler_endDocument", _wrap_DefaultHandler_endDocument},
{"XML::Xercesc::DefaultHandler_endElement", _wrap_DefaultHandler_endElement},
{"XML::Xercesc::DefaultHandler_ignorableWhitespace", _wrap_DefaultHandler_ignorableWhitespace},
{"XML::Xercesc::DefaultHandler_processingInstruction", _wrap_DefaultHandler_processingInstruction},
{"XML::Xercesc::DefaultHandler_resetDocument", _wrap_DefaultHandler_resetDocument},
{"XML::Xercesc::DefaultHandler_setDocumentLocator", _wrap_DefaultHandler_setDocumentLocator},
{"XML::Xercesc::DefaultHandler_startDocument", _wrap_DefaultHandler_startDocument},
{"XML::Xercesc::DefaultHandler_startElement", _wrap_DefaultHandler_startElement},
{"XML::Xercesc::DefaultHandler_startPrefixMapping", _wrap_DefaultHandler_startPrefixMapping},
{"XML::Xercesc::DefaultHandler_endPrefixMapping", _wrap_DefaultHandler_endPrefixMapping},
{"XML::Xercesc::DefaultHandler_skippedEntity", _wrap_DefaultHandler_skippedEntity},
{"XML::Xercesc::DefaultHandler_resolveEntity", _wrap_DefaultHandler_resolveEntity},
{"XML::Xercesc::DefaultHandler_error", _wrap_DefaultHandler_error},
{"XML::Xercesc::DefaultHandler_fatalError", _wrap_DefaultHandler_fatalError},
{"XML::Xercesc::DefaultHandler_warning", _wrap_DefaultHandler_warning},
{"XML::Xercesc::DefaultHandler_resetErrors", _wrap_DefaultHandler_resetErrors},
{"XML::Xercesc::DefaultHandler_notationDecl", _wrap_DefaultHandler_notationDecl},
{"XML::Xercesc::DefaultHandler_resetDocType", _wrap_DefaultHandler_resetDocType},
{"XML::Xercesc::DefaultHandler_unparsedEntityDecl", _wrap_DefaultHandler_unparsedEntityDecl},
{"XML::Xercesc::DefaultHandler_comment", _wrap_DefaultHandler_comment},
{"XML::Xercesc::DefaultHandler_endCDATA", _wrap_DefaultHandler_endCDATA},
{"XML::Xercesc::DefaultHandler_endDTD", _wrap_DefaultHandler_endDTD},
{"XML::Xercesc::DefaultHandler_endEntity", _wrap_DefaultHandler_endEntity},
{"XML::Xercesc::DefaultHandler_startCDATA", _wrap_DefaultHandler_startCDATA},
{"XML::Xercesc::DefaultHandler_startDTD", _wrap_DefaultHandler_startDTD},
{"XML::Xercesc::DefaultHandler_startEntity", _wrap_DefaultHandler_startEntity},
{"XML::Xercesc::DefaultHandler_elementDecl", _wrap_DefaultHandler_elementDecl},
{"XML::Xercesc::DefaultHandler_attributeDecl", _wrap_DefaultHandler_attributeDecl},
{"XML::Xercesc::DefaultHandler_internalEntityDecl", _wrap_DefaultHandler_internalEntityDecl},
{"XML::Xercesc::DefaultHandler_externalEntityDecl", _wrap_DefaultHandler_externalEntityDecl},
{"XML::Xercesc::new_DefaultHandler", _wrap_new_DefaultHandler},
{"XML::Xercesc::delete_DefaultHandler", _wrap_delete_DefaultHandler},
{"XML::Xercesc::delete_InputSource", _wrap_delete_InputSource},
{"XML::Xercesc::InputSource_makeStream", _wrap_InputSource_makeStream},
{"XML::Xercesc::InputSource_getEncoding", _wrap_InputSource_getEncoding},
{"XML::Xercesc::InputSource_getPublicId", _wrap_InputSource_getPublicId},
{"XML::Xercesc::InputSource_getSystemId", _wrap_InputSource_getSystemId},
{"XML::Xercesc::InputSource_getIssueFatalErrorIfNotFound", _wrap_InputSource_getIssueFatalErrorIfNotFound},
{"XML::Xercesc::InputSource_getMemoryManager", _wrap_InputSource_getMemoryManager},
{"XML::Xercesc::InputSource_setEncoding", _wrap_InputSource_setEncoding},
{"XML::Xercesc::InputSource_setPublicId", _wrap_InputSource_setPublicId},
{"XML::Xercesc::InputSource_setSystemId", _wrap_InputSource_setSystemId},
{"XML::Xercesc::InputSource_setIssueFatalErrorIfNotFound", _wrap_InputSource_setIssueFatalErrorIfNotFound},
{"XML::Xercesc::new_MemBufInputSource", _wrap_new_MemBufInputSource},
{"XML::Xercesc::delete_MemBufInputSource", _wrap_delete_MemBufInputSource},
{"XML::Xercesc::MemBufInputSource_makeStream", _wrap_MemBufInputSource_makeStream},
{"XML::Xercesc::MemBufInputSource_setCopyBufToStream", _wrap_MemBufInputSource_setCopyBufToStream},
{"XML::Xercesc::new_StdInInputSource", _wrap_new_StdInInputSource},
{"XML::Xercesc::delete_StdInInputSource", _wrap_delete_StdInInputSource},
{"XML::Xercesc::StdInInputSource_makeStream", _wrap_StdInInputSource_makeStream},
{"XML::Xercesc::new_LocalFileInputSource", _wrap_new_LocalFileInputSource},
{"XML::Xercesc::delete_LocalFileInputSource", _wrap_delete_LocalFileInputSource},
{"XML::Xercesc::LocalFileInputSource_makeStream", _wrap_LocalFileInputSource_makeStream},
{"XML::Xercesc::new_URLInputSource", _wrap_new_URLInputSource},
{"XML::Xercesc::delete_URLInputSource", _wrap_delete_URLInputSource},
{"XML::Xercesc::URLInputSource_makeStream", _wrap_URLInputSource_makeStream},
{"XML::Xercesc::URLInputSource_urlSrc", _wrap_URLInputSource_urlSrc},
{"XML::Xercesc::new_XMLFormatter", _wrap_new_XMLFormatter},
{"XML::Xercesc::delete_XMLFormatter", _wrap_delete_XMLFormatter},
{"XML::Xercesc::XMLFormatter_formatBuf", _wrap_XMLFormatter_formatBuf},
{"XML::Xercesc::XMLFormatter_writeBOM", _wrap_XMLFormatter_writeBOM},
{"XML::Xercesc::XMLFormatter_getEncodingName", _wrap_XMLFormatter_getEncodingName},
{"XML::Xercesc::XMLFormatter_getTranscoder", _wrap_XMLFormatter_getTranscoder},
{"XML::Xercesc::XMLFormatter_setEscapeFlags", _wrap_XMLFormatter_setEscapeFlags},
{"XML::Xercesc::XMLFormatter_setUnRepFlags", _wrap_XMLFormatter_setUnRepFlags},
{"XML::Xercesc::delete_XMLFormatTarget", _wrap_delete_XMLFormatTarget},
{"XML::Xercesc::XMLFormatTarget_writeChars", _wrap_XMLFormatTarget_writeChars},
{"XML::Xercesc::XMLFormatTarget_flush", _wrap_XMLFormatTarget_flush},
{"XML::Xercesc::new_MemBufFormatTarget", _wrap_new_MemBufFormatTarget},
{"XML::Xercesc::delete_MemBufFormatTarget", _wrap_delete_MemBufFormatTarget},
{"XML::Xercesc::MemBufFormatTarget_writeChars", _wrap_MemBufFormatTarget_writeChars},
{"XML::Xercesc::MemBufFormatTarget_getRawBuffer", _wrap_MemBufFormatTarget_getRawBuffer},
{"XML::Xercesc::MemBufFormatTarget_getLen", _wrap_MemBufFormatTarget_getLen},
{"XML::Xercesc::MemBufFormatTarget_reset", _wrap_MemBufFormatTarget_reset},
{"XML::Xercesc::new_StdOutFormatTarget", _wrap_new_StdOutFormatTarget},
{"XML::Xercesc::delete_StdOutFormatTarget", _wrap_delete_StdOutFormatTarget},
{"XML::Xercesc::StdOutFormatTarget_writeChars", _wrap_StdOutFormatTarget_writeChars},
{"XML::Xercesc::StdOutFormatTarget_flush", _wrap_StdOutFormatTarget_flush},
{"XML::Xercesc::new_XMLUni", _wrap_new_XMLUni},
{"XML::Xercesc::delete_XMLUni", _wrap_delete_XMLUni},
{"XML::Xercesc::delete_XMLScanner", _wrap_delete_XMLScanner},
{"XML::Xercesc::XMLScanner_getName", _wrap_XMLScanner_getName},
{"XML::Xercesc::XMLScanner_resolveQName", _wrap_XMLScanner_resolveQName},
{"XML::Xercesc::XMLScanner_scanNext", _wrap_XMLScanner_scanNext},
{"XML::Xercesc::XMLScanner_getErrorHandler", _wrap_XMLScanner_getErrorHandler},
{"XML::Xercesc::XMLScanner_getReaderMgr", _wrap_XMLScanner_getReaderMgr},
{"XML::Xercesc::XMLScanner_getSrcOffset", _wrap_XMLScanner_getSrcOffset},
{"XML::Xercesc::XMLScanner_getSecurityManager", _wrap_XMLScanner_getSecurityManager},
{"XML::Xercesc::XMLScanner_getLoadExternalDTD", _wrap_XMLScanner_getLoadExternalDTD},
{"XML::Xercesc::XMLScanner_getNormalizeData", _wrap_XMLScanner_getNormalizeData},
{"XML::Xercesc::XMLScanner_isCachingGrammarFromParse", _wrap_XMLScanner_isCachingGrammarFromParse},
{"XML::Xercesc::XMLScanner_isUsingCachedGrammarInParse", _wrap_XMLScanner_isUsingCachedGrammarInParse},
{"XML::Xercesc::XMLScanner_getCalculateSrcOfs", _wrap_XMLScanner_getCalculateSrcOfs},
{"XML::Xercesc::XMLScanner_getRootGrammar", _wrap_XMLScanner_getRootGrammar},
{"XML::Xercesc::XMLScanner_getXMLVersion", _wrap_XMLScanner_getXMLVersion},
{"XML::Xercesc::XMLScanner_getMemoryManager", _wrap_XMLScanner_getMemoryManager},
{"XML::Xercesc::XMLScanner_getEmptyNamespaceId", _wrap_XMLScanner_getEmptyNamespaceId},
{"XML::Xercesc::XMLScanner_getUnknownNamespaceId", _wrap_XMLScanner_getUnknownNamespaceId},
{"XML::Xercesc::XMLScanner_getXMLNamespaceId", _wrap_XMLScanner_getXMLNamespaceId},
{"XML::Xercesc::XMLScanner_getXMLNSNamespaceId", _wrap_XMLScanner_getXMLNSNamespaceId},
{"XML::Xercesc::XMLScanner_isValidatorFromUser", _wrap_XMLScanner_isValidatorFromUser},
{"XML::Xercesc::XMLScanner_getStandardUriConformant", _wrap_XMLScanner_getStandardUriConformant},
{"XML::Xercesc::XMLScanner_setDocHandler", _wrap_XMLScanner_setDocHandler},
{"XML::Xercesc::XMLScanner_setDocTypeHandler", _wrap_XMLScanner_setDocTypeHandler},
{"XML::Xercesc::XMLScanner_setDoNamespaces", _wrap_XMLScanner_setDoNamespaces},
{"XML::Xercesc::XMLScanner_setEntityHandler", _wrap_XMLScanner_setEntityHandler},
{"XML::Xercesc::XMLScanner_setErrorReporter", _wrap_XMLScanner_setErrorReporter},
{"XML::Xercesc::XMLScanner_setErrorHandler", _wrap_XMLScanner_setErrorHandler},
{"XML::Xercesc::XMLScanner_setGrammarResolver", _wrap_XMLScanner_setGrammarResolver},
{"XML::Xercesc::XMLScanner_setURIStringPool", _wrap_XMLScanner_setURIStringPool},
{"XML::Xercesc::XMLScanner_setExitOnFirstFatal", _wrap_XMLScanner_setExitOnFirstFatal},
{"XML::Xercesc::XMLScanner_setValidationConstraintFatal", _wrap_XMLScanner_setValidationConstraintFatal},
{"XML::Xercesc::XMLScanner_setValidationScheme", _wrap_XMLScanner_setValidationScheme},
{"XML::Xercesc::XMLScanner_setValidator", _wrap_XMLScanner_setValidator},
{"XML::Xercesc::XMLScanner_setDoSchema", _wrap_XMLScanner_setDoSchema},
{"XML::Xercesc::XMLScanner_setValidationSchemaFullChecking", _wrap_XMLScanner_setValidationSchemaFullChecking},
{"XML::Xercesc::XMLScanner_setHasNoDTD", _wrap_XMLScanner_setHasNoDTD},
{"XML::Xercesc::XMLScanner_cacheGrammarFromParse", _wrap_XMLScanner_cacheGrammarFromParse},
{"XML::Xercesc::XMLScanner_useCachedGrammarInParse", _wrap_XMLScanner_useCachedGrammarInParse},
{"XML::Xercesc::XMLScanner_setRootElemName", _wrap_XMLScanner_setRootElemName},
{"XML::Xercesc::XMLScanner_setSecurityManager", _wrap_XMLScanner_setSecurityManager},
{"XML::Xercesc::XMLScanner_setLoadExternalDTD", _wrap_XMLScanner_setLoadExternalDTD},
{"XML::Xercesc::XMLScanner_setNormalizeData", _wrap_XMLScanner_setNormalizeData},
{"XML::Xercesc::XMLScanner_setCalculateSrcOfs", _wrap_XMLScanner_setCalculateSrcOfs},
{"XML::Xercesc::XMLScanner_setParseSettings", _wrap_XMLScanner_setParseSettings},
{"XML::Xercesc::XMLScanner_setStandardUriConformant", _wrap_XMLScanner_setStandardUriConformant},
{"XML::Xercesc::XMLScanner_incrementErrorCount", _wrap_XMLScanner_incrementErrorCount},
{"XML::Xercesc::XMLScanner_getDoValidation", _wrap_XMLScanner_getDoValidation},
{"XML::Xercesc::XMLScanner_setDoValidation", _wrap_XMLScanner_setDoValidation},
{"XML::Xercesc::XMLScanner_scanReset", _wrap_XMLScanner_scanReset},
{"XML::Xercesc::XMLScanner_checkXMLDecl", _wrap_XMLScanner_checkXMLDecl},
{"XML::Xercesc::XMLScanner_loadGrammar", _wrap_XMLScanner_loadGrammar},
{"XML::Xercesc::XMLScanner_reinitScannerMutex", _wrap_XMLScanner_reinitScannerMutex},
{"XML::Xercesc::XMLScanner_reinitMsgLoader", _wrap_XMLScanner_reinitMsgLoader},
{"XML::Xercesc::new_XMLPScanToken", _wrap_new_XMLPScanToken},
{"XML::Xercesc::delete_XMLPScanToken", _wrap_delete_XMLPScanToken},
{"XML::Xercesc::XMLPScanToken_operator_assignment", _wrap_XMLPScanToken_operator_assignment},
{"XML::Xercesc::delete_Parser", _wrap_delete_Parser},
{"XML::Xercesc::Parser_setEntityResolver", _wrap_Parser_setEntityResolver},
{"XML::Xercesc::Parser_setDTDHandler", _wrap_Parser_setDTDHandler},
{"XML::Xercesc::Parser_setDocumentHandler", _wrap_Parser_setDocumentHandler},
{"XML::Xercesc::Parser_setErrorHandler", _wrap_Parser_setErrorHandler},
{"XML::Xercesc::Parser_parse", _wrap_Parser_parse},
{"XML::Xercesc::delete_XMLDocumentHandler", _wrap_delete_XMLDocumentHandler},
{"XML::Xercesc::delete_XMLErrorReporter", _wrap_delete_XMLErrorReporter},
{"XML::Xercesc::XMLErrorReporter_error", _wrap_XMLErrorReporter_error},
{"XML::Xercesc::XMLErrorReporter_resetErrors", _wrap_XMLErrorReporter_resetErrors},
{"XML::Xercesc::delete_XMLEntityHandler", _wrap_delete_XMLEntityHandler},
{"XML::Xercesc::delete_DocTypeHandler", _wrap_delete_DocTypeHandler},
{"XML::Xercesc::delete_SAX2XMLReader", _wrap_delete_SAX2XMLReader},
{"XML::Xercesc::SAX2XMLReader_getContentHandler", _wrap_SAX2XMLReader_getContentHandler},
{"XML::Xercesc::SAX2XMLReader_getDTDHandler", _wrap_SAX2XMLReader_getDTDHandler},
{"XML::Xercesc::SAX2XMLReader_getEntityResolver", _wrap_SAX2XMLReader_getEntityResolver},
{"XML::Xercesc::SAX2XMLReader_getErrorHandler", _wrap_SAX2XMLReader_getErrorHandler},
{"XML::Xercesc::SAX2XMLReader_getFeature", _wrap_SAX2XMLReader_getFeature},
{"XML::Xercesc::SAX2XMLReader_getProperty", _wrap_SAX2XMLReader_getProperty},
{"XML::Xercesc::SAX2XMLReader_setContentHandler", _wrap_SAX2XMLReader_setContentHandler},
{"XML::Xercesc::SAX2XMLReader_setDTDHandler", _wrap_SAX2XMLReader_setDTDHandler},
{"XML::Xercesc::SAX2XMLReader_setEntityResolver", _wrap_SAX2XMLReader_setEntityResolver},
{"XML::Xercesc::SAX2XMLReader_setErrorHandler", _wrap_SAX2XMLReader_setErrorHandler},
{"XML::Xercesc::SAX2XMLReader_setFeature", _wrap_SAX2XMLReader_setFeature},
{"XML::Xercesc::SAX2XMLReader_setProperty", _wrap_SAX2XMLReader_setProperty},
{"XML::Xercesc::SAX2XMLReader_parse", _wrap_SAX2XMLReader_parse},
{"XML::Xercesc::SAX2XMLReader_getDeclarationHandler", _wrap_SAX2XMLReader_getDeclarationHandler},
{"XML::Xercesc::SAX2XMLReader_getLexicalHandler", _wrap_SAX2XMLReader_getLexicalHandler},
{"XML::Xercesc::SAX2XMLReader_setDeclarationHandler", _wrap_SAX2XMLReader_setDeclarationHandler},
{"XML::Xercesc::SAX2XMLReader_setLexicalHandler", _wrap_SAX2XMLReader_setLexicalHandler},
{"XML::Xercesc::SAX2XMLReader_getValidator", _wrap_SAX2XMLReader_getValidator},
{"XML::Xercesc::SAX2XMLReader_getErrorCount", _wrap_SAX2XMLReader_getErrorCount},
{"XML::Xercesc::SAX2XMLReader_getExitOnFirstFatalError", _wrap_SAX2XMLReader_getExitOnFirstFatalError},
{"XML::Xercesc::SAX2XMLReader_getValidationConstraintFatal", _wrap_SAX2XMLReader_getValidationConstraintFatal},
{"XML::Xercesc::SAX2XMLReader_getGrammar", _wrap_SAX2XMLReader_getGrammar},
{"XML::Xercesc::SAX2XMLReader_getRootGrammar", _wrap_SAX2XMLReader_getRootGrammar},
{"XML::Xercesc::SAX2XMLReader_getURIText", _wrap_SAX2XMLReader_getURIText},
{"XML::Xercesc::SAX2XMLReader_getSrcOffset", _wrap_SAX2XMLReader_getSrcOffset},
{"XML::Xercesc::SAX2XMLReader_setValidator", _wrap_SAX2XMLReader_setValidator},
{"XML::Xercesc::SAX2XMLReader_setExitOnFirstFatalError", _wrap_SAX2XMLReader_setExitOnFirstFatalError},
{"XML::Xercesc::SAX2XMLReader_setValidationConstraintFatal", _wrap_SAX2XMLReader_setValidationConstraintFatal},
{"XML::Xercesc::SAX2XMLReader_parseFirst", _wrap_SAX2XMLReader_parseFirst},
{"XML::Xercesc::SAX2XMLReader_parseNext", _wrap_SAX2XMLReader_parseNext},
{"XML::Xercesc::SAX2XMLReader_parseReset", _wrap_SAX2XMLReader_parseReset},
{"XML::Xercesc::SAX2XMLReader_loadGrammar", _wrap_SAX2XMLReader_loadGrammar},
{"XML::Xercesc::SAX2XMLReader_resetCachedGrammarPool", _wrap_SAX2XMLReader_resetCachedGrammarPool},
{"XML::Xercesc::SAX2XMLReader_installAdvDocHandler", _wrap_SAX2XMLReader_installAdvDocHandler},
{"XML::Xercesc::SAX2XMLReader_removeAdvDocHandler", _wrap_SAX2XMLReader_removeAdvDocHandler},
{"XML::Xercesc::XMLReaderFactory_createXMLReader", _wrap_XMLReaderFactory_createXMLReader},
{"XML::Xercesc::new_SAXParser", _wrap_new_SAXParser},
{"XML::Xercesc::delete_SAXParser", _wrap_delete_SAXParser},
{"XML::Xercesc::SAXParser_getDocumentHandler", _wrap_SAXParser_getDocumentHandler},
{"XML::Xercesc::SAXParser_getEntityResolver", _wrap_SAXParser_getEntityResolver},
{"XML::Xercesc::SAXParser_getErrorHandler", _wrap_SAXParser_getErrorHandler},
{"XML::Xercesc::SAXParser_getValidator", _wrap_SAXParser_getValidator},
{"XML::Xercesc::SAXParser_getValidationScheme", _wrap_SAXParser_getValidationScheme},
{"XML::Xercesc::SAXParser_getDoSchema", _wrap_SAXParser_getDoSchema},
{"XML::Xercesc::SAXParser_getValidationSchemaFullChecking", _wrap_SAXParser_getValidationSchemaFullChecking},
{"XML::Xercesc::SAXParser_getErrorCount", _wrap_SAXParser_getErrorCount},
{"XML::Xercesc::SAXParser_getDoNamespaces", _wrap_SAXParser_getDoNamespaces},
{"XML::Xercesc::SAXParser_getExitOnFirstFatalError", _wrap_SAXParser_getExitOnFirstFatalError},
{"XML::Xercesc::SAXParser_getValidationConstraintFatal", _wrap_SAXParser_getValidationConstraintFatal},
{"XML::Xercesc::SAXParser_getExternalSchemaLocation", _wrap_SAXParser_getExternalSchemaLocation},
{"XML::Xercesc::SAXParser_getExternalNoNamespaceSchemaLocation", _wrap_SAXParser_getExternalNoNamespaceSchemaLocation},
{"XML::Xercesc::SAXParser_getSecurityManager", _wrap_SAXParser_getSecurityManager},
{"XML::Xercesc::SAXParser_getLoadExternalDTD", _wrap_SAXParser_getLoadExternalDTD},
{"XML::Xercesc::SAXParser_isCachingGrammarFromParse", _wrap_SAXParser_isCachingGrammarFromParse},
{"XML::Xercesc::SAXParser_isUsingCachedGrammarInParse", _wrap_SAXParser_isUsingCachedGrammarInParse},
{"XML::Xercesc::SAXParser_getCalculateSrcOfs", _wrap_SAXParser_getCalculateSrcOfs},
{"XML::Xercesc::SAXParser_getStandardUriConformant", _wrap_SAXParser_getStandardUriConformant},
{"XML::Xercesc::SAXParser_getGrammar", _wrap_SAXParser_getGrammar},
{"XML::Xercesc::SAXParser_getRootGrammar", _wrap_SAXParser_getRootGrammar},
{"XML::Xercesc::SAXParser_getURIText", _wrap_SAXParser_getURIText},
{"XML::Xercesc::SAXParser_getSrcOffset", _wrap_SAXParser_getSrcOffset},
{"XML::Xercesc::SAXParser_setDoNamespaces", _wrap_SAXParser_setDoNamespaces},
{"XML::Xercesc::SAXParser_setValidationScheme", _wrap_SAXParser_setValidationScheme},
{"XML::Xercesc::SAXParser_setDoSchema", _wrap_SAXParser_setDoSchema},
{"XML::Xercesc::SAXParser_setValidationSchemaFullChecking", _wrap_SAXParser_setValidationSchemaFullChecking},
{"XML::Xercesc::SAXParser_setExitOnFirstFatalError", _wrap_SAXParser_setExitOnFirstFatalError},
{"XML::Xercesc::SAXParser_setValidationConstraintFatal", _wrap_SAXParser_setValidationConstraintFatal},
{"XML::Xercesc::SAXParser_setExternalSchemaLocation", _wrap_SAXParser_setExternalSchemaLocation},
{"XML::Xercesc::SAXParser_setExternalNoNamespaceSchemaLocation", _wrap_SAXParser_setExternalNoNamespaceSchemaLocation},
{"XML::Xercesc::SAXParser_setSecurityManager", _wrap_SAXParser_setSecurityManager},
{"XML::Xercesc::SAXParser_setLoadExternalDTD", _wrap_SAXParser_setLoadExternalDTD},
{"XML::Xercesc::SAXParser_cacheGrammarFromParse", _wrap_SAXParser_cacheGrammarFromParse},
{"XML::Xercesc::SAXParser_useCachedGrammarInParse", _wrap_SAXParser_useCachedGrammarInParse},
{"XML::Xercesc::SAXParser_setCalculateSrcOfs", _wrap_SAXParser_setCalculateSrcOfs},
{"XML::Xercesc::SAXParser_setStandardUriConformant", _wrap_SAXParser_setStandardUriConformant},
{"XML::Xercesc::SAXParser_useScanner", _wrap_SAXParser_useScanner},
{"XML::Xercesc::SAXParser_installAdvDocHandler", _wrap_SAXParser_installAdvDocHandler},
{"XML::Xercesc::SAXParser_removeAdvDocHandler", _wrap_SAXParser_removeAdvDocHandler},
{"XML::Xercesc::SAXParser_parseFirst", _wrap_SAXParser_parseFirst},
{"XML::Xercesc::SAXParser_parseNext", _wrap_SAXParser_parseNext},
{"XML::Xercesc::SAXParser_parseReset", _wrap_SAXParser_parseReset},
{"XML::Xercesc::SAXParser_loadGrammar", _wrap_SAXParser_loadGrammar},
{"XML::Xercesc::SAXParser_resetCachedGrammarPool", _wrap_SAXParser_resetCachedGrammarPool},
{"XML::Xercesc::SAXParser_parse", _wrap_SAXParser_parse},
{"XML::Xercesc::SAXParser_setDocumentHandler", _wrap_SAXParser_setDocumentHandler},
{"XML::Xercesc::SAXParser_setDTDHandler", _wrap_SAXParser_setDTDHandler},
{"XML::Xercesc::SAXParser_setErrorHandler", _wrap_SAXParser_setErrorHandler},
{"XML::Xercesc::SAXParser_setEntityResolver", _wrap_SAXParser_setEntityResolver},
{"XML::Xercesc::SAXParser_error", _wrap_SAXParser_error},
{"XML::Xercesc::SAXParser_resetErrors", _wrap_SAXParser_resetErrors},
{"XML::Xercesc::delete_Grammar", _wrap_delete_Grammar},
{"XML::Xercesc::Grammar_getGrammarType", _wrap_Grammar_getGrammarType},
{"XML::Xercesc::Grammar_getTargetNamespace", _wrap_Grammar_getTargetNamespace},
{"XML::Xercesc::Grammar_getValidated", _wrap_Grammar_getValidated},
{"XML::Xercesc::Grammar_findOrAddElemDecl", _wrap_Grammar_findOrAddElemDecl},
{"XML::Xercesc::Grammar_getElemId", _wrap_Grammar_getElemId},
{"XML::Xercesc::Grammar_getElemDecl", _wrap_Grammar_getElemDecl},
{"XML::Xercesc::Grammar_getNotationDecl", _wrap_Grammar_getNotationDecl},
{"XML::Xercesc::Grammar_putElemDecl", _wrap_Grammar_putElemDecl},
{"XML::Xercesc::Grammar_putNotationDecl", _wrap_Grammar_putNotationDecl},
{"XML::Xercesc::Grammar_setValidated", _wrap_Grammar_setValidated},
{"XML::Xercesc::Grammar_reset", _wrap_Grammar_reset},
{"XML::Xercesc::new_DOMException", _wrap_new_DOMException},
{"XML::Xercesc::delete_DOMException", _wrap_delete_DOMException},
{"XML::Xercesc::DOMException_code_set", _wrap_DOMException_code_set},
{"XML::Xercesc::DOMException_code_get", _wrap_DOMException_code_get},
{"XML::Xercesc::DOMException_msg_set", _wrap_DOMException_msg_set},
{"XML::Xercesc::DOMException_msg_get", _wrap_DOMException_msg_get},
{"XML::Xercesc::delete_DOMDocumentRange", _wrap_delete_DOMDocumentRange},
{"XML::Xercesc::DOMDocumentRange_createRange", _wrap_DOMDocumentRange_createRange},
{"XML::Xercesc::delete_DOMDocumentTraversal", _wrap_delete_DOMDocumentTraversal},
{"XML::Xercesc::DOMDocumentTraversal_createNodeIterator", _wrap_DOMDocumentTraversal_createNodeIterator},
{"XML::Xercesc::DOMDocumentTraversal_createTreeWalker", _wrap_DOMDocumentTraversal_createTreeWalker},
{"XML::Xercesc::delete_DOMNodeFilter", _wrap_delete_DOMNodeFilter},
{"XML::Xercesc::DOMNodeFilter_acceptNode", _wrap_DOMNodeFilter_acceptNode},
{"XML::Xercesc::delete_DOMNodeIterator", _wrap_delete_DOMNodeIterator},
{"XML::Xercesc::DOMNodeIterator_getRoot", _wrap_DOMNodeIterator_getRoot},
{"XML::Xercesc::DOMNodeIterator_getWhatToShow", _wrap_DOMNodeIterator_getWhatToShow},
{"XML::Xercesc::DOMNodeIterator_getFilter", _wrap_DOMNodeIterator_getFilter},
{"XML::Xercesc::DOMNodeIterator_getExpandEntityReferences", _wrap_DOMNodeIterator_getExpandEntityReferences},
{"XML::Xercesc::DOMNodeIterator_nextNode", _wrap_DOMNodeIterator_nextNode},
{"XML::Xercesc::DOMNodeIterator_previousNode", _wrap_DOMNodeIterator_previousNode},
{"XML::Xercesc::DOMNodeIterator_detach", _wrap_DOMNodeIterator_detach},
{"XML::Xercesc::DOMNodeIterator_release", _wrap_DOMNodeIterator_release},
{"XML::Xercesc::delete_DOMRange", _wrap_delete_DOMRange},
{"XML::Xercesc::DOMRange_getStartContainer", _wrap_DOMRange_getStartContainer},
{"XML::Xercesc::DOMRange_getStartOffset", _wrap_DOMRange_getStartOffset},
{"XML::Xercesc::DOMRange_getEndContainer", _wrap_DOMRange_getEndContainer},
{"XML::Xercesc::DOMRange_getEndOffset", _wrap_DOMRange_getEndOffset},
{"XML::Xercesc::DOMRange_getCollapsed", _wrap_DOMRange_getCollapsed},
{"XML::Xercesc::DOMRange_getCommonAncestorContainer", _wrap_DOMRange_getCommonAncestorContainer},
{"XML::Xercesc::DOMRange_setStart", _wrap_DOMRange_setStart},
{"XML::Xercesc::DOMRange_setEnd", _wrap_DOMRange_setEnd},
{"XML::Xercesc::DOMRange_setStartBefore", _wrap_DOMRange_setStartBefore},
{"XML::Xercesc::DOMRange_setStartAfter", _wrap_DOMRange_setStartAfter},
{"XML::Xercesc::DOMRange_setEndBefore", _wrap_DOMRange_setEndBefore},
{"XML::Xercesc::DOMRange_setEndAfter", _wrap_DOMRange_setEndAfter},
{"XML::Xercesc::DOMRange_collapse", _wrap_DOMRange_collapse},
{"XML::Xercesc::DOMRange_selectNode", _wrap_DOMRange_selectNode},
{"XML::Xercesc::DOMRange_selectNodeContents", _wrap_DOMRange_selectNodeContents},
{"XML::Xercesc::DOMRange_compareBoundaryPoints", _wrap_DOMRange_compareBoundaryPoints},
{"XML::Xercesc::DOMRange_deleteContents", _wrap_DOMRange_deleteContents},
{"XML::Xercesc::DOMRange_extractContents", _wrap_DOMRange_extractContents},
{"XML::Xercesc::DOMRange_cloneContents", _wrap_DOMRange_cloneContents},
{"XML::Xercesc::DOMRange_insertNode", _wrap_DOMRange_insertNode},
{"XML::Xercesc::DOMRange_surroundContents", _wrap_DOMRange_surroundContents},
{"XML::Xercesc::DOMRange_cloneRange", _wrap_DOMRange_cloneRange},
{"XML::Xercesc::DOMRange_toString", _wrap_DOMRange_toString},
{"XML::Xercesc::DOMRange_detach", _wrap_DOMRange_detach},
{"XML::Xercesc::DOMRange_release", _wrap_DOMRange_release},
{"XML::Xercesc::new_DOMRangeException", _wrap_new_DOMRangeException},
{"XML::Xercesc::delete_DOMRangeException", _wrap_delete_DOMRangeException},
{"XML::Xercesc::DOMRangeException_code_set", _wrap_DOMRangeException_code_set},
{"XML::Xercesc::DOMRangeException_code_get", _wrap_DOMRangeException_code_get},
{"XML::Xercesc::delete_DOMTreeWalker", _wrap_delete_DOMTreeWalker},
{"XML::Xercesc::DOMTreeWalker_getRoot", _wrap_DOMTreeWalker_getRoot},
{"XML::Xercesc::DOMTreeWalker_getWhatToShow", _wrap_DOMTreeWalker_getWhatToShow},
{"XML::Xercesc::DOMTreeWalker_getFilter", _wrap_DOMTreeWalker_getFilter},
{"XML::Xercesc::DOMTreeWalker_getExpandEntityReferences", _wrap_DOMTreeWalker_getExpandEntityReferences},
{"XML::Xercesc::DOMTreeWalker_getCurrentNode", _wrap_DOMTreeWalker_getCurrentNode},
{"XML::Xercesc::DOMTreeWalker_parentNode", _wrap_DOMTreeWalker_parentNode},
{"XML::Xercesc::DOMTreeWalker_firstChild", _wrap_DOMTreeWalker_firstChild},
{"XML::Xercesc::DOMTreeWalker_lastChild", _wrap_DOMTreeWalker_lastChild},
{"XML::Xercesc::DOMTreeWalker_previousSibling", _wrap_DOMTreeWalker_previousSibling},
{"XML::Xercesc::DOMTreeWalker_nextSibling", _wrap_DOMTreeWalker_nextSibling},
{"XML::Xercesc::DOMTreeWalker_previousNode", _wrap_DOMTreeWalker_previousNode},
{"XML::Xercesc::DOMTreeWalker_nextNode", _wrap_DOMTreeWalker_nextNode},
{"XML::Xercesc::DOMTreeWalker_setCurrentNode", _wrap_DOMTreeWalker_setCurrentNode},
{"XML::Xercesc::DOMTreeWalker_release", _wrap_DOMTreeWalker_release},
{"XML::Xercesc::delete_DOMNode", _wrap_delete_DOMNode},
{"XML::Xercesc::DOMNode_getNodeName", _wrap_DOMNode_getNodeName},
{"XML::Xercesc::DOMNode_getNodeValue", _wrap_DOMNode_getNodeValue},
{"XML::Xercesc::DOMNode_getNodeType", _wrap_DOMNode_getNodeType},
{"XML::Xercesc::DOMNode_getParentNode", _wrap_DOMNode_getParentNode},
{"XML::Xercesc::DOMNode_getChildNodes", _wrap_DOMNode_getChildNodes},
{"XML::Xercesc::DOMNode_getFirstChild", _wrap_DOMNode_getFirstChild},
{"XML::Xercesc::DOMNode_getLastChild", _wrap_DOMNode_getLastChild},
{"XML::Xercesc::DOMNode_getPreviousSibling", _wrap_DOMNode_getPreviousSibling},
{"XML::Xercesc::DOMNode_getNextSibling", _wrap_DOMNode_getNextSibling},
{"XML::Xercesc::DOMNode_getAttributes", _wrap_DOMNode_getAttributes},
{"XML::Xercesc::DOMNode_getOwnerDocument", _wrap_DOMNode_getOwnerDocument},
{"XML::Xercesc::DOMNode_cloneNode", _wrap_DOMNode_cloneNode},
{"XML::Xercesc::DOMNode_insertBefore", _wrap_DOMNode_insertBefore},
{"XML::Xercesc::DOMNode_replaceChild", _wrap_DOMNode_replaceChild},
{"XML::Xercesc::DOMNode_removeChild", _wrap_DOMNode_removeChild},
{"XML::Xercesc::DOMNode_appendChild", _wrap_DOMNode_appendChild},
{"XML::Xercesc::DOMNode_hasChildNodes", _wrap_DOMNode_hasChildNodes},
{"XML::Xercesc::DOMNode_setNodeValue", _wrap_DOMNode_setNodeValue},
{"XML::Xercesc::DOMNode_normalize", _wrap_DOMNode_normalize},
{"XML::Xercesc::DOMNode_isSupported", _wrap_DOMNode_isSupported},
{"XML::Xercesc::DOMNode_getNamespaceURI", _wrap_DOMNode_getNamespaceURI},
{"XML::Xercesc::DOMNode_getPrefix", _wrap_DOMNode_getPrefix},
{"XML::Xercesc::DOMNode_getLocalName", _wrap_DOMNode_getLocalName},
{"XML::Xercesc::DOMNode_setPrefix", _wrap_DOMNode_setPrefix},
{"XML::Xercesc::DOMNode_hasAttributes", _wrap_DOMNode_hasAttributes},
{"XML::Xercesc::DOMNode_isSameNode", _wrap_DOMNode_isSameNode},
{"XML::Xercesc::DOMNode_isEqualNode", _wrap_DOMNode_isEqualNode},
{"XML::Xercesc::DOMNode_setUserData", _wrap_DOMNode_setUserData},
{"XML::Xercesc::DOMNode_getUserData", _wrap_DOMNode_getUserData},
{"XML::Xercesc::DOMNode_getBaseURI", _wrap_DOMNode_getBaseURI},
{"XML::Xercesc::DOMNode_compareTreePosition", _wrap_DOMNode_compareTreePosition},
{"XML::Xercesc::DOMNode_getTextContent", _wrap_DOMNode_getTextContent},
{"XML::Xercesc::DOMNode_setTextContent", _wrap_DOMNode_setTextContent},
{"XML::Xercesc::DOMNode_lookupNamespacePrefix", _wrap_DOMNode_lookupNamespacePrefix},
{"XML::Xercesc::DOMNode_isDefaultNamespace", _wrap_DOMNode_isDefaultNamespace},
{"XML::Xercesc::DOMNode_lookupNamespaceURI", _wrap_DOMNode_lookupNamespaceURI},
{"XML::Xercesc::DOMNode_getInterface", _wrap_DOMNode_getInterface},
{"XML::Xercesc::DOMNode_release", _wrap_DOMNode_release},
{"XML::Xercesc::DOMNode_operator_equal_to", _wrap_DOMNode_operator_equal_to},
{"XML::Xercesc::DOMNode_operator_not_equal_to", _wrap_DOMNode_operator_not_equal_to},
{"XML::Xercesc::delete_DOMAttr", _wrap_delete_DOMAttr},
{"XML::Xercesc::DOMAttr_getName", _wrap_DOMAttr_getName},
{"XML::Xercesc::DOMAttr_getSpecified", _wrap_DOMAttr_getSpecified},
{"XML::Xercesc::DOMAttr_getValue", _wrap_DOMAttr_getValue},
{"XML::Xercesc::DOMAttr_setValue", _wrap_DOMAttr_setValue},
{"XML::Xercesc::DOMAttr_getOwnerElement", _wrap_DOMAttr_getOwnerElement},
{"XML::Xercesc::DOMAttr_isId", _wrap_DOMAttr_isId},
{"XML::Xercesc::DOMAttr_getTypeInfo", _wrap_DOMAttr_getTypeInfo},
{"XML::Xercesc::delete_DOMCharacterData", _wrap_delete_DOMCharacterData},
{"XML::Xercesc::DOMCharacterData_getData", _wrap_DOMCharacterData_getData},
{"XML::Xercesc::DOMCharacterData_getLength", _wrap_DOMCharacterData_getLength},
{"XML::Xercesc::DOMCharacterData_substringData", _wrap_DOMCharacterData_substringData},
{"XML::Xercesc::DOMCharacterData_appendData", _wrap_DOMCharacterData_appendData},
{"XML::Xercesc::DOMCharacterData_insertData", _wrap_DOMCharacterData_insertData},
{"XML::Xercesc::DOMCharacterData_deleteData", _wrap_DOMCharacterData_deleteData},
{"XML::Xercesc::DOMCharacterData_replaceData", _wrap_DOMCharacterData_replaceData},
{"XML::Xercesc::DOMCharacterData_setData", _wrap_DOMCharacterData_setData},
{"XML::Xercesc::delete_DOMText", _wrap_delete_DOMText},
{"XML::Xercesc::DOMText_splitText", _wrap_DOMText_splitText},
{"XML::Xercesc::DOMText_getIsWhitespaceInElementContent", _wrap_DOMText_getIsWhitespaceInElementContent},
{"XML::Xercesc::DOMText_getWholeText", _wrap_DOMText_getWholeText},
{"XML::Xercesc::DOMText_replaceWholeText", _wrap_DOMText_replaceWholeText},
{"XML::Xercesc::DOMText_isIgnorableWhitespace", _wrap_DOMText_isIgnorableWhitespace},
{"XML::Xercesc::delete_DOMCDATASection", _wrap_delete_DOMCDATASection},
{"XML::Xercesc::delete_DOMComment", _wrap_delete_DOMComment},
{"XML::Xercesc::delete_DOMDocument", _wrap_delete_DOMDocument},
{"XML::Xercesc::DOMDocument_createElement", _wrap_DOMDocument_createElement},
{"XML::Xercesc::DOMDocument_createDocumentFragment", _wrap_DOMDocument_createDocumentFragment},
{"XML::Xercesc::DOMDocument_createTextNode", _wrap_DOMDocument_createTextNode},
{"XML::Xercesc::DOMDocument_createComment", _wrap_DOMDocument_createComment},
{"XML::Xercesc::DOMDocument_createCDATASection", _wrap_DOMDocument_createCDATASection},
{"XML::Xercesc::DOMDocument_createProcessingInstruction", _wrap_DOMDocument_createProcessingInstruction},
{"XML::Xercesc::DOMDocument_createAttribute", _wrap_DOMDocument_createAttribute},
{"XML::Xercesc::DOMDocument_createEntityReference", _wrap_DOMDocument_createEntityReference},
{"XML::Xercesc::DOMDocument_getDoctype", _wrap_DOMDocument_getDoctype},
{"XML::Xercesc::DOMDocument_getImplementation", _wrap_DOMDocument_getImplementation},
{"XML::Xercesc::DOMDocument_getDocumentElement", _wrap_DOMDocument_getDocumentElement},
{"XML::Xercesc::DOMDocument_getElementsByTagName", _wrap_DOMDocument_getElementsByTagName},
{"XML::Xercesc::DOMDocument_importNode", _wrap_DOMDocument_importNode},
{"XML::Xercesc::DOMDocument_createAttributeNS", _wrap_DOMDocument_createAttributeNS},
{"XML::Xercesc::DOMDocument_getElementsByTagNameNS", _wrap_DOMDocument_getElementsByTagNameNS},
{"XML::Xercesc::DOMDocument_getElementById", _wrap_DOMDocument_getElementById},
{"XML::Xercesc::DOMDocument_getActualEncoding", _wrap_DOMDocument_getActualEncoding},
{"XML::Xercesc::DOMDocument_setActualEncoding", _wrap_DOMDocument_setActualEncoding},
{"XML::Xercesc::DOMDocument_getEncoding", _wrap_DOMDocument_getEncoding},
{"XML::Xercesc::DOMDocument_setEncoding", _wrap_DOMDocument_setEncoding},
{"XML::Xercesc::DOMDocument_getStandalone", _wrap_DOMDocument_getStandalone},
{"XML::Xercesc::DOMDocument_setStandalone", _wrap_DOMDocument_setStandalone},
{"XML::Xercesc::DOMDocument_getVersion", _wrap_DOMDocument_getVersion},
{"XML::Xercesc::DOMDocument_setVersion", _wrap_DOMDocument_setVersion},
{"XML::Xercesc::DOMDocument_getDocumentURI", _wrap_DOMDocument_getDocumentURI},
{"XML::Xercesc::DOMDocument_setDocumentURI", _wrap_DOMDocument_setDocumentURI},
{"XML::Xercesc::DOMDocument_getStrictErrorChecking", _wrap_DOMDocument_getStrictErrorChecking},
{"XML::Xercesc::DOMDocument_setStrictErrorChecking", _wrap_DOMDocument_setStrictErrorChecking},
{"XML::Xercesc::DOMDocument_renameNode", _wrap_DOMDocument_renameNode},
{"XML::Xercesc::DOMDocument_adoptNode", _wrap_DOMDocument_adoptNode},
{"XML::Xercesc::DOMDocument_normalizeDocument", _wrap_DOMDocument_normalizeDocument},
{"XML::Xercesc::DOMDocument_getDOMConfiguration", _wrap_DOMDocument_getDOMConfiguration},
{"XML::Xercesc::DOMDocument_createEntity", _wrap_DOMDocument_createEntity},
{"XML::Xercesc::DOMDocument_createDocumentType", _wrap_DOMDocument_createDocumentType},
{"XML::Xercesc::DOMDocument_createNotation", _wrap_DOMDocument_createNotation},
{"XML::Xercesc::DOMDocument_createElementNS", _wrap_DOMDocument_createElementNS},
{"XML::Xercesc::DOMDocument_toDOMNode", _wrap_DOMDocument_toDOMNode},
{"XML::Xercesc::DOMDocument_toDOMDocumentTraversal", _wrap_DOMDocument_toDOMDocumentTraversal},
{"XML::Xercesc::delete_DOMDocumentFragment", _wrap_delete_DOMDocumentFragment},
{"XML::Xercesc::delete_DOMDocumentType", _wrap_delete_DOMDocumentType},
{"XML::Xercesc::DOMDocumentType_getName", _wrap_DOMDocumentType_getName},
{"XML::Xercesc::DOMDocumentType_getEntities", _wrap_DOMDocumentType_getEntities},
{"XML::Xercesc::DOMDocumentType_getNotations", _wrap_DOMDocumentType_getNotations},
{"XML::Xercesc::DOMDocumentType_getPublicId", _wrap_DOMDocumentType_getPublicId},
{"XML::Xercesc::DOMDocumentType_getSystemId", _wrap_DOMDocumentType_getSystemId},
{"XML::Xercesc::DOMDocumentType_getInternalSubset", _wrap_DOMDocumentType_getInternalSubset},
{"XML::Xercesc::delete_DOMImplementationLS", _wrap_delete_DOMImplementationLS},
{"XML::Xercesc::DOMImplementationLS_createDOMBuilder", _wrap_DOMImplementationLS_createDOMBuilder},
{"XML::Xercesc::DOMImplementationLS_createDOMWriter", _wrap_DOMImplementationLS_createDOMWriter},
{"XML::Xercesc::DOMImplementationLS_createDOMInputSource", _wrap_DOMImplementationLS_createDOMInputSource},
{"XML::Xercesc::delete_DOMImplementation", _wrap_delete_DOMImplementation},
{"XML::Xercesc::DOMImplementation_hasFeature", _wrap_DOMImplementation_hasFeature},
{"XML::Xercesc::DOMImplementation_createDocumentType", _wrap_DOMImplementation_createDocumentType},
{"XML::Xercesc::DOMImplementation_getInterface", _wrap_DOMImplementation_getInterface},
{"XML::Xercesc::DOMImplementation_createDocument", _wrap_DOMImplementation_createDocument},
{"XML::Xercesc::DOMImplementation_getImplementation", _wrap_DOMImplementation_getImplementation},
{"XML::Xercesc::delete_DOMElement", _wrap_delete_DOMElement},
{"XML::Xercesc::DOMElement_getTagName", _wrap_DOMElement_getTagName},
{"XML::Xercesc::DOMElement_getAttribute", _wrap_DOMElement_getAttribute},
{"XML::Xercesc::DOMElement_getAttributeNode", _wrap_DOMElement_getAttributeNode},
{"XML::Xercesc::DOMElement_getElementsByTagName", _wrap_DOMElement_getElementsByTagName},
{"XML::Xercesc::DOMElement_setAttribute", _wrap_DOMElement_setAttribute},
{"XML::Xercesc::DOMElement_setAttributeNode", _wrap_DOMElement_setAttributeNode},
{"XML::Xercesc::DOMElement_removeAttributeNode", _wrap_DOMElement_removeAttributeNode},
{"XML::Xercesc::DOMElement_removeAttribute", _wrap_DOMElement_removeAttribute},
{"XML::Xercesc::DOMElement_getAttributeNS", _wrap_DOMElement_getAttributeNS},
{"XML::Xercesc::DOMElement_setAttributeNS", _wrap_DOMElement_setAttributeNS},
{"XML::Xercesc::DOMElement_removeAttributeNS", _wrap_DOMElement_removeAttributeNS},
{"XML::Xercesc::DOMElement_getAttributeNodeNS", _wrap_DOMElement_getAttributeNodeNS},
{"XML::Xercesc::DOMElement_setAttributeNodeNS", _wrap_DOMElement_setAttributeNodeNS},
{"XML::Xercesc::DOMElement_getElementsByTagNameNS", _wrap_DOMElement_getElementsByTagNameNS},
{"XML::Xercesc::DOMElement_hasAttribute", _wrap_DOMElement_hasAttribute},
{"XML::Xercesc::DOMElement_hasAttributeNS", _wrap_DOMElement_hasAttributeNS},
{"XML::Xercesc::DOMElement_setIdAttribute", _wrap_DOMElement_setIdAttribute},
{"XML::Xercesc::DOMElement_setIdAttributeNS", _wrap_DOMElement_setIdAttributeNS},
{"XML::Xercesc::DOMElement_setIdAttributeNode", _wrap_DOMElement_setIdAttributeNode},
{"XML::Xercesc::DOMElement_getTypeInfo", _wrap_DOMElement_getTypeInfo},
{"XML::Xercesc::delete_DOMEntity", _wrap_delete_DOMEntity},
{"XML::Xercesc::DOMEntity_getPublicId", _wrap_DOMEntity_getPublicId},
{"XML::Xercesc::DOMEntity_getSystemId", _wrap_DOMEntity_getSystemId},
{"XML::Xercesc::DOMEntity_getNotationName", _wrap_DOMEntity_getNotationName},
{"XML::Xercesc::DOMEntity_getActualEncoding", _wrap_DOMEntity_getActualEncoding},
{"XML::Xercesc::DOMEntity_setActualEncoding", _wrap_DOMEntity_setActualEncoding},
{"XML::Xercesc::DOMEntity_getEncoding", _wrap_DOMEntity_getEncoding},
{"XML::Xercesc::DOMEntity_setEncoding", _wrap_DOMEntity_setEncoding},
{"XML::Xercesc::DOMEntity_getVersion", _wrap_DOMEntity_getVersion},
{"XML::Xercesc::DOMEntity_setVersion", _wrap_DOMEntity_setVersion},
{"XML::Xercesc::delete_DOMEntityReference", _wrap_delete_DOMEntityReference},
{"XML::Xercesc::delete_DOMNamedNodeMap", _wrap_delete_DOMNamedNodeMap},
{"XML::Xercesc::DOMNamedNodeMap_setNamedItem", _wrap_DOMNamedNodeMap_setNamedItem},
{"XML::Xercesc::DOMNamedNodeMap_item", _wrap_DOMNamedNodeMap_item},
{"XML::Xercesc::DOMNamedNodeMap_getNamedItem", _wrap_DOMNamedNodeMap_getNamedItem},
{"XML::Xercesc::DOMNamedNodeMap_getLength", _wrap_DOMNamedNodeMap_getLength},
{"XML::Xercesc::DOMNamedNodeMap_removeNamedItem", _wrap_DOMNamedNodeMap_removeNamedItem},
{"XML::Xercesc::DOMNamedNodeMap_getNamedItemNS", _wrap_DOMNamedNodeMap_getNamedItemNS},
{"XML::Xercesc::DOMNamedNodeMap_setNamedItemNS", _wrap_DOMNamedNodeMap_setNamedItemNS},
{"XML::Xercesc::DOMNamedNodeMap_removeNamedItemNS", _wrap_DOMNamedNodeMap_removeNamedItemNS},
{"XML::Xercesc::delete_DOMNodeList", _wrap_delete_DOMNodeList},
{"XML::Xercesc::DOMNodeList_item", _wrap_DOMNodeList_item},
{"XML::Xercesc::DOMNodeList_getLength", _wrap_DOMNodeList_getLength},
{"XML::Xercesc::delete_DOMNotation", _wrap_delete_DOMNotation},
{"XML::Xercesc::DOMNotation_getPublicId", _wrap_DOMNotation_getPublicId},
{"XML::Xercesc::DOMNotation_getSystemId", _wrap_DOMNotation_getSystemId},
{"XML::Xercesc::delete_DOMProcessingInstruction", _wrap_delete_DOMProcessingInstruction},
{"XML::Xercesc::DOMProcessingInstruction_getTarget", _wrap_DOMProcessingInstruction_getTarget},
{"XML::Xercesc::DOMProcessingInstruction_getData", _wrap_DOMProcessingInstruction_getData},
{"XML::Xercesc::DOMProcessingInstruction_setData", _wrap_DOMProcessingInstruction_setData},
{"XML::Xercesc::delete_DOMBuilder", _wrap_delete_DOMBuilder},
{"XML::Xercesc::DOMBuilder_getErrorHandler", _wrap_DOMBuilder_getErrorHandler},
{"XML::Xercesc::DOMBuilder_getEntityResolver", _wrap_DOMBuilder_getEntityResolver},
{"XML::Xercesc::DOMBuilder_getFilter", _wrap_DOMBuilder_getFilter},
{"XML::Xercesc::DOMBuilder_setErrorHandler", _wrap_DOMBuilder_setErrorHandler},
{"XML::Xercesc::DOMBuilder_setEntityResolver", _wrap_DOMBuilder_setEntityResolver},
{"XML::Xercesc::DOMBuilder_setFilter", _wrap_DOMBuilder_setFilter},
{"XML::Xercesc::DOMBuilder_setFeature", _wrap_DOMBuilder_setFeature},
{"XML::Xercesc::DOMBuilder_getFeature", _wrap_DOMBuilder_getFeature},
{"XML::Xercesc::DOMBuilder_canSetFeature", _wrap_DOMBuilder_canSetFeature},
{"XML::Xercesc::DOMBuilder_parse", _wrap_DOMBuilder_parse},
{"XML::Xercesc::DOMBuilder_parseURI", _wrap_DOMBuilder_parseURI},
{"XML::Xercesc::DOMBuilder_parseWithContext", _wrap_DOMBuilder_parseWithContext},
{"XML::Xercesc::DOMBuilder_getProperty", _wrap_DOMBuilder_getProperty},
{"XML::Xercesc::DOMBuilder_setProperty", _wrap_DOMBuilder_setProperty},
{"XML::Xercesc::DOMBuilder_release", _wrap_DOMBuilder_release},
{"XML::Xercesc::DOMBuilder_resetDocumentPool", _wrap_DOMBuilder_resetDocumentPool},
{"XML::Xercesc::DOMBuilder_loadGrammar", _wrap_DOMBuilder_loadGrammar},
{"XML::Xercesc::DOMBuilder_getGrammar", _wrap_DOMBuilder_getGrammar},
{"XML::Xercesc::DOMBuilder_getRootGrammar", _wrap_DOMBuilder_getRootGrammar},
{"XML::Xercesc::DOMBuilder_getURIText", _wrap_DOMBuilder_getURIText},
{"XML::Xercesc::DOMBuilder_resetCachedGrammarPool", _wrap_DOMBuilder_resetCachedGrammarPool},
{"XML::Xercesc::DOMBuilder_getSrcOffset", _wrap_DOMBuilder_getSrcOffset},
{"XML::Xercesc::DOMImplementationRegistry_getDOMImplementation", _wrap_DOMImplementationRegistry_getDOMImplementation},
{"XML::Xercesc::DOMImplementationRegistry_addSource", _wrap_DOMImplementationRegistry_addSource},
{"XML::Xercesc::new_DOMImplementationRegistry", _wrap_new_DOMImplementationRegistry},
{"XML::Xercesc::delete_DOMImplementationRegistry", _wrap_delete_DOMImplementationRegistry},
{"XML::Xercesc::delete_DOMImplementationSource", _wrap_delete_DOMImplementationSource},
{"XML::Xercesc::DOMImplementationSource_getDOMImplementation", _wrap_DOMImplementationSource_getDOMImplementation},
{"XML::Xercesc::delete_DOMInputSource", _wrap_delete_DOMInputSource},
{"XML::Xercesc::DOMInputSource_getEncoding", _wrap_DOMInputSource_getEncoding},
{"XML::Xercesc::DOMInputSource_getPublicId", _wrap_DOMInputSource_getPublicId},
{"XML::Xercesc::DOMInputSource_getSystemId", _wrap_DOMInputSource_getSystemId},
{"XML::Xercesc::DOMInputSource_getBaseURI", _wrap_DOMInputSource_getBaseURI},
{"XML::Xercesc::DOMInputSource_setEncoding", _wrap_DOMInputSource_setEncoding},
{"XML::Xercesc::DOMInputSource_setPublicId", _wrap_DOMInputSource_setPublicId},
{"XML::Xercesc::DOMInputSource_setSystemId", _wrap_DOMInputSource_setSystemId},
{"XML::Xercesc::DOMInputSource_setBaseURI", _wrap_DOMInputSource_setBaseURI},
{"XML::Xercesc::DOMInputSource_makeStream", _wrap_DOMInputSource_makeStream},
{"XML::Xercesc::DOMInputSource_setIssueFatalErrorIfNotFound", _wrap_DOMInputSource_setIssueFatalErrorIfNotFound},
{"XML::Xercesc::DOMInputSource_getIssueFatalErrorIfNotFound", _wrap_DOMInputSource_getIssueFatalErrorIfNotFound},
{"XML::Xercesc::DOMInputSource_release", _wrap_DOMInputSource_release},
{"XML::Xercesc::delete_DOMLocator", _wrap_delete_DOMLocator},
{"XML::Xercesc::DOMLocator_getLineNumber", _wrap_DOMLocator_getLineNumber},
{"XML::Xercesc::DOMLocator_getColumnNumber", _wrap_DOMLocator_getColumnNumber},
{"XML::Xercesc::DOMLocator_getOffset", _wrap_DOMLocator_getOffset},
{"XML::Xercesc::DOMLocator_getErrorNode", _wrap_DOMLocator_getErrorNode},
{"XML::Xercesc::DOMLocator_getURI", _wrap_DOMLocator_getURI},
{"XML::Xercesc::DOMLocator_setLineNumber", _wrap_DOMLocator_setLineNumber},
{"XML::Xercesc::DOMLocator_setColumnNumber", _wrap_DOMLocator_setColumnNumber},
{"XML::Xercesc::DOMLocator_setOffset", _wrap_DOMLocator_setOffset},
{"XML::Xercesc::DOMLocator_setErrorNode", _wrap_DOMLocator_setErrorNode},
{"XML::Xercesc::DOMLocator_setURI", _wrap_DOMLocator_setURI},
{"XML::Xercesc::delete_DOMWriter", _wrap_delete_DOMWriter},
{"XML::Xercesc::DOMWriter_canSetFeature", _wrap_DOMWriter_canSetFeature},
{"XML::Xercesc::DOMWriter_setFeature", _wrap_DOMWriter_setFeature},
{"XML::Xercesc::DOMWriter_getFeature", _wrap_DOMWriter_getFeature},
{"XML::Xercesc::DOMWriter_setEncoding", _wrap_DOMWriter_setEncoding},
{"XML::Xercesc::DOMWriter_setNewLine", _wrap_DOMWriter_setNewLine},
{"XML::Xercesc::DOMWriter_setErrorHandler", _wrap_DOMWriter_setErrorHandler},
{"XML::Xercesc::DOMWriter_setFilter", _wrap_DOMWriter_setFilter},
{"XML::Xercesc::DOMWriter_getEncoding", _wrap_DOMWriter_getEncoding},
{"XML::Xercesc::DOMWriter_getNewLine", _wrap_DOMWriter_getNewLine},
{"XML::Xercesc::DOMWriter_getErrorHandler", _wrap_DOMWriter_getErrorHandler},
{"XML::Xercesc::DOMWriter_getFilter", _wrap_DOMWriter_getFilter},
{"XML::Xercesc::DOMWriter_writeNode", _wrap_DOMWriter_writeNode},
{"XML::Xercesc::DOMWriter_writeToString", _wrap_DOMWriter_writeToString},
{"XML::Xercesc::DOMWriter_release", _wrap_DOMWriter_release},
{"XML::Xercesc::delete_DOMWriterFilter", _wrap_delete_DOMWriterFilter},
{"XML::Xercesc::DOMWriterFilter_acceptNode", _wrap_DOMWriterFilter_acceptNode},
{"XML::Xercesc::DOMWriterFilter_getWhatToShow", _wrap_DOMWriterFilter_getWhatToShow},
{"XML::Xercesc::DOMWriterFilter_setWhatToShow", _wrap_DOMWriterFilter_setWhatToShow},
{"XML::Xercesc::delete_AbstractDOMParser", _wrap_delete_AbstractDOMParser},
{"XML::Xercesc::AbstractDOMParser_reset", _wrap_AbstractDOMParser_reset},
{"XML::Xercesc::AbstractDOMParser_adoptDocument", _wrap_AbstractDOMParser_adoptDocument},
{"XML::Xercesc::AbstractDOMParser_getDocument", _wrap_AbstractDOMParser_getDocument},
{"XML::Xercesc::AbstractDOMParser_getValidator", _wrap_AbstractDOMParser_getValidator},
{"XML::Xercesc::AbstractDOMParser_getValidationScheme", _wrap_AbstractDOMParser_getValidationScheme},
{"XML::Xercesc::AbstractDOMParser_getDoSchema", _wrap_AbstractDOMParser_getDoSchema},
{"XML::Xercesc::AbstractDOMParser_getValidationSchemaFullChecking", _wrap_AbstractDOMParser_getValidationSchemaFullChecking},
{"XML::Xercesc::AbstractDOMParser_getErrorCount", _wrap_AbstractDOMParser_getErrorCount},
{"XML::Xercesc::AbstractDOMParser_getDoNamespaces", _wrap_AbstractDOMParser_getDoNamespaces},
{"XML::Xercesc::AbstractDOMParser_getExitOnFirstFatalError", _wrap_AbstractDOMParser_getExitOnFirstFatalError},
{"XML::Xercesc::AbstractDOMParser_getValidationConstraintFatal", _wrap_AbstractDOMParser_getValidationConstraintFatal},
{"XML::Xercesc::AbstractDOMParser_getCreateEntityReferenceNodes", _wrap_AbstractDOMParser_getCreateEntityReferenceNodes},
{"XML::Xercesc::AbstractDOMParser_getIncludeIgnorableWhitespace", _wrap_AbstractDOMParser_getIncludeIgnorableWhitespace},
{"XML::Xercesc::AbstractDOMParser_getExternalSchemaLocation", _wrap_AbstractDOMParser_getExternalSchemaLocation},
{"XML::Xercesc::AbstractDOMParser_getExternalNoNamespaceSchemaLocation", _wrap_AbstractDOMParser_getExternalNoNamespaceSchemaLocation},
{"XML::Xercesc::AbstractDOMParser_getSecurityManager", _wrap_AbstractDOMParser_getSecurityManager},
{"XML::Xercesc::AbstractDOMParser_getLoadExternalDTD", _wrap_AbstractDOMParser_getLoadExternalDTD},
{"XML::Xercesc::AbstractDOMParser_getCreateCommentNodes", _wrap_AbstractDOMParser_getCreateCommentNodes},
{"XML::Xercesc::AbstractDOMParser_getCalculateSrcOfs", _wrap_AbstractDOMParser_getCalculateSrcOfs},
{"XML::Xercesc::AbstractDOMParser_getStandardUriConformant", _wrap_AbstractDOMParser_getStandardUriConformant},
{"XML::Xercesc::AbstractDOMParser_setDoNamespaces", _wrap_AbstractDOMParser_setDoNamespaces},
{"XML::Xercesc::AbstractDOMParser_setExitOnFirstFatalError", _wrap_AbstractDOMParser_setExitOnFirstFatalError},
{"XML::Xercesc::AbstractDOMParser_setValidationConstraintFatal", _wrap_AbstractDOMParser_setValidationConstraintFatal},
{"XML::Xercesc::AbstractDOMParser_setCreateEntityReferenceNodes", _wrap_AbstractDOMParser_setCreateEntityReferenceNodes},
{"XML::Xercesc::AbstractDOMParser_setIncludeIgnorableWhitespace", _wrap_AbstractDOMParser_setIncludeIgnorableWhitespace},
{"XML::Xercesc::AbstractDOMParser_setValidationScheme", _wrap_AbstractDOMParser_setValidationScheme},
{"XML::Xercesc::AbstractDOMParser_setDoSchema", _wrap_AbstractDOMParser_setDoSchema},
{"XML::Xercesc::AbstractDOMParser_setValidationSchemaFullChecking", _wrap_AbstractDOMParser_setValidationSchemaFullChecking},
{"XML::Xercesc::AbstractDOMParser_setExternalSchemaLocation", _wrap_AbstractDOMParser_setExternalSchemaLocation},
{"XML::Xercesc::AbstractDOMParser_setExternalNoNamespaceSchemaLocation", _wrap_AbstractDOMParser_setExternalNoNamespaceSchemaLocation},
{"XML::Xercesc::AbstractDOMParser_setSecurityManager", _wrap_AbstractDOMParser_setSecurityManager},
{"XML::Xercesc::AbstractDOMParser_setLoadExternalDTD", _wrap_AbstractDOMParser_setLoadExternalDTD},
{"XML::Xercesc::AbstractDOMParser_setCreateCommentNodes", _wrap_AbstractDOMParser_setCreateCommentNodes},
{"XML::Xercesc::AbstractDOMParser_setCalculateSrcOfs", _wrap_AbstractDOMParser_setCalculateSrcOfs},
{"XML::Xercesc::AbstractDOMParser_setStandardUriConformant", _wrap_AbstractDOMParser_setStandardUriConformant},
{"XML::Xercesc::AbstractDOMParser_useScanner", _wrap_AbstractDOMParser_useScanner},
{"XML::Xercesc::AbstractDOMParser_parse", _wrap_AbstractDOMParser_parse},
{"XML::Xercesc::AbstractDOMParser_parseFirst", _wrap_AbstractDOMParser_parseFirst},
{"XML::Xercesc::AbstractDOMParser_parseNext", _wrap_AbstractDOMParser_parseNext},
{"XML::Xercesc::AbstractDOMParser_parseReset", _wrap_AbstractDOMParser_parseReset},
{"XML::Xercesc::AbstractDOMParser_getExpandEntityReferences", _wrap_AbstractDOMParser_getExpandEntityReferences},
{"XML::Xercesc::AbstractDOMParser_setExpandEntityReferences", _wrap_AbstractDOMParser_setExpandEntityReferences},
{"XML::Xercesc::new_XercesDOMParser", _wrap_new_XercesDOMParser},
{"XML::Xercesc::delete_XercesDOMParser", _wrap_delete_XercesDOMParser},
{"XML::Xercesc::XercesDOMParser_getErrorHandler", _wrap_XercesDOMParser_getErrorHandler},
{"XML::Xercesc::XercesDOMParser_getEntityResolver", _wrap_XercesDOMParser_getEntityResolver},
{"XML::Xercesc::XercesDOMParser_isCachingGrammarFromParse", _wrap_XercesDOMParser_isCachingGrammarFromParse},
{"XML::Xercesc::XercesDOMParser_isUsingCachedGrammarInParse", _wrap_XercesDOMParser_isUsingCachedGrammarInParse},
{"XML::Xercesc::XercesDOMParser_getGrammar", _wrap_XercesDOMParser_getGrammar},
{"XML::Xercesc::XercesDOMParser_getRootGrammar", _wrap_XercesDOMParser_getRootGrammar},
{"XML::Xercesc::XercesDOMParser_getURIText", _wrap_XercesDOMParser_getURIText},
{"XML::Xercesc::XercesDOMParser_getSrcOffset", _wrap_XercesDOMParser_getSrcOffset},
{"XML::Xercesc::XercesDOMParser_setErrorHandler", _wrap_XercesDOMParser_setErrorHandler},
{"XML::Xercesc::XercesDOMParser_setEntityResolver", _wrap_XercesDOMParser_setEntityResolver},
{"XML::Xercesc::XercesDOMParser_cacheGrammarFromParse", _wrap_XercesDOMParser_cacheGrammarFromParse},
{"XML::Xercesc::XercesDOMParser_useCachedGrammarInParse", _wrap_XercesDOMParser_useCachedGrammarInParse},
{"XML::Xercesc::XercesDOMParser_resetDocumentPool", _wrap_XercesDOMParser_resetDocumentPool},
{"XML::Xercesc::XercesDOMParser_error", _wrap_XercesDOMParser_error},
{"XML::Xercesc::XercesDOMParser_resetErrors", _wrap_XercesDOMParser_resetErrors},
{"XML::Xercesc::XercesDOMParser_loadGrammar", _wrap_XercesDOMParser_loadGrammar},
{"XML::Xercesc::XercesDOMParser_resetCachedGrammarPool", _wrap_XercesDOMParser_resetCachedGrammarPool},
{"XML::Xercesc::new_PerlErrorCallbackHandler", _wrap_new_PerlErrorCallbackHandler},
{"XML::Xercesc::delete_PerlErrorCallbackHandler", _wrap_delete_PerlErrorCallbackHandler},
{"XML::Xercesc::PerlErrorCallbackHandler_set_callback_obj", _wrap_PerlErrorCallbackHandler_set_callback_obj},
{"XML::Xercesc::PerlErrorCallbackHandler_resetErrors", _wrap_PerlErrorCallbackHandler_resetErrors},
{"XML::Xercesc::new_PerlDocumentCallbackHandler", _wrap_new_PerlDocumentCallbackHandler},
{"XML::Xercesc::delete_PerlDocumentCallbackHandler", _wrap_delete_PerlDocumentCallbackHandler},
{"XML::Xercesc::PerlDocumentCallbackHandler_set_callback_obj", _wrap_PerlDocumentCallbackHandler_set_callback_obj},
{"XML::Xercesc::PerlDocumentCallbackHandler_characters", _wrap_PerlDocumentCallbackHandler_characters},
{"XML::Xercesc::PerlDocumentCallbackHandler_processingInstruction", _wrap_PerlDocumentCallbackHandler_processingInstruction},
{"XML::Xercesc::PerlDocumentCallbackHandler_setDocumentLocator", _wrap_PerlDocumentCallbackHandler_setDocumentLocator},
{"XML::Xercesc::new_PerlContentCallbackHandler", _wrap_new_PerlContentCallbackHandler},
{"XML::Xercesc::delete_PerlContentCallbackHandler", _wrap_delete_PerlContentCallbackHandler},
{"XML::Xercesc::PerlContentCallbackHandler_set_callback_obj", _wrap_PerlContentCallbackHandler_set_callback_obj},
{"XML::Xercesc::PerlContentCallbackHandler_characters", _wrap_PerlContentCallbackHandler_characters},
{"XML::Xercesc::PerlContentCallbackHandler_processingInstruction", _wrap_PerlContentCallbackHandler_processingInstruction},
{"XML::Xercesc::PerlContentCallbackHandler_setDocumentLocator", _wrap_PerlContentCallbackHandler_setDocumentLocator},
{"XML::Xercesc::PerlContentCallbackHandler_startPrefixMapping", _wrap_PerlContentCallbackHandler_startPrefixMapping},
{"XML::Xercesc::PerlContentCallbackHandler_endPrefixMapping", _wrap_PerlContentCallbackHandler_endPrefixMapping},
{"XML::Xercesc::PerlContentCallbackHandler_skippedEntity", _wrap_PerlContentCallbackHandler_skippedEntity},
{"XML::Xercesc::new_PerlEntityResolverHandler", _wrap_new_PerlEntityResolverHandler},
{"XML::Xercesc::delete_PerlEntityResolverHandler", _wrap_delete_PerlEntityResolverHandler},
{"XML::Xercesc::PerlEntityResolverHandler_set_callback_obj", _wrap_PerlEntityResolverHandler_set_callback_obj},
{"XML::Xercesc::new_PerlNodeFilterCallbackHandler", _wrap_new_PerlNodeFilterCallbackHandler},
{"XML::Xercesc::delete_PerlNodeFilterCallbackHandler", _wrap_delete_PerlNodeFilterCallbackHandler},
{"XML::Xercesc::PerlNodeFilterCallbackHandler_set_callback_obj", _wrap_PerlNodeFilterCallbackHandler_set_callback_obj},
{0,0}
};

#ifdef __cplusplus
extern "C"
#endif

XS(SWIG_init) {
    dXSARGS;
    int i;
    static int _init = 0;
    if (!_init) {
        for (i = 0; swig_types_initial[i]; i++) {
            swig_types[i] = SWIG_TypeRegister(swig_types_initial[i]);
        }
        _init = 1;
    }
    
    /* Install commands */
    for (i = 0; swig_commands[i].name; i++) {
        newXS((char*) swig_commands[i].name,swig_commands[i].wrapper, (char*)__FILE__);
    }
    
    /* Install variables */
    for (i = 0; swig_variables[i].name; i++) {
        SV *sv;
        sv = perl_get_sv((char*) swig_variables[i].name, TRUE | 0x2);
        if (swig_variables[i].type) {
            SWIG_MakePtr(sv,(void *)1, *swig_variables[i].type,0);
        }else {
            sv_setiv(sv,(IV) 0);
        }
        swig_create_magic(sv, (char *) swig_variables[i].name, swig_variables[i].set, swig_variables[i].get); 
    }
    
    /* Install constant */
    for (i = 0; swig_constants[i].type; i++) {
        SV *sv;
        sv = perl_get_sv((char*)swig_constants[i].name, TRUE | 0x2);
        switch(swig_constants[i].type) {
            case SWIG_INT:
            sv_setiv(sv, (IV) swig_constants[i].lvalue);
            break;
            case SWIG_FLOAT:
            sv_setnv(sv, (double) swig_constants[i].dvalue);
            break;
            case SWIG_STRING:
            sv_setpv(sv, (char *) swig_constants[i].pvalue);
            break;
            case SWIG_POINTER:
            SWIG_MakePtr(sv, swig_constants[i].pvalue, *(swig_constants[i].ptype),0);
            break;
            case SWIG_BINARY:
            /*      obj = SWIG_NewPackedObj(swig_constants[i].pvalue, swig_constants[i].lvalue, *(swig_constants[i].ptype)); */
            break;
            default:
            break;
        }
        SvREADONLY_on(sv);
    }
    
    
    SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode->dcast = (swig_dycast_func) DOMNode_dynamic_cast;
    
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDeleter, (void*) "XML::Xerces::XMLDeleter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPlatformUtils, (void*) "XML::Xerces::XMLPlatformUtils");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLURL, (void*) "XML::Xerces::XMLURL");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUri, (void*) "XML::Xerces::XMLUri");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__QName, (void*) "XML::Xerces::QName");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__HexBin, (void*) "XML::Xerces::HexBin");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__Base64, (void*) "XML::Xerces::Base64");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLExcepts, (void*) "XML::Xerces::XMLExcepts");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLException, (void*) "XML::Xerces::XMLException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLValidator, (void*) "XML::Xerces::XMLValidator");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXException, (void*) "XML::Xerces::SAXException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotSupportedException, (void*) "XML::Xerces::SAXNotSupportedException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXNotRecognizedException, (void*) "XML::Xerces::SAXNotRecognizedException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParseException, (void*) "XML::Xerces::SAXParseException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__ErrorHandler, (void*) "XML::Xerces::ErrorHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DTDHandler, (void*) "XML::Xerces::DTDHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocumentHandler, (void*) "XML::Xerces::DocumentHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__EntityResolver, (void*) "XML::Xerces::EntityResolver");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__AttributeList, (void*) "XML::Xerces::AttributeList");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__HandlerBase, (void*) "XML::Xerces::HandlerBase");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__Locator, (void*) "XML::Xerces::Locator");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__Attributes, (void*) "XML::Xerces::Attributes");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__ContentHandler, (void*) "XML::Xerces::ContentHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__LexicalHandler, (void*) "XML::Xerces::LexicalHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DeclHandler, (void*) "XML::Xerces::DeclHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DefaultHandler, (void*) "XML::Xerces::DefaultHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__InputSource, (void*) "XML::Xerces::InputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufInputSource, (void*) "XML::Xerces::MemBufInputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdInInputSource, (void*) "XML::Xerces::StdInInputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__LocalFileInputSource, (void*) "XML::Xerces::LocalFileInputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__URLInputSource, (void*) "XML::Xerces::URLInputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatter, (void*) "XML::Xerces::XMLFormatter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLFormatTarget, (void*) "XML::Xerces::XMLFormatTarget");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__MemBufFormatTarget, (void*) "XML::Xerces::MemBufFormatTarget");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__StdOutFormatTarget, (void*) "XML::Xerces::StdOutFormatTarget");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLUni, (void*) "XML::Xerces::XMLUni");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLScanner, (void*) "XML::Xerces::XMLScanner");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLPScanToken, (void*) "XML::Xerces::XMLPScanToken");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__Parser, (void*) "XML::Xerces::Parser");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLDocumentHandler, (void*) "XML::Xerces::XMLDocumentHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLErrorReporter, (void*) "XML::Xerces::XMLErrorReporter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLEntityHandler, (void*) "XML::Xerces::XMLEntityHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DocTypeHandler, (void*) "XML::Xerces::DocTypeHandler");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAX2XMLReader, (void*) "XML::Xerces::SAX2XMLReader");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XMLReaderFactory, (void*) "XML::Xerces::XMLReaderFactory");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__SAXParser, (void*) "XML::Xerces::SAXParser");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__Grammar, (void*) "XML::Xerces::Grammar");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMException, (void*) "XML::Xerces::DOMException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentRange, (void*) "XML::Xerces::DOMDocumentRange");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentTraversal, (void*) "XML::Xerces::DOMDocumentTraversal");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeFilter, (void*) "XML::Xerces::DOMNodeFilter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeIterator, (void*) "XML::Xerces::DOMNodeIterator");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRange, (void*) "XML::Xerces::DOMRange");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMRangeException, (void*) "XML::Xerces::DOMRangeException");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMTreeWalker, (void*) "XML::Xerces::DOMTreeWalker");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNode, (void*) "XML::Xerces::DOMNode");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMAttr, (void*) "XML::Xerces::DOMAttr");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCharacterData, (void*) "XML::Xerces::DOMCharacterData");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMText, (void*) "XML::Xerces::DOMText");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMCDATASection, (void*) "XML::Xerces::DOMCDATASection");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMComment, (void*) "XML::Xerces::DOMComment");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocument, (void*) "XML::Xerces::DOMDocument");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentFragment, (void*) "XML::Xerces::DOMDocumentFragment");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMDocumentType, (void*) "XML::Xerces::DOMDocumentType");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationLS, (void*) "XML::Xerces::DOMImplementationLS");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementation, (void*) "XML::Xerces::DOMImplementation");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMElement, (void*) "XML::Xerces::DOMElement");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntity, (void*) "XML::Xerces::DOMEntity");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMEntityReference, (void*) "XML::Xerces::DOMEntityReference");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNamedNodeMap, (void*) "XML::Xerces::DOMNamedNodeMap");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNodeList, (void*) "XML::Xerces::DOMNodeList");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMNotation, (void*) "XML::Xerces::DOMNotation");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMProcessingInstruction, (void*) "XML::Xerces::DOMProcessingInstruction");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMBuilder, (void*) "XML::Xerces::DOMBuilder");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationRegistry, (void*) "XML::Xerces::DOMImplementationRegistry");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMImplementationSource, (void*) "XML::Xerces::DOMImplementationSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMInputSource, (void*) "XML::Xerces::DOMInputSource");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMLocator, (void*) "XML::Xerces::DOMLocator");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriter, (void*) "XML::Xerces::DOMWriter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__DOMWriterFilter, (void*) "XML::Xerces::DOMWriterFilter");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__AbstractDOMParser, (void*) "XML::Xerces::AbstractDOMParser");
    SWIG_TypeClientData(SWIGTYPE_p_XERCES_CPP_NAMESPACE__XercesDOMParser, (void*) "XML::Xerces::XercesDOMParser");
    SWIG_TypeClientData(SWIGTYPE_p_PerlErrorCallbackHandler, (void*) "XML::Xerces::PerlErrorCallbackHandler");
    SWIG_TypeClientData(SWIGTYPE_p_PerlDocumentCallbackHandler, (void*) "XML::Xerces::PerlDocumentCallbackHandler");
    SWIG_TypeClientData(SWIGTYPE_p_PerlContentCallbackHandler, (void*) "XML::Xerces::PerlContentCallbackHandler");
    SWIG_TypeClientData(SWIGTYPE_p_PerlEntityResolverHandler, (void*) "XML::Xerces::PerlEntityResolverHandler");
    SWIG_TypeClientData(SWIGTYPE_p_PerlNodeFilterCallbackHandler, (void*) "XML::Xerces::PerlNodeFilterCallbackHandler");
    
    // we create the global transcoder for UTF-8 to UTF-16
    XMLTransService::Codes failReason;
    XMLPlatformUtils::Initialize(); // first we must create the transservice
    UTF8_ENCODING = XMLString::transcode("UTF-8");
    UTF8_TRANSCODER =
    XMLPlatformUtils::fgTransService->makeNewTranscoderFor(UTF8_ENCODING,
    failReason,
    1024,
    XMLPlatformUtils::fgMemoryManager);
    if (! UTF8_TRANSCODER) {
        croak("ERROR: XML::Xerces: INIT: Could not create UTF-8 transcoder");
    }
    
    
    ISO_8859_1_ENCODING = XMLString::transcode("ISO-8859-1");
    ISO_8859_1_TRANSCODER =
    XMLPlatformUtils::fgTransService->makeNewTranscoderFor(ISO_8859_1_ENCODING,
    failReason,
    1024,
    XMLPlatformUtils::fgMemoryManager);
    if (! ISO_8859_1_TRANSCODER) {
        croak("ERROR: XML::Xerces: INIT: Could not create ISO-8859-1 transcoder");
    }
    
    
    ST(0) = &PL_sv_yes;
    XSRETURN(1);
}

